#----------------------------------------------------------------------
# This file was generated by /Users/humberto.a.sanchez.ii/PycharmProjects/PyUt/venv-pyenv-3.9.0/bin/img2py
#
from wx.lib.embeddedimage import PyEmbeddedImage

embeddedImage = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAAA8AAAAPCAYAAAA71pVKAAABhWlDQ1BJQ0MgcHJvZmlsZQAA'
    b'KJF9kT1Iw1AUhU9TpSIVBSuIOmSoThZERR21CkWoEGqFVh1MXn+hSUOS4uIouBYc/FmsOrg4'
    b'6+rgKgiCPyBubk6KLlLifUmhRYwXHu/jvHsO790HCLUSU822MUDVLCMRi4qp9KoYeIUPPejD'
    b'NAZlZupzkhSHZ33dUzfVXYRneff9WV2ZrMkAn0g8y3TDIt4gntq0dM77xCFWkDPE58SjBl2Q'
    b'+JHristvnPMOCzwzZCQT88QhYjHfwkoLs4KhEk8ShzOqRvlCyuUM5y3OaqnCGvfkLwxmtZVl'
    b'rtMaQgyLWIIEEQoqKKIECxHaNVJMJOg86uEfcPwSuRRyFcHIsYAyVMiOH/wPfs/WzE2Mu0nB'
    b'KND+Ytsfw0BgF6hXbfv72LbrJ4D/GbjSmv5yDZj5JL3a1MJHQPc2cHHd1JQ94HIH6H/SZUN2'
    b'JD8tIZcD3s/om9JA7y3QuebOrXGO0wcgSbOK3wAHh8BInrLXPd7d0Tq3f3sa8/sBmGhytoLJ'
    b'W7wAAAAGYktHRAD/AP8A/6C9p5MAAAAJcEhZcwAACxIAAAsSAdLdfvwAAAAHdElNRQflARAV'
    b'ORDu+qL7AAAAZUlEQVQoz6WSwQ3AMAgDHcQS3aajZxvGoJ9WSktAMvUPibNNFOCHxmd2Zj/A'
    b'0/b8eYzACFPzNvYWvKQ7ACiZ+jKRKmVJ2koycJpjmpcGwtSlYbp28sJBmlV9oKq2dm7t/u2K'
    b'5XQBrCMgHHCHIN4AAAAASUVORK5CYII=')

