#----------------------------------------------------------------------
# This file was generated by /Users/humberto.a.sanchez.ii/PycharmProjects/PyUt/venv-pyenv-3.9.0/bin/img2py
#
from wx.lib.embeddedimage import PyEmbeddedImage

embeddedImage = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAABhGlDQ1BJQ0MgcHJvZmlsZQAA'
    b'KJF9kTtIw1AUhv+miiKVInYQcchQnSyIiuimVShChVArtOpgctMXNGlIUlwcBdeCg4/FqoOL'
    b's64OroIg+ABxc3NSdJESz00KLWI8cLgf/z3/4dxzAaFeZprVMQZoum2mEnExk10Vu14RQB9l'
    b'GDMys4w5SUrCN77uqZLiLsZ7+df9Gb1qzmJAQCSeZYZpE28QT23aBud94ggryirxOfGoSQMS'
    b'P3Jd8fiNc8FlgfeMmOnUPHGEWCy0sdLGrGhqxJPEUVXTqb+Q8VjlvMVZK1dZc07+wlBOX1nm'
    b'OuUQEljEEiSIUFBFCWXYiNGpk2IhRfdxH/+g65fIpZCrBEaOBVSgQXb94H/we7dWfmLc6xSK'
    b'A50vjvMxDHTtAo2a43wfO07jBAg+A1d6y1+pA9OfpNdaWvQICG8DF9ctTdkDLneAgSdDNmVX'
    b'ClIK+TzwfkbflAX6b4GeNW9vzXucPgBp2lXyBjg4BEYK1Hvd593d7Xv7t6a5vx9PpXKZcf7U'
    b'MwAAAAZiS0dEAP8A/wD/oL2nkwAAAAlwSFlzAAAOxAAADsQBlSsOGwAAAAd0SU1FB+UBEQER'
    b'IDbtUDQAAAA9SURBVDjLY2AYBaSA/9gEGck0gJEsA/7/h5jByIjQz4jLaThMQHU+IyMDCwmu'
    b'+I+sEdkFFIUBxbEwCqgAAG+sDQpZORdGAAAAAElFTkSuQmCC')

