#----------------------------------------------------------------------
# This file was generated by /Users/humberto.a.sanchez.ii/PycharmProjects/PyUt/venv-pyenv-3.9.0/bin/img2py
#
from wx.lib.embeddedimage import PyEmbeddedImage

embeddedImage = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAK3RFWHRDcmVhdGlvbiBUaW1l'
    b'AERpIDE2IEF1ZyAyMDA1IDEzOjU3OjUwICswMTAw0YaYRwAAAAd0SU1FB9MCGxAGHYzcL/AA'
    b'AAAJcEhZcwAACvAAAArwAUKsNJgAAAAEZ0FNQQAAsY8L/GEFAAACO0lEQVR42qWSXUgUURTH'
    b'/3d2ZsfWbDfSPiwqzAo1LKKiaF8s0AiCIsinHgz7WoMeAoMKoVyCfJHood1KRHqIQM0tF6uX'
    b'etLt81XXRJPYXd11Rmd3xmn2w9MoWA+5ttAfzuFeuPfHOf9zgP8UWzxIUzHhVY+vMZFOnefz'
    b'V2/WlOm4GhrrJt5663azO7wsYDgY5AOBQG9h5f6aHXvKIOtARANikzJF/O1hXY46795r+b4U'
    b'gJtPnwIDDfaKfTVO8/Na856XScOi6+AEG3Mcd20UraInWwULAEkz6ooryjEbCUE3w5gIgZfC'
    b'EGPjYBwPvmRv9cX6c8VLAfj5RPmrSmUVCO7ehNkMoKUB1Yx4CnD0jSBv3VamTE9vM5+GlwQk'
    b'E4o0oVJ+gX8YsW9DSKYJMINLZqDLU+DIAGNMylqBGh7ttUzJLkXcAEtZIYQ5QipFcBBD3koH'
    b'JF/LyLPO7sGsHsAiNKvvOiLxJEfxjAg9zcMmroBgs2P2s48MeXL9g47nb1+eOWTLugc3rjdu'
    b't4rCU1Zy8IBYtIVSmgJ98P1EPPJDcLd6i748uYKqvrYeNvqzlpld/gVY1KX6ukplZqbUSKak'
    b'/g8fB67dvOPZSUN1J44owKBpQ1fAj0D0NBuHkdOqXm5qsKer0E7t1UTDV4k6TxLVrnlD5bDl'
    b'BFgYs+kVnSp4TI+OmhAXaV1nqanVG/xj4j9k9jmHF4kL8Pd79NdBRJ33wRLS199jzBFC5NNd'
    b'7sPHdlm8D8fkyXBbzi0sp1+5mvzKqKC80wAAAABJRU5ErkJggg==')

