#----------------------------------------------------------------------
# This file was generated by /Users/humberto.a.sanchez.ii/PycharmProjects/PyUt/venv-pyenv-3.9.0/bin/img2py
#
from wx.lib.embeddedimage import PyEmbeddedImage

embeddedImage = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAADr3pUWHRSYXcgcHJvZmlsZSB0'
    b'eXBlIGV4aWYAAHja7VZbsuMoDP3XKmYJlsRDLAeDqZod9PLngO3cOLGT3On701VtYh5CHCQd'
    b'gUPLr38b/YNHRIycjxZSCBMel1ySjI5N65NHzZMb9Xhkm8L4IKfbhECkaHUdWtj0dznfANYm'
    b'o+fvgKxsE/NxIrkN3x6Atp21W9T7dQNKG5DKOsEbQF7dmkKyeO/CvKxt3T2x9aVeOTua/TSO'
    b'iF712EdFFmWdUIvKaoD2l0kzOoxa1Env9b5H6XXawBCQszhNd1bRIyu3Hl/IH0jRsMoJgmMw'
    b'w609lbN/kG+ANEJ8t7OW284HeZQpPrqzv61Vo9aW1bvsAkIaNqd2V0YPijNCrmNZQIl4Pfpx'
    b'lIRihOwtoLxOZZpRCicW0NLYceXMjZfRFi4w0ckiMA1HooCoLjONkqToRGDJ9cJNoiatauCv'
    b'gF6FVG628Ng3je0KGzauDE1hgHFPBerVT5RLoNZ6yjNPdosV7JKehDCjM9draIEQbnse+RHg'
    b'vTw+nVcFg36E2eBgnuYVYva85VbPIx1EKxQ92vWscawbAEKEvT2MQdY7ngKr58DIB4nMiKOB'
    b'nwwg62djBgXsvVRYKU41gByTvjfWRB664mUV484CEV6DRlCTNIMrh4sN+ROdIYcyjpjz3gcf'
    b'vfnkc9Dggg8hxNAvvxw1uuhjiDFaTDGbmjNvwaIZWbKcJCkuR59CislSSjlj0wzkjNUZCjnP'
    b'MuvsZj+HOc42pzkXpE9xxZdQYjEqqeQqVSvuiRpqrFZTzQsvSKXFLX4JS1xsSUtuSLWmzTXf'
    b'QovNWmr5xhrTSutT+Zw13lmTwVRXjDfWsDTGHYL7deI7Z2BMHIPx2BlAQkvnbDJ2TqhT1zmb'
    b'kuBUeIGVvpNTuTMGBt3C4hvfuPti7sAbOfdbvMnOHHXqfoI56tRdMPfM2wlrtX9tyqQ0GOrH'
    b'sAd1Uhw/KGUx/PBN+ryl7y74A4Ca9c+60tIQkf4d7jM6Ro/Kx9mTUZvbQuf4r5Z8wzXd15ws'
    b'vpqjdwunYeQMo7buIQBfK+m1wZ+0KxjtdjxF5rVzPZxDuo7mhYbJ90baKweu7afvOXBtI32X'
    b'nSsC6HsOHHXu40rvOLuL3UvpVx7tpl6Nn8AODgq9W7aTfUR4du48Id8e0+cRfa76ekSXk+8T'
    b'7N5B5NG7IH84pt8F+Mrstws+uG1Pbsj/3dJFLl/se52c9BPWnACdXFonu3/o2o/F6C/QX6BP'
    b'vnQN/yAT/QfFhVT0iscGGwAAAYVpQ0NQSUNDIHByb2ZpbGUAAHicfZE9SMNQFIVPU0WRiogd'
    b'ijhkqE4WREUdtQpFqBBqhVYdTF76B00akhQXR8G14ODPYtXBxVlXB1dBEPwBcXNzUnSREu9L'
    b'Ci1ivPB4H+fdc3jvPkCol5lmdYwBmm6bqURczGRXxa5XBBBBP6YRkZllzElSEr71dU/dVHcx'
    b'nuXf92f1qjmLAQGReJYZpk28QTy1aRuc94nDrCirxOfEoyZdkPiR64rHb5wLLgs8M2ymU/PE'
    b'YWKx0MZKG7OiqRFPEkdVTad8IeOxynmLs1ausuY9+QtDOX1lmeu0hpDAIpYgQYSCKkoow0aM'
    b'dp0UCyk6j/v4B12/RC6FXCUwciygAg2y6wf/g9+ztfIT415SKA50vjjOxzDQtQs0ao7zfew4'
    b'jRMg+Axc6S1/pQ7MfJJea2nRI6BvG7i4bmnKHnC5A0SeDNmUXSlIS8jngfcz+qYsMHAL9Kx5'
    b'c2ue4/QBSNOskjfAwSEwUqDsdZ93d7fP7d+e5vx+AJsFcrcY3lRgAAAPoGlUWHRYTUw6Y29t'
    b'LmFkb2JlLnhtcAAAAAAAPD94cGFja2V0IGJlZ2luPSLvu78iIGlkPSJXNU0wTXBDZWhpSHpy'
    b'ZVN6TlRjemtjOWQiPz4KPHg6eG1wbWV0YSB4bWxuczp4PSJhZG9iZTpuczptZXRhLyIgeDp4'
    b'bXB0az0iWE1QIENvcmUgNC40LjAtRXhpdjIiPgogPHJkZjpSREYgeG1sbnM6cmRmPSJodHRw'
    b'Oi8vd3d3LnczLm9yZy8xOTk5LzAyLzIyLXJkZi1zeW50YXgtbnMjIj4KICA8cmRmOkRlc2Ny'
    b'aXB0aW9uIHJkZjphYm91dD0iIgogICAgeG1sbnM6aXB0Y0V4dD0iaHR0cDovL2lwdGMub3Jn'
    b'L3N0ZC9JcHRjNHhtcEV4dC8yMDA4LTAyLTI5LyIKICAgIHhtbG5zOnhtcE1NPSJodHRwOi8v'
    b'bnMuYWRvYmUuY29tL3hhcC8xLjAvbW0vIgogICAgeG1sbnM6c3RFdnQ9Imh0dHA6Ly9ucy5h'
    b'ZG9iZS5jb20veGFwLzEuMC9zVHlwZS9SZXNvdXJjZUV2ZW50IyIKICAgIHhtbG5zOnBsdXM9'
    b'Imh0dHA6Ly9ucy51c2VwbHVzLm9yZy9sZGYveG1wLzEuMC8iCiAgICB4bWxuczpHSU1QPSJo'
    b'dHRwOi8vd3d3LmdpbXAub3JnL3htcC8iCiAgICB4bWxuczpkYz0iaHR0cDovL3B1cmwub3Jn'
    b'L2RjL2VsZW1lbnRzLzEuMS8iCiAgICB4bWxuczp0aWZmPSJodHRwOi8vbnMuYWRvYmUuY29t'
    b'L3RpZmYvMS4wLyIKICAgIHhtbG5zOnhtcD0iaHR0cDovL25zLmFkb2JlLmNvbS94YXAvMS4w'
    b'LyIKICAgeG1wTU06RG9jdW1lbnRJRD0iZ2ltcDpkb2NpZDpnaW1wOjFlYWQxOGVhLTEwZDQt'
    b'NDdjNy1iMGI5LWM0MGRlM2UwODZmYiIKICAgeG1wTU06SW5zdGFuY2VJRD0ieG1wLmlpZDo3'
    b'ZGUwM2VlNC05YTYxLTQwNWUtYjBjMC05ZDQ1Y2Y3ODY5OGQiCiAgIHhtcE1NOk9yaWdpbmFs'
    b'RG9jdW1lbnRJRD0ieG1wLmRpZDo3ZTMxYTFlNi02NDZlLTQ3OWMtYjg4Zi0xZTFkMjIzOWJl'
    b'MWYiCiAgIEdJTVA6QVBJPSIyLjAiCiAgIEdJTVA6UGxhdGZvcm09Ik1hYyBPUyIKICAgR0lN'
    b'UDpUaW1lU3RhbXA9IjE2MTE1MTA5NjIxMTcxNTAiCiAgIEdJTVA6VmVyc2lvbj0iMi4xMC4y'
    b'MiIKICAgZGM6Rm9ybWF0PSJpbWFnZS9wbmciCiAgIHRpZmY6T3JpZW50YXRpb249IjEiCiAg'
    b'IHhtcDpDcmVhdG9yVG9vbD0iR0lNUCAyLjEwIj4KICAgPGlwdGNFeHQ6TG9jYXRpb25DcmVh'
    b'dGVkPgogICAgPHJkZjpCYWcvPgogICA8L2lwdGNFeHQ6TG9jYXRpb25DcmVhdGVkPgogICA8'
    b'aXB0Y0V4dDpMb2NhdGlvblNob3duPgogICAgPHJkZjpCYWcvPgogICA8L2lwdGNFeHQ6TG9j'
    b'YXRpb25TaG93bj4KICAgPGlwdGNFeHQ6QXJ0d29ya09yT2JqZWN0PgogICAgPHJkZjpCYWcv'
    b'PgogICA8L2lwdGNFeHQ6QXJ0d29ya09yT2JqZWN0PgogICA8aXB0Y0V4dDpSZWdpc3RyeUlk'
    b'PgogICAgPHJkZjpCYWcvPgogICA8L2lwdGNFeHQ6UmVnaXN0cnlJZD4KICAgPHhtcE1NOkhp'
    b'c3Rvcnk+CiAgICA8cmRmOlNlcT4KICAgICA8cmRmOmxpCiAgICAgIHN0RXZ0OmFjdGlvbj0i'
    b'c2F2ZWQiCiAgICAgIHN0RXZ0OmNoYW5nZWQ9Ii8iCiAgICAgIHN0RXZ0Omluc3RhbmNlSUQ9'
    b'InhtcC5paWQ6NTk5ZTU4YzYtYmIxMy00YzYxLTg2OGYtMDc5OWJmMWVhNDZkIgogICAgICBz'
    b'dEV2dDpzb2Z0d2FyZUFnZW50PSJHaW1wIDIuMTAgKE1hYyBPUykiCiAgICAgIHN0RXZ0Ondo'
    b'ZW49IjIwMjEtMDEtMjRUMTE6NTY6MDItMDY6MDAiLz4KICAgIDwvcmRmOlNlcT4KICAgPC94'
    b'bXBNTTpIaXN0b3J5PgogICA8cGx1czpJbWFnZVN1cHBsaWVyPgogICAgPHJkZjpTZXEvPgog'
    b'ICA8L3BsdXM6SW1hZ2VTdXBwbGllcj4KICAgPHBsdXM6SW1hZ2VDcmVhdG9yPgogICAgPHJk'
    b'ZjpTZXEvPgogICA8L3BsdXM6SW1hZ2VDcmVhdG9yPgogICA8cGx1czpDb3B5cmlnaHRPd25l'
    b'cj4KICAgIDxyZGY6U2VxLz4KICAgPC9wbHVzOkNvcHlyaWdodE93bmVyPgogICA8cGx1czpM'
    b'aWNlbnNvcj4KICAgIDxyZGY6U2VxLz4KICAgPC9wbHVzOkxpY2Vuc29yPgogIDwvcmRmOkRl'
    b'c2NyaXB0aW9uPgogPC9yZGY6UkRGPgo8L3g6eG1wbWV0YT4KICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgIAogICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgCiAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAKICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgIAogICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'CiAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAKICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgIAogICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgCiAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAKICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgIAogICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgCiAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAKICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgIAog'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgCiAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAKICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgIAogICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgCiAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAKICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgIAogICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgCiAgICAgICAgICAgICAgICAgICAgICAgICAgIAo8P3hwYWNrZXQgZW5kPSJ3Ij8+13bj'
    b'LwAAAAZiS0dEAP8A/wD/oL2nkwAAAAlwSFlzAAALEwAACxMBAJqcGAAAAAd0SU1FB+UBGBE4'
    b'AsblYsEAAACCSURBVFjD7ZQ7DsAgDENjxP2v7C4dEKLlF8hiL4gEKY/EYCZJwcK7shGzRm70'
    b'DGYgOLmvY9zpQIoeQV7sErwBOOiVEsgFIhUF4HmzUW+c9gB7IB4ewE8eFQRuGpwf3WAUQBME'
    b'h4l6LWf4RxQ+ghwEhNln6F7YLrxLXqqz9xVLkiRJD8kaJA6UusFqAAAAAElFTkSuQmCC')

