#----------------------------------------------------------------------
# This file was generated by /Users/humberto.a.sanchez.ii/PycharmProjects/PyUt/venv-pyenv-3.9.0/bin/img2py
#
from wx.lib.embeddedimage import PyEmbeddedImage

embeddedImage = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAGXRFWHRTb2Z0d2FyZQBBZG9i'
    b'ZSBJbWFnZVJlYWR5ccllPAAAA9dpVFh0WE1MOmNvbS5hZG9iZS54bXAAAAAAADw/eHBhY2tl'
    b'dCBiZWdpbj0i77u/IiBpZD0iVzVNME1wQ2VoaUh6cmVTek5UY3prYzlkIj8+IDx4OnhtcG1l'
    b'dGEgeG1sbnM6eD0iYWRvYmU6bnM6bWV0YS8iIHg6eG1wdGs9IkFkb2JlIFhNUCBDb3JlIDUu'
    b'MC1jMDYwIDYxLjEzNDc3NywgMjAxMC8wMi8xMi0xNzozMjowMCAgICAgICAgIj4gPHJkZjpS'
    b'REYgeG1sbnM6cmRmPSJodHRwOi8vd3d3LnczLm9yZy8xOTk5LzAyLzIyLXJkZi1zeW50YXgt'
    b'bnMjIj4gPHJkZjpEZXNjcmlwdGlvbiByZGY6YWJvdXQ9IiIgeG1sbnM6eG1wUmlnaHRzPSJo'
    b'dHRwOi8vbnMuYWRvYmUuY29tL3hhcC8xLjAvcmlnaHRzLyIgeG1sbnM6eG1wTU09Imh0dHA6'
    b'Ly9ucy5hZG9iZS5jb20veGFwLzEuMC9tbS8iIHhtbG5zOnN0UmVmPSJodHRwOi8vbnMuYWRv'
    b'YmUuY29tL3hhcC8xLjAvc1R5cGUvUmVzb3VyY2VSZWYjIiB4bWxuczp4bXA9Imh0dHA6Ly9u'
    b'cy5hZG9iZS5jb20veGFwLzEuMC8iIHhtcFJpZ2h0czpNYXJrZWQ9IkZhbHNlIiB4bXBNTTpP'
    b'cmlnaW5hbERvY3VtZW50SUQ9ImFkb2JlOmRvY2lkOnBob3Rvc2hvcDo4ZTMyMGZhYy0xMDU3'
    b'LTExZGItYTlkNC1mZTk0NmM0OWUxNTciIHhtcE1NOkRvY3VtZW50SUQ9InhtcC5kaWQ6RTFB'
    b'NUY3REJGM0I0MTFFNkEzNDlGNjRCNEQ1RDgxRDEiIHhtcE1NOkluc3RhbmNlSUQ9InhtcC5p'
    b'aWQ6RTFBNUY3REFGM0I0MTFFNkEzNDlGNjRCNEQ1RDgxRDEiIHhtcDpDcmVhdG9yVG9vbD0i'
    b'QWRvYmUgUGhvdG9zaG9wIENTNSBXaW5kb3dzIj4gPHhtcE1NOkRlcml2ZWRGcm9tIHN0UmVm'
    b'Omluc3RhbmNlSUQ9InhtcC5paWQ6MjhGQjk3NTU5N0YzRTYxMTk1QkZFNzg5RjBFRkJDN0Ei'
    b'IHN0UmVmOmRvY3VtZW50SUQ9ImFkb2JlOmRvY2lkOnBob3Rvc2hvcDo4ZTMyMGZhYy0xMDU3'
    b'LTExZGItYTlkNC1mZTk0NmM0OWUxNTciLz4gPC9yZGY6RGVzY3JpcHRpb24+IDwvcmRmOlJE'
    b'Rj4gPC94OnhtcG1ldGE+IDw/eHBhY2tldCBlbmQ9InIiPz59cfg6AAACV0lEQVR42oyTS0wT'
    b'QRzGv5ndZdtSWmhLLLU0hFRSg2AIJ3zEejKePWji3eDNqweIB2IiXky8cEJiokb0KokHEkPU'
    b'pBdfREzrgzaRNlLY0t1uy27bHWervLQQdvPfncl8+5tvNt+fMMZ8lUplql6vewAGPm8Uf0Av'
    b'l5HPr73o7++/LwgCml2Ei0OKoiRNw3AzG2BZsOxiVmOcTmcgStLYyMipCRv69snjO92hkBU6'
    b'feaWJMuGDegqFAqLHODfBrA/ED5FoaAgm82hzeO5QQXqWp6dvf09maxcn3kYDnR2KmJTX2xn'
    b'aIMcDgc0rXSvqJpMPzEE19HwnP2xvU6bH+wvhzvxer0IR3rh0ecx1DNHVlc+VzfK+t0taXMH'
    b'u4wIkhPFzEcE2xfgd+o46Tk2Pnx5KrGloQcBCL9r1Ro2fz5CJEbw5Z2/FB28MN0VPIJDABio'
    b'5ML613n0RlPI/jDhjIzWYudH2W7VvgBCRFSKCkT9GXxBisxyDL7oObLzhw4C8D2I6ISSeo6+'
    b'gXV8+wS4eq5CEP+XNwVQsQVaLoV2+WWDtqaeRXv3IKyacThA3aIopp+ib3ATyfcu+GJXeCCM'
    b'vQHZD0AoRaW0gexaEYk3EszWS2j1h3hCq/8efzsHRJblFjs0dhNRKkLHL1gmgypdw8DwRb5x'
    b'FYLDyRMp2/raHsDS0lI9n88nebd12ABBENnih0SbuRmhEeqnrxdeMbs3CCEwDVOffjBzvFQq'
    b'5eLx+Mrk5KQhut3uvKZpcQ5o+FNVld0cm/CrqtZRr5mBJr5beYUDgcAqfxu/BRgAJ9ARQuBm'
    b'0B0AAAAASUVORK5CYII=')

