#----------------------------------------------------------------------
# This file was generated by /Users/humberto.a.sanchez.ii/PycharmProjects/PyUt/venv-pyenv-3.9.0/bin/img2py
#
from wx.lib.embeddedimage import PyEmbeddedImage

embeddedImage = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAAAXNSR0IArs4c6QAAADhlWElm'
    b'TU0AKgAAAAgAAYdpAAQAAAABAAAAGgAAAAAAAqACAAQAAAABAAAAIKADAAQAAAABAAAAIAAA'
    b'AACPTkDJAAAAoUlEQVRYCe1R7QrAIAhse/933uaPAxHFstr244SQzPvgao3FBJjAjxO4Hm9y'
    b'ttYRsFvhaC+A9489YisONm8Xb+VuSSNxCNh9zMtdE2biENEYzModZL3iEAIO93IXolHxspgH'
    b'PL3hm7PPDeAvR78BuOmwNFGvCY1ZakDIMhNLxUXQI4xMeLvCMVURqTUR7U2JZ2AxYY1kGL4z'
    b'ASbABJjAcAI34/cPC7xdKCUAAAAASUVORK5CYII=')

