#----------------------------------------------------------------------
# This file was generated by /Users/humberto.a.sanchez.ii/PycharmProjects/PyUt/venv-pyenv-3.9.0/bin/img2py
#
from wx.lib.embeddedimage import PyEmbeddedImage

embeddedImage = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAAA8AAAAPCAYAAAA71pVKAAABhWlDQ1BJQ0MgcHJvZmlsZQAA'
    b'KJF9kT1Iw1AUhU9TpSKVChYRcchQnSyIijhqFYpQIdQKrTqYvPRHaNKQpLg4Cq4FB38Wqw4u'
    b'zro6uAqC4A+Im5uToouUeF9SaBHjhcf7OO+ew3v3AUK9zDSrYwzQdNtMJxNiNrcihl4RQC/6'
    b'EUFIZpYxK0kp+NbXPXVT3cV5ln/fn9Wj5i0GBETiGWaYNvE68dSmbXDeJ46ykqwSnxOPmnRB'
    b'4keuKx6/cS66LPDMqJlJzxFHicViGyttzEqmRjxJHFM1nfKFrMcq5y3OWrnKmvfkLwzn9eUl'
    b'rtMaQhILWIQEEQqq2EAZNuK066RYSNN5wsc/6Polcink2gAjxzwq0CC7fvA/+D1bqzAx7iWF'
    b'E0Dni+N8DAOhXaBRc5zvY8dpnADBZ+BKb/krdWD6k/RaS4sdAZFt4OK6pSl7wOUOMPBkyKbs'
    b'SkFaQqEAvJ/RN+WAvluge9WbW/Mcpw9AhmaVugEODoGRImWv+by7q31u//Y05/cDBU1ye/Jw'
    b'OsYAAAAGYktHRAD/AP8A/6C9p5MAAAAJcEhZcwAACxIAAAsSAdLdfvwAAAAHdElNRQflARAW'
    b'Dza3rQgqAAAAWUlEQVQoz2NgoAAwovH/k6IeQ/OB59j1O0gyYuhhIsWZUIP/k6UZyfb/DAwM'
    b'DCwk2opiCBMloc1EwHkobKI0U2QzXTSz4ApZmF9xJRq8UYVPE7lpG59e0gAASEIXHOpnuVMA'
    b'AAAASUVORK5CYII=')

