#----------------------------------------------------------------------
# This file was generated by /Users/humberto.a.sanchez.ii/PycharmProjects/PyUt/venv-pyenv-3.9.0/bin/img2py
#
from wx.lib.embeddedimage import PyEmbeddedImage

embeddedImage = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAKnRFWHRDcmVhdGlvbiBUaW1l'
    b'AERpIDQgTXJ6IDIwMDMgMTk6MTg6MDUgKzAxMDDiemgrAAAAB3RJTUUH0wgNDSQH/TCwawAA'
    b'AAlwSFlzAAAK8AAACvABQqw0mAAAAARnQU1BAACxjwv8YQUAAAIHSURBVHjarZJNaBNBFMf/'
    b'6bpbk6VFt0loWk9tCOQgxILaGERQCl5UxJOhFxEPXrzorVAxYC+FCnqwXoqHngoVC0KlFFEE'
    b'D1Wh7aGSomD9oNKPdJOYdTv7Mc7MdptAEyjog7ez++a93/vP2wH+0QL7TfzwEDObv9HnugD3'
    b'ko6xqyO4vu9Or4ZhEGOT+jY1CMrjBxoV5J8is1XEOZei1yKIUjmsyEFtT94ewNwj5CXtWIKo'
    b'MXQcTSPcdQFKSxSSpLLdVeYm84g4Rl2AQZA4k30D21yCoX+H/nMK2+U1gBLYNkH89B2WFYTj'
    b'1ADePmiyILdKHalbga/vcjAKC6gUpiEfVKEdOYzmUCebnIlfywsglU9Q1NSugib+sGxaOXlt'
    b'JtCVuS02QloMkXgfDsVOoFmNC8kItKM9cRZ/ykH2rSDd/6yqwKXSsr66cjzS3blDrjDJZdz9'
    b'2Ibc/Km6Q76p/agBOPb8ytxoKtLdIwuAs8WCrV7xxkZdwGNkagAuZgufX1+xjbwmhmPpTIE3'
    b'36XL62LlccvyVtsG0ovhKuD8ACZeDsnZ9xP3LwkFhClASCQkk0lxLF5EiAfh71isGSI3sm1O'
    b'l9a/OALgFvkPFXGe7Dvv7sN82wVcvIcnihoVSebaLErFNg9Mqp39Ykob3MQWSbnxrYyRydEX'
    b'eqY/W2Kh5+o4Bhvc9hz+h/0FAjroo1wrUa4AAAAASUVORK5CYII=')

