#----------------------------------------------------------------------
# This file was generated by /Users/humberto.a.sanchez.ii/PycharmProjects/PyUt/venv-pyenv-3.9.0/bin/img2py
#
from wx.lib.embeddedimage import PyEmbeddedImage

embeddedImage = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAK3RFWHRDcmVhdGlvbiBUaW1l'
    b'AFNvIDE3IE5vdiAyMDAyIDE5OjE3OjQ2ICswMTAwQcC18QAAAAd0SU1FB9MCGhEmLPH4BjoA'
    b'AAAJcEhZcwAACvAAAArwAUKsNJgAAAAEZ0FNQQAAsY8L/GEFAAACh0lEQVR42qWTu2sUURTG'
    b'v7nzfiSbYd8bFhUJhGBEiELAJpWQQlCIkFKwsUsXGwtBLSz8EwTBThCxTKE2Fgq+goriA9xk'
    b'l2QTQ9jNkt3ZuXeuZ+7Krn1muPO653zn9517BzjioaUXZ+XjnV6jfeP2JctYmhtDxNVncB6D'
    b'xzFiGr2oDyY5Xnzt4O6rkLtR61736cWbLA0Urc4qPq8bXnSI6ekZZMMMEt6HTjqmocOxLRTz'
    b'WZw9cwphxkGu+9owZbKa5hoKg2kmXBtiAIRSsQDfc6FpGvr9viJQREJACA73xDyib1vmSCBN'
    b'tOhRChX4u7aBRqMBxhQgkiRBEAQ4VikQbgJm+9D4QHQgMGBFLBN6i1HI5xBOZCClpIqCesHV'
    b'PRWSiSRiqvWPdkigk09JAYKQa5t17DSbiiC1kUZ4ZKlazpFNCaanZHIkIOm0HAOmTtNRGyfK'
    b'GZyshERAPIQqiKAX9QCaM2klDCLWBgAjC75n4PE7jrUvbyBkWkVLa9Gd5DWmquo6CeoTsE0N'
    b'ysdQQGqwHRP1joafbYZIUAL1xKDBTB06o0FJ454Ji2w5ZtqE/yxQIRiWjkQauFDt4PpCiN29'
    b'fWw2tpWY5brIT/i49WwDMlNE6fTcsIlscGFUjfho05RDA4+et7H8QOLTYRWL81NYXjyPq8uX'
    b'gSAPrzqLmUkPXK3Y0EICkyyYXIfoHqAPG24mwHg2QKmcRbZUoaiICCmJeiPIMm2+EUFvjz/c'
    b'P0jgjnkw0YX0fRilHMbzBVSOT6nl3N2swaZ5Z8xBkLFpQ6E3JIjPPbnWWls4aH7fWSpONq2V'
    b'K761NEt2ignW339ArV7Xu61t79fLrT/s7WH8w4CI2p37R/2T1fEXJeb4wF5BsO0AAAAASUVO'
    b'RK5CYII=')

