#----------------------------------------------------------------------
# This file was generated by /Users/humberto.a.sanchez.ii/PycharmProjects/PyUt/venv-pyenv-3.9.0/bin/img2py
#
from wx.lib.embeddedimage import PyEmbeddedImage

embeddedImage = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAFznpUWHRSYXcgcHJvZmlsZSB0'
    b'eXBlIGV4aWYAAHjarVdZduwoDP1nFb0ECxCC5TCe0zvo5fcVYKeml0ryYsdGBVhIuppi+n//'
    b'DvMPLsshGM8SQwrhwOWTTzaDiMe68nzT4ed7XnYv4ffdvLkWLKYcRrd+xrD3n/N0MVhDBsU3'
    b'jGLdC+V+IfnNPz4w2ic7lUjpthmlzcjZtUCbQV5qHSFFuVWh9DW2U5O4HqMvH+/FfvotsF5j'
    b'nOOs7Y7cgbd1dgng9CHjMgjC2zqsgOJJR7xBb2YwyCs7HTdSmUdULor+MP8Aigtr3mDi3pjh'
    b'Gl/OEz/Mb4ZmmvjmZFevk+/mq7u8687I+ozRohmjL+2yDzBp2EqdqkwKGwtM7uZnAbfgYdAy'
    b'74Q7GnhvBeTtqEfBXSmRBSyDPDXKNKjPsVKFiN52KxitrQBK56ITmyzENcDG603DikuuAS/r'
    b'KuB1mLWXLDTPTfO4ShEHN8JOS2BG6gpGX79x/5HRGOryREe8bAW5rDohxFDk9I1dAITG6Uc8'
    b'DXzej5fi6oAgTzNHKJiPslgUpu1b6kduAu2wkTGuWCNpmwFMhLMZwpADAkeAw1OgQ6wVItgx'
    b'Ap8MRtE6bwsgIGbbIKX1zgWAE62ejW+E5l7Ldk0jZwEIdsEJoEkuAyuPxAb/ER/hQ5kde2YO'
    b'LBw5cQ4u+IDsFyRo8svixAtLEJEoSXJ00UeOIUqMJqaYk00OyZFTSJJiSilnHJrBOePrjA05'
    b'F1tc8YVLKFJiSSVXuE/1lWuoUqOpqeZmm2vIEy00abGlljt1uFL3nXvo0mNPPQ+42nDDDx5h'
    b'yIgjjXyhRmbB+nR/HTU6UbMTKd0oF2r4VORkQZpOWDEDYtYTEBdFAA5tFbMjkvfWKHSK2ZGQ'
    b'2RxbSMkKTiNFDAj6TpYHXdh9IHeHm/H+r3CzJ3JGofsN5IxC9wfknnF7gVrTalMPZyZCGoZq'
    b'1MMh/LAp24g/1KSvj+a7H3yT0YiHLX2MTX6Bl3mzwYHbl+QyX5RnFAmlW7sIztx8DxVes74q'
    b'wbgU5/dZ+4XPxxFjnmT3rlllPnoBvDqfTWfq7FwWdqkPlA0ZjTyjDoaoo2dtLN6MPJBqWZoq'
    b'wfrMudCbVPi3EgH+l1NtMfbNFjkDuXTSx+1oHid0RDWjSXKNkr20UiYT4dRD0sV9eN1n1gFj'
    b'D5saLIcwasO7ZWK1Skbtems97ZaWrUyfnSJm2rLaJBoCDjYrRCezFnv4FH9z5zOAd4KZjuGj'
    b'Ah3zggrxl0ei2gbLcE4Ps2VtH3AL1GmjC1u6S0yLqP+GVlMp8zWtKGzSP7tA8oDCm8JIfWkh'
    b'GxT9iYnC5H12tcIBAARypF+az9OQqRrSVsrSgqtRpTDxw/tT8oKmMySAKAWOw+qdUo9FeHSS'
    b'Lxxoj2YT13Yl5gSkOsVrXBqIcueZwlTzqaBUg+w+p1OVHB4NsHS8/Fw8EnitQuyz1BTahqSg'
    b'HzY3Ib/NPQnKpR09VTf4a5iaz0H9FFPUCTwlo2yiYR90rGiv9ims4ssY/AhrhNgVYWaHmGKq'
    b'Pp2PTsdP1DXf9+HX6ppX+n5H3XM0z771gbYSsXGPggZg5DjT0MyAOx8lana7ivk0fx4fn75J'
    b'nsVozHFDR5o0ZFZsdkJyvwGgDvfWkubGpGexUaKGDDCzHIix29KkZK7oBB6zm/nbqsazYenJ'
    b'RELw1DPijtQTqQUmaC1Iyi9st0qDuJo18oA9Is8kaX4lVTWOtk0/U9Y8a/szZc29trbAZer0'
    b'yTOqbAs+xzZyaogNxBbZsySknfg175tXFeGqFLva58C2B8dZ/Eh2eeb0dobCsJSg8zTwqRHO'
    b'PK8Z6ocJyvxKxCJgzUMtnYZCdQjHbdEoxwhoSqHZVTVW0YirnERp5lwoOyJKrCgltWfWUnK2'
    b'NpzSm+g2z+G9W5wZrjfh/Sa6ze90R1rXjk+q3jcylHlOUd/IUDcbzJd6xPcniLkp7n/F0dCv'
    b'iPTISPDfTkLa/B88tfbyQcfN4QAAAYVpQ0NQSUNDIHByb2ZpbGUAAHicfZE9SMNQFIVPU6Ui'
    b'FQcrSnHIUJ0siBVx1CoUoUKoFVp1MHnpHzRpSFJcHAXXgoM/i1UHF2ddHVwFQfAHxM3NSdFF'
    b'SryvKbSI8cLjfZx3z+G9+wChXmaa1TUBaLptphJxMZNdFQOv8GEIgwgjJjPLmJOkJDzr6566'
    b'qe6iPMu778/qU3MWA3wi8SwzTJt4g3h60zY47xOHWFFWic+Jx026IPEj1xWX3zgXmizwzJCZ'
    b'Ts0Th4jFQgcrHcyKpkY8RRxRNZ3yhYzLKuctzlq5ylr35C8M5vSVZa7TGkECi1iCBBEKqiih'
    b'DBtR2nVSLKToPO7hDzf9ErkUcpXAyLGACjTITT/4H/yerZWPTbpJwTjQ/eI4H6NAYBdo1Bzn'
    b'+9hxGieA/xm40tv+Sh2Y+SS91tYiR0D/NnBx3daUPeByBxh+MmRTbkp+WkI+D7yf0TdlgYFb'
    b'oHfNnVvrHKcPQJpmlbwBDg6BsQJlr3u8u6dzbv/2tOb3A51ScriOJyF4AAAPoGlUWHRYTUw6'
    b'Y29tLmFkb2JlLnhtcAAAAAAAPD94cGFja2V0IGJlZ2luPSLvu78iIGlkPSJXNU0wTXBDZWhp'
    b'SHpyZVN6TlRjemtjOWQiPz4KPHg6eG1wbWV0YSB4bWxuczp4PSJhZG9iZTpuczptZXRhLyIg'
    b'eDp4bXB0az0iWE1QIENvcmUgNC40LjAtRXhpdjIiPgogPHJkZjpSREYgeG1sbnM6cmRmPSJo'
    b'dHRwOi8vd3d3LnczLm9yZy8xOTk5LzAyLzIyLXJkZi1zeW50YXgtbnMjIj4KICA8cmRmOkRl'
    b'c2NyaXB0aW9uIHJkZjphYm91dD0iIgogICAgeG1sbnM6aXB0Y0V4dD0iaHR0cDovL2lwdGMu'
    b'b3JnL3N0ZC9JcHRjNHhtcEV4dC8yMDA4LTAyLTI5LyIKICAgIHhtbG5zOnhtcE1NPSJodHRw'
    b'Oi8vbnMuYWRvYmUuY29tL3hhcC8xLjAvbW0vIgogICAgeG1sbnM6c3RFdnQ9Imh0dHA6Ly9u'
    b'cy5hZG9iZS5jb20veGFwLzEuMC9zVHlwZS9SZXNvdXJjZUV2ZW50IyIKICAgIHhtbG5zOnBs'
    b'dXM9Imh0dHA6Ly9ucy51c2VwbHVzLm9yZy9sZGYveG1wLzEuMC8iCiAgICB4bWxuczpHSU1Q'
    b'PSJodHRwOi8vd3d3LmdpbXAub3JnL3htcC8iCiAgICB4bWxuczpkYz0iaHR0cDovL3B1cmwu'
    b'b3JnL2RjL2VsZW1lbnRzLzEuMS8iCiAgICB4bWxuczp0aWZmPSJodHRwOi8vbnMuYWRvYmUu'
    b'Y29tL3RpZmYvMS4wLyIKICAgIHhtbG5zOnhtcD0iaHR0cDovL25zLmFkb2JlLmNvbS94YXAv'
    b'MS4wLyIKICAgeG1wTU06RG9jdW1lbnRJRD0iZ2ltcDpkb2NpZDpnaW1wOjBlZWQzMWFhLTc1'
    b'NDYtNGM2ZC05NDQxLTllZTRkYWE3ZDE3OSIKICAgeG1wTU06SW5zdGFuY2VJRD0ieG1wLmlp'
    b'ZDozNTk1MjA4Ni1jN2JkLTRiOWEtYmY3My1jZjA2YjhlZGMwODEiCiAgIHhtcE1NOk9yaWdp'
    b'bmFsRG9jdW1lbnRJRD0ieG1wLmRpZDozNDRhNmQ2My03NDJlLTQ5NWItYmZiZS00OTFiY2Q5'
    b'MmJiZGMiCiAgIEdJTVA6QVBJPSIyLjAiCiAgIEdJTVA6UGxhdGZvcm09Ik1hYyBPUyIKICAg'
    b'R0lNUDpUaW1lU3RhbXA9IjE2MTE0MzcyOTczODc0MTAiCiAgIEdJTVA6VmVyc2lvbj0iMi4x'
    b'MC4yMiIKICAgZGM6Rm9ybWF0PSJpbWFnZS9wbmciCiAgIHRpZmY6T3JpZW50YXRpb249IjEi'
    b'CiAgIHhtcDpDcmVhdG9yVG9vbD0iR0lNUCAyLjEwIj4KICAgPGlwdGNFeHQ6TG9jYXRpb25D'
    b'cmVhdGVkPgogICAgPHJkZjpCYWcvPgogICA8L2lwdGNFeHQ6TG9jYXRpb25DcmVhdGVkPgog'
    b'ICA8aXB0Y0V4dDpMb2NhdGlvblNob3duPgogICAgPHJkZjpCYWcvPgogICA8L2lwdGNFeHQ6'
    b'TG9jYXRpb25TaG93bj4KICAgPGlwdGNFeHQ6QXJ0d29ya09yT2JqZWN0PgogICAgPHJkZjpC'
    b'YWcvPgogICA8L2lwdGNFeHQ6QXJ0d29ya09yT2JqZWN0PgogICA8aXB0Y0V4dDpSZWdpc3Ry'
    b'eUlkPgogICAgPHJkZjpCYWcvPgogICA8L2lwdGNFeHQ6UmVnaXN0cnlJZD4KICAgPHhtcE1N'
    b'Okhpc3Rvcnk+CiAgICA8cmRmOlNlcT4KICAgICA8cmRmOmxpCiAgICAgIHN0RXZ0OmFjdGlv'
    b'bj0ic2F2ZWQiCiAgICAgIHN0RXZ0OmNoYW5nZWQ9Ii8iCiAgICAgIHN0RXZ0Omluc3RhbmNl'
    b'SUQ9InhtcC5paWQ6ZTBhODE0NDEtMTc1Yy00ZmM3LTgwNmMtOGFjM2ZhOWJkZTJiIgogICAg'
    b'ICBzdEV2dDpzb2Z0d2FyZUFnZW50PSJHaW1wIDIuMTAgKE1hYyBPUykiCiAgICAgIHN0RXZ0'
    b'OndoZW49IjIwMjEtMDEtMjNUMTU6Mjg6MTctMDY6MDAiLz4KICAgIDwvcmRmOlNlcT4KICAg'
    b'PC94bXBNTTpIaXN0b3J5PgogICA8cGx1czpJbWFnZVN1cHBsaWVyPgogICAgPHJkZjpTZXEv'
    b'PgogICA8L3BsdXM6SW1hZ2VTdXBwbGllcj4KICAgPHBsdXM6SW1hZ2VDcmVhdG9yPgogICAg'
    b'PHJkZjpTZXEvPgogICA8L3BsdXM6SW1hZ2VDcmVhdG9yPgogICA8cGx1czpDb3B5cmlnaHRP'
    b'd25lcj4KICAgIDxyZGY6U2VxLz4KICAgPC9wbHVzOkNvcHlyaWdodE93bmVyPgogICA8cGx1'
    b'czpMaWNlbnNvcj4KICAgIDxyZGY6U2VxLz4KICAgPC9wbHVzOkxpY2Vuc29yPgogIDwvcmRm'
    b'OkRlc2NyaXB0aW9uPgogPC9yZGY6UkRGPgo8L3g6eG1wbWV0YT4KICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgIAogICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgCiAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAKICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgIAogICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgCiAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAKICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgIAogICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgCiAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAKICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgIAogICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgCiAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAKICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'IAogICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgCiAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAKICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgIAogICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgCiAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAKICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgIAogICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgCiAgICAgICAgICAgICAgICAgICAgICAgICAgIAo8P3hwYWNrZXQgZW5kPSJ3Ij8+'
    b'eAgi0AAAAAZiS0dEAP8A/wD/oL2nkwAAAAlwSFlzAAALEwAACxMBAJqcGAAAAAd0SU1FB+UB'
    b'FxUcEezZejMAAAC6SURBVFjD7VdJDoAgDKzEK9z5DU/3N97lAXgR4xKwxRZMpAkXD53pTJcI'
    b'8PcYEt+DYO5TqE8rMM0LOaGzhqSCmAIb+dDUAgwJ8R54IlGlCXMkRinQSzNyWKAz71YtOpgU'
    b'0ADgkyRyaoy45MdkQ85ncigKOIfnRAX8TiRWnqrUWQPOGrISinnUuC2QJ9H8GnYCrARKRlG1'
    b'BGcjEMFLpgB5C/yWXNdexbJLqOAa+ldgfQ/U/jNC4TVXoMcKbII8fN8MSdgAAAAASUVORK5C'
    b'YII=')

