#----------------------------------------------------------------------
# This file was generated by /Users/humberto.a.sanchez.ii/PycharmProjects/PyUt/venv-pyenv-3.9.0/bin/img2py
#
from wx.lib.embeddedimage import PyEmbeddedImage

embeddedImage = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAADGHpUWHRSYXcgcHJvZmlsZSB0'
    b'eXBlIGV4aWYAAHja7ZZbkuMgDEX/WcUswZIQEsvBPKpmB7P8uWDH00l3V/Wr5ism5iHji9BR'
    b'SEL/83uEX7h4cw5RzVNOacMVc8xc0PHtuMqqaYurXhefjzC+s4frAcMkaOUYejrn3+x0CRxN'
    b'QU9fCHk9H+z3D3I89f1B6FxZpkez306hfAoJHw/oFCjHtraU3V5uYe9H22478eMOs4p+7/ar'
    b'sSF6TbGOMHch2VCz8OGAzJuCFHQINYvwYS4YO+oodoohIG/FaXvhVXikcvXoHfsDFEmHPcBw'
    b'H8x0tW/aSR/sp2BYIX6xstRr5Tt7/7fEXZDnPUbzMEY/dldiQkjTuanbVlYPE3eEXNZrCcVw'
    b'K/q2SkbxgOytQN62uu0olTIxsAyK1KjQoL7aShUuRu5saJkrQE2bi3HmKlsAoTgLDTbJ0sCL'
    b'pQKvwMqXL7TWzWu5So6FG2EmE8RopkKY1U+Ud4XGmClPtPkVK/jFMwnhxiQ3a8wCEBq3PNIV'
    b'4Ft5vCZXAUFdYXZssGz7IbErnbk180gWaMFERXt818jaKYAQYW2FMyQgsCUSpUSbMRsR4ujg'
    b'UyDkLJF3ICBVbvCSo0gCHOe5Nt4xWnNZ+TDjzAIIlSQGNFkKWEUcbMgfi44cKioaVTWpqWvW'
    b'kiTFpCklS/PwKyYWTS2ZmVu24uLR1ZObe/DsJXMWHI6aU7bsOedSsGiBcsHbBRNK2XmXPe66'
    b'p9123/NeKtKnxqo1Vaseaq6lcZOGc6KlZs1bbqVTRyr12LWnbt177mUg1YaMOHSkYcNHHuWi'
    b'RuHA+qp8nBrdqPEiNSfaRQ2vmt0kaB4nOpmBGEcCcZsEkNA8mW1OMXKY6CazLeNkE2V4qRNO'
    b'o0kMBGMn1kEXu3/k7riFGL/FjW/kwkT3E+TCRPcOudfc3qDW5q9N3SQsQvNrOIO6Cb5+mFTY'
    b'8cFv0sfb8NkXnkJPoafQR9r5D3B2pY+xRuF++PVR+BkZbO3LMmt/Y9wehUfDV8fhuwL/y6PP'
    b'J0T4fio+hZ5CT6FXrQz8M8rhLyR56srbTAdGAAABhGlDQ1BJQ0MgcHJvZmlsZQAAeJx9kT1I'
    b'w1AUhU9TRZGKiB2KOGSoTlZERRy1CkWoEGqFVh1MXvoHTRqSFBdHwbXg4M9i1cHFWVcHV0EQ'
    b'/AFxc3NSdJES70sKLWK88Hgf591zeO8+QKiXmWZ1jAOabpupRFzMZFfFrlcEEIGAfozJzDLm'
    b'JCkJ3/q6p26quxjP8u/7s3rVnMWAgEg8ywzTJt4gnt60Dc77xGFWlFXic+JRky5I/Mh1xeM3'
    b'zgWXBZ4ZNtOpeeIwsVhoY6WNWdHUiKeIo6qmU76Q8VjlvMVZK1dZ8578haGcvrLMdVpDSGAR'
    b'S5AgQkEVJZRhI0a7ToqFFJ3HffyDrl8il0KuEhg5FlCBBtn1g//B79la+ckJLykUBzpfHOdj'
    b'GOjaBRo1x/k+dpzGCRB8Bq70lr9SB2Y+Sa+1tOgR0LcNXFy3NGUPuNwBIk+GbMquFKQl5PPA'
    b'+xl9UxYYuAV61ry5Nc9x+gCkaVbJG+DgEBgpUPa6z7u72+f2b09zfj9NWnKYMAC+RAAAD6Bp'
    b'VFh0WE1MOmNvbS5hZG9iZS54bXAAAAAAADw/eHBhY2tldCBiZWdpbj0i77u/IiBpZD0iVzVN'
    b'ME1wQ2VoaUh6cmVTek5UY3prYzlkIj8+Cjx4OnhtcG1ldGEgeG1sbnM6eD0iYWRvYmU6bnM6'
    b'bWV0YS8iIHg6eG1wdGs9IlhNUCBDb3JlIDQuNC4wLUV4aXYyIj4KIDxyZGY6UkRGIHhtbG5z'
    b'OnJkZj0iaHR0cDovL3d3dy53My5vcmcvMTk5OS8wMi8yMi1yZGYtc3ludGF4LW5zIyI+CiAg'
    b'PHJkZjpEZXNjcmlwdGlvbiByZGY6YWJvdXQ9IiIKICAgIHhtbG5zOmlwdGNFeHQ9Imh0dHA6'
    b'Ly9pcHRjLm9yZy9zdGQvSXB0YzR4bXBFeHQvMjAwOC0wMi0yOS8iCiAgICB4bWxuczp4bXBN'
    b'TT0iaHR0cDovL25zLmFkb2JlLmNvbS94YXAvMS4wL21tLyIKICAgIHhtbG5zOnN0RXZ0PSJo'
    b'dHRwOi8vbnMuYWRvYmUuY29tL3hhcC8xLjAvc1R5cGUvUmVzb3VyY2VFdmVudCMiCiAgICB4'
    b'bWxuczpwbHVzPSJodHRwOi8vbnMudXNlcGx1cy5vcmcvbGRmL3htcC8xLjAvIgogICAgeG1s'
    b'bnM6R0lNUD0iaHR0cDovL3d3dy5naW1wLm9yZy94bXAvIgogICAgeG1sbnM6ZGM9Imh0dHA6'
    b'Ly9wdXJsLm9yZy9kYy9lbGVtZW50cy8xLjEvIgogICAgeG1sbnM6dGlmZj0iaHR0cDovL25z'
    b'LmFkb2JlLmNvbS90aWZmLzEuMC8iCiAgICB4bWxuczp4bXA9Imh0dHA6Ly9ucy5hZG9iZS5j'
    b'b20veGFwLzEuMC8iCiAgIHhtcE1NOkRvY3VtZW50SUQ9ImdpbXA6ZG9jaWQ6Z2ltcDoxMDc2'
    b'ODViYy04YmI5LTRmZDktOGQ3YS03NmZhYjUwMTBhM2QiCiAgIHhtcE1NOkluc3RhbmNlSUQ9'
    b'InhtcC5paWQ6YzRhYmMxOGItMTk2Yy00YzFkLWI0OTktZWRhY2U5MmM3ZjhhIgogICB4bXBN'
    b'TTpPcmlnaW5hbERvY3VtZW50SUQ9InhtcC5kaWQ6NmQ3MGYzZjktMTJkMi00ZjBlLTg1Yzgt'
    b'ZTY4YzAxMjI1Y2I0IgogICBHSU1QOkFQST0iMi4wIgogICBHSU1QOlBsYXRmb3JtPSJNYWMg'
    b'T1MiCiAgIEdJTVA6VGltZVN0YW1wPSIxNjExNDU0NzI5NjcwNDgzIgogICBHSU1QOlZlcnNp'
    b'b249IjIuMTAuMjIiCiAgIGRjOkZvcm1hdD0iaW1hZ2UvcG5nIgogICB0aWZmOk9yaWVudGF0'
    b'aW9uPSIxIgogICB4bXA6Q3JlYXRvclRvb2w9IkdJTVAgMi4xMCI+CiAgIDxpcHRjRXh0Okxv'
    b'Y2F0aW9uQ3JlYXRlZD4KICAgIDxyZGY6QmFnLz4KICAgPC9pcHRjRXh0OkxvY2F0aW9uQ3Jl'
    b'YXRlZD4KICAgPGlwdGNFeHQ6TG9jYXRpb25TaG93bj4KICAgIDxyZGY6QmFnLz4KICAgPC9p'
    b'cHRjRXh0OkxvY2F0aW9uU2hvd24+CiAgIDxpcHRjRXh0OkFydHdvcmtPck9iamVjdD4KICAg'
    b'IDxyZGY6QmFnLz4KICAgPC9pcHRjRXh0OkFydHdvcmtPck9iamVjdD4KICAgPGlwdGNFeHQ6'
    b'UmVnaXN0cnlJZD4KICAgIDxyZGY6QmFnLz4KICAgPC9pcHRjRXh0OlJlZ2lzdHJ5SWQ+CiAg'
    b'IDx4bXBNTTpIaXN0b3J5PgogICAgPHJkZjpTZXE+CiAgICAgPHJkZjpsaQogICAgICBzdEV2'
    b'dDphY3Rpb249InNhdmVkIgogICAgICBzdEV2dDpjaGFuZ2VkPSIvIgogICAgICBzdEV2dDpp'
    b'bnN0YW5jZUlEPSJ4bXAuaWlkOjJiODMwOGNlLTIyMWUtNDk0My1hNzY0LTQ5NjczNGFmNzM5'
    b'MiIKICAgICAgc3RFdnQ6c29mdHdhcmVBZ2VudD0iR2ltcCAyLjEwIChNYWMgT1MpIgogICAg'
    b'ICBzdEV2dDp3aGVuPSIyMDIxLTAxLTIzVDIwOjE4OjQ5LTA2OjAwIi8+CiAgICA8L3JkZjpT'
    b'ZXE+CiAgIDwveG1wTU06SGlzdG9yeT4KICAgPHBsdXM6SW1hZ2VTdXBwbGllcj4KICAgIDxy'
    b'ZGY6U2VxLz4KICAgPC9wbHVzOkltYWdlU3VwcGxpZXI+CiAgIDxwbHVzOkltYWdlQ3JlYXRv'
    b'cj4KICAgIDxyZGY6U2VxLz4KICAgPC9wbHVzOkltYWdlQ3JlYXRvcj4KICAgPHBsdXM6Q29w'
    b'eXJpZ2h0T3duZXI+CiAgICA8cmRmOlNlcS8+CiAgIDwvcGx1czpDb3B5cmlnaHRPd25lcj4K'
    b'ICAgPHBsdXM6TGljZW5zb3I+CiAgICA8cmRmOlNlcS8+CiAgIDwvcGx1czpMaWNlbnNvcj4K'
    b'ICA8L3JkZjpEZXNjcmlwdGlvbj4KIDwvcmRmOlJERj4KPC94OnhtcG1ldGE+CiAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAKICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgIAogICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgCiAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAKICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgIAogICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgCiAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAKICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgIAogICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgCiAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAKICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgIAogICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgCiAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAKICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'IAogICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgCiAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAKICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgIAogICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgCiAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAKICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgIAogICAgICAgICAgICAgICAgICAgICAgICAgICAKPD94cGFja2V0IGVu'
    b'ZD0idyI/Pk+nw7YAAAAGYktHRAD/AP8A/6C9p5MAAAAJcEhZcwAACxMAAAsTAQCanBgAAAAH'
    b'dElNRQflARgCEjEIPtLWAAAAJklEQVRYw+3RQREAIAzAsIJ/z0PGHiQKetcCAJadajYDrgcA'
    b'8L0HrbwBA/7oszMAAAAASUVORK5CYII=')

