#----------------------------------------------------------------------
# This file was generated by /Users/humberto.a.sanchez.ii/PycharmProjects/PyUt/venv-pyenv-3.9.0/bin/img2py
#
from wx.lib.embeddedimage import PyEmbeddedImage

embeddedImage = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAAK3RFWHRDcmVhdGlvbiBUaW1l'
    b'AE1vIDE3IEZlYiAyMDAzIDIzOjQ5OjQ2ICswMTAwscrZowAAAAd0SU1FB9MCERcmCB53GVgA'
    b'AAAJcEhZcwAACvAAAArwAUKsNJgAAAAEZ0FNQQAAsY8L/GEFAAADBElEQVR42uVXS2sUQRCu'
    b'6VnjOWdB8ZA/4U+IRy+CwUSzzqIH2YDoKScFL0I8JThGEzTB10klexC8iOALwUMgGHPxoIuL'
    b'rksSEtfd2bJ7pmu2el4b93EQCybdWzPMV/V9VdUZgP/dLP5j7nVjRi5FRASQV7i2WhDzaX/o'
    b'A0i/x/yV1dXr16ZHp2KRKPDZV79xUNbwEN+vV3HheRkvXC7NEG6ONi3PK547sh+26gCfqgDf'
    b'd+RNyU9OANgiWP299Antt/TKfwu6IFh9mrXv0IFhCfgTyiMjRemeMgJAz/NXAh+KAKsX2Cwg'
    b'AuXAOb3yQADM/eGDw4DvKhBjwNcM2uAr990QyM9G/jl+0oFHd5lfg42fcmB50TXALMpeM5A/'
    b'40AUKypB4LCCDKPgttVmhGdps+cJLFz1XjCpOFaiBETrsTEnpJzXwZjM1t9bphSTecdgRkRk'
    b'4IZJAbQ0LQT0eNkNM6cXcVbGJwPaBWWpGVDPFwoOuK5rgDpOW4JkBnQARFUaOPmGbDNLm+ne'
    b'0fTcSJVAvUwVHLGxz9ZSWGZnqKxyIplqnnEMP6kIKQDSXVU7vVzRfU/THV6MIQUWpTwrCC6B'
    b'iEYlol0g2kMlCbwby25DDXxiIpCABtLpvBObinulPBZAVhHSeH1wxzX6nJgpSKDb827ii7kU'
    b'UVnSuiAmAR+vthWv9GjmvUoQ2pWlNf/U2viB+LmGWN5ErGwj1nYRt+uI9Sai1+rPyXjx6rOw'
    b'DxPbUGWrhgyn/qwcLvM304fL31iiBOS09Knm7wHak67Lik+UIKsISe8J2ftq2qkhpNZeMo4F'
    b'kDWI6KRbWnBD+jsVXlLFZ50FmDmIWBBWD8Mmy3gNhDY9+8av0G9biNUdxM1fiLuN/lU+t/OX'
    b'HqZ3AdniLdegP23ep9GcZdipC8QA6Y9KYDCgjmnqAvU/XHTm960L0orww0bNeHAQDKytV4w2'
    b'bEvQbJZevPwIX77WunrxXsGfPnmrJCiRz8hRzugVGcio8RmW8lmW9cmWeQ+gdGMuf3RgWf5z'
    b'9gcwQL7Lcp8odwAAAABJRU5ErkJggg==')

