#----------------------------------------------------------------------
# This file was generated by /Users/humberto.a.sanchez.ii/PycharmProjects/PyUt/venv-pyenv-3.9.0/bin/img2py
#
from wx.lib.embeddedimage import PyEmbeddedImage

embeddedImage = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAADUXpUWHRSYXcgcHJvZmlsZSB0'
    b'eXBlIGV4aWYAAHja7ZZtstsqDIb/s4ouAUkIxHIwmJm7gy6/L/5qnI/eJCedTmdqjgHLQhJ6'
    b'ZHLc/P2/7r7hYs/mgiaLOUaPK+SQuWBifr3K0pMPS789+H1ykrvjBUMkGGV9tLjp73LyJ0tU'
    b'MNMLQ1a3F9P5RQ6bfbsyxOsgI6Ixb5uhvBkSXl/QZqCs2/IxW7rcwjSvY9t3YuvtRhfsHPbN'
    b'c0L2msKPMM9C4tGz8BqAjJucFEwIPUniMRPMVWyR7MaQkHt58hdRuWsqx4weyK+gSFzlDoJz'
    b'MuMx3pWTXsk3g25J8YVnqYfnk7zkw8UpyePuvZnrfV53V0JESuO2qSM7YwLFCSmXZVlES7gV'
    b'87S0jGYO1VuBvPnqJ7RKmRhZ7hSoUaFO8zJWqggx8MxAwswVoIbMgChzFe/AJoxGnZNkaeDF'
    b'UoFXIOUjFlr85sVdJYPjRtBkgjEapeBG94n20FDvo+SJvB25Qlw8ihBhDHKjhxaAUN/rSJcE'
    b'7+36GlwFBHVJs2GDxU+riUlpq61RR7KAFigqxvVbo9Q2A0gRfCuCIQEBH0mUIvnEnIiQRwOf'
    b'AkPGEngCAlLlhig5iETAMR6+sSbRosvKqxhnFkCoRElAk6WAVcDBhvpJwVBDRUWDqkZNapq1'
    b'RIkhaowxxXH4lSQpJE0xpWQpp2JiwdSiJTNn2UrmLDgcNcecsuWcS4HTAssFqwsUSpl4kilM'
    b'OsUpTTblqVSUTw1Va6ypmqu5lsZNGs6JFltq1nIrM80opTnMOsc5zTbnuXSUWpceuvbYU7ee'
    b'ezmokVux3rTnqdFOjRdSQzEd1LA0pd0EjeNEBzMQ40AgngYBFDQPZt4oBHYD3WDmM+OrUEaU'
    b'OuA0GsRAMMzE2ulg95PciZsL4UvceCfnBrpPkHMD3QNyt9zuUGvj16Z6cQuh8RmOpHrB5wel'
    b'woY/HIvPj+7VBX+5IZlft+WOtb2/Gc/q1l3J3jbn7mzjCXO3q9xXoniY7Oeiu9C6eOs+gf6u'
    b'ofv+7kv/aEH+LxL3mXhOht6rKP9xau9S+ii1S3ful5X7QlTuC1Gc3LjX1N/M0Svm3FubuTO6'
    b'B2tfPqN+3zHyz9ATR23HvyoZv5w/APjexnblioeKAAABhmlDQ1BJQ0MgcHJvZmlsZQAAeJx9'
    b'kT1Iw1AUhU9TpSIVkXYQcchQnSyIioqTVqEIFUKt0KqDyUv/oElDkuLiKLgWHPxZrDq4OOvq'
    b'4CoIgj8gbm5Oii5S4n1JoUWsFx7v47x7Du/dBwi1EtOsjlFA020zGY+J6cyqGHiFD30IYQoz'
    b'MrOMOUlKoG193VM31V2UZ7Xv+7N61KzFAJ9IPMsM0ybeIJ7ctA3O+8RhVpBV4nPiEZMuSPzI'
    b'dcXjN855lwWeGTZTyXniMLGYb2GlhVnB1IgniCOqplO+kPZY5bzFWStVWOOe/IXBrL6yzHVa'
    b'g4hjEUuQIEJBBUWUYCNKu06KhSSdx9r4B1y/RC6FXEUwciygDA2y6wf/g9+ztXLjY15SMAZ0'
    b'vjjOxxAQ2AXqVcf5Pnac+gngfwau9Ka/XAOmP0mvNrXIEdC7DVxcNzVlD7jcAfqfDNmUXclP'
    b'S8jlgPcz+qYMELoFute8uTXOcfoApGhWiRvg4BAYzlP2ept3d7XO7d+exvx+AOMMctRM/HtO'
    b'AAAPoGlUWHRYTUw6Y29tLmFkb2JlLnhtcAAAAAAAPD94cGFja2V0IGJlZ2luPSLvu78iIGlk'
    b'PSJXNU0wTXBDZWhpSHpyZVN6TlRjemtjOWQiPz4KPHg6eG1wbWV0YSB4bWxuczp4PSJhZG9i'
    b'ZTpuczptZXRhLyIgeDp4bXB0az0iWE1QIENvcmUgNC40LjAtRXhpdjIiPgogPHJkZjpSREYg'
    b'eG1sbnM6cmRmPSJodHRwOi8vd3d3LnczLm9yZy8xOTk5LzAyLzIyLXJkZi1zeW50YXgtbnMj'
    b'Ij4KICA8cmRmOkRlc2NyaXB0aW9uIHJkZjphYm91dD0iIgogICAgeG1sbnM6aXB0Y0V4dD0i'
    b'aHR0cDovL2lwdGMub3JnL3N0ZC9JcHRjNHhtcEV4dC8yMDA4LTAyLTI5LyIKICAgIHhtbG5z'
    b'OnhtcE1NPSJodHRwOi8vbnMuYWRvYmUuY29tL3hhcC8xLjAvbW0vIgogICAgeG1sbnM6c3RF'
    b'dnQ9Imh0dHA6Ly9ucy5hZG9iZS5jb20veGFwLzEuMC9zVHlwZS9SZXNvdXJjZUV2ZW50IyIK'
    b'ICAgIHhtbG5zOnBsdXM9Imh0dHA6Ly9ucy51c2VwbHVzLm9yZy9sZGYveG1wLzEuMC8iCiAg'
    b'ICB4bWxuczpHSU1QPSJodHRwOi8vd3d3LmdpbXAub3JnL3htcC8iCiAgICB4bWxuczpkYz0i'
    b'aHR0cDovL3B1cmwub3JnL2RjL2VsZW1lbnRzLzEuMS8iCiAgICB4bWxuczp0aWZmPSJodHRw'
    b'Oi8vbnMuYWRvYmUuY29tL3RpZmYvMS4wLyIKICAgIHhtbG5zOnhtcD0iaHR0cDovL25zLmFk'
    b'b2JlLmNvbS94YXAvMS4wLyIKICAgeG1wTU06RG9jdW1lbnRJRD0iZ2ltcDpkb2NpZDpnaW1w'
    b'OmNlZTBmODhhLTE3NWUtNDY3MC04YzU5LWIzMDIzOTMyMjUxNCIKICAgeG1wTU06SW5zdGFu'
    b'Y2VJRD0ieG1wLmlpZDpmMTRkNjAyYi1mMTlmLTQ3MTktYjE3NC01ZWNjOTQ3YTYxNjAiCiAg'
    b'IHhtcE1NOk9yaWdpbmFsRG9jdW1lbnRJRD0ieG1wLmRpZDpjMzFkOGE4NS0yMjY3LTQ5ODEt'
    b'YWE3OC02YWFlYmM1MzhiNDAiCiAgIEdJTVA6QVBJPSIyLjAiCiAgIEdJTVA6UGxhdGZvcm09'
    b'Ik1hYyBPUyIKICAgR0lNUDpUaW1lU3RhbXA9IjE2MTA5MTM0OTMyMjQxODIiCiAgIEdJTVA6'
    b'VmVyc2lvbj0iMi4xMC4yMiIKICAgZGM6Rm9ybWF0PSJpbWFnZS9wbmciCiAgIHRpZmY6T3Jp'
    b'ZW50YXRpb249IjEiCiAgIHhtcDpDcmVhdG9yVG9vbD0iR0lNUCAyLjEwIj4KICAgPGlwdGNF'
    b'eHQ6TG9jYXRpb25DcmVhdGVkPgogICAgPHJkZjpCYWcvPgogICA8L2lwdGNFeHQ6TG9jYXRp'
    b'b25DcmVhdGVkPgogICA8aXB0Y0V4dDpMb2NhdGlvblNob3duPgogICAgPHJkZjpCYWcvPgog'
    b'ICA8L2lwdGNFeHQ6TG9jYXRpb25TaG93bj4KICAgPGlwdGNFeHQ6QXJ0d29ya09yT2JqZWN0'
    b'PgogICAgPHJkZjpCYWcvPgogICA8L2lwdGNFeHQ6QXJ0d29ya09yT2JqZWN0PgogICA8aXB0'
    b'Y0V4dDpSZWdpc3RyeUlkPgogICAgPHJkZjpCYWcvPgogICA8L2lwdGNFeHQ6UmVnaXN0cnlJ'
    b'ZD4KICAgPHhtcE1NOkhpc3Rvcnk+CiAgICA8cmRmOlNlcT4KICAgICA8cmRmOmxpCiAgICAg'
    b'IHN0RXZ0OmFjdGlvbj0ic2F2ZWQiCiAgICAgIHN0RXZ0OmNoYW5nZWQ9Ii8iCiAgICAgIHN0'
    b'RXZ0Omluc3RhbmNlSUQ9InhtcC5paWQ6ZjllNjVlN2UtNTNjOS00MmVkLThiZTMtN2JmNTZi'
    b'Y2Y4NTU4IgogICAgICBzdEV2dDpzb2Z0d2FyZUFnZW50PSJHaW1wIDIuMTAgKE1hYyBPUyki'
    b'CiAgICAgIHN0RXZ0OndoZW49IjIwMjEtMDEtMTdUMTM6NTg6MTMtMDY6MDAiLz4KICAgIDwv'
    b'cmRmOlNlcT4KICAgPC94bXBNTTpIaXN0b3J5PgogICA8cGx1czpJbWFnZVN1cHBsaWVyPgog'
    b'ICAgPHJkZjpTZXEvPgogICA8L3BsdXM6SW1hZ2VTdXBwbGllcj4KICAgPHBsdXM6SW1hZ2VD'
    b'cmVhdG9yPgogICAgPHJkZjpTZXEvPgogICA8L3BsdXM6SW1hZ2VDcmVhdG9yPgogICA8cGx1'
    b'czpDb3B5cmlnaHRPd25lcj4KICAgIDxyZGY6U2VxLz4KICAgPC9wbHVzOkNvcHlyaWdodE93'
    b'bmVyPgogICA8cGx1czpMaWNlbnNvcj4KICAgIDxyZGY6U2VxLz4KICAgPC9wbHVzOkxpY2Vu'
    b'c29yPgogIDwvcmRmOkRlc2NyaXB0aW9uPgogPC9yZGY6UkRGPgo8L3g6eG1wbWV0YT4KICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgIAogICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgCiAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAKICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgIAogICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgCiAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAKICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'IAogICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgCiAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAKICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgIAogICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgCiAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAKICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgIAogICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgCiAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAK'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgIAogICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgCiAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAKICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgIAogICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgCiAgICAgICAgICAgICAgICAgICAgICAgICAgIAo8P3hwYWNr'
    b'ZXQgZW5kPSJ3Ij8+5VxkAAAAAAZiS0dEAP8A/wD/oL2nkwAAAAlwSFlzAAALEwAACxMBAJqc'
    b'GAAAAAd0SU1FB+UBERM6DRrghjYAAAA/SURBVDjLY2AYaMCIRew/iepRNP4nYCFONcRoxqv+'
    b'Pxne/0+JZrheJkpjgYla0Ul2GDCRach/qqUDqqbEIQoAd9MV9YEt+iEAAAAASUVORK5CYII=')

