#----------------------------------------------------------------------
# This file was generated by /Users/humberto.a.sanchez.ii/PycharmProjects/PyUt/venv-pyenv-3.9.0/bin/img2py
#
from wx.lib.embeddedimage import PyEmbeddedImage

embeddedImage = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAGrXpUWHRSYXcgcHJvZmlsZSB0'
    b'eXBlIGV4aWYAAHjarVdZlisrDvxnFb0EJiGxHMZzege9/A4B6Zt2Ta73rrOcqEhSIEVosBn/'
    b'++80/8HHp5xMJBaMyeITc8y+QBC7P2XdnY3rvj7+PML/T/Pm8cBjKmAM+19JZ/017x4K9lAg'
    b'0U2RtPOgPj/I8eiXF0Vn56AnUrkfRfkoCn4/cEdB2WbZlIXvJtSxx35ZIvtr9Bbl+dgf/md4'
    b'rxP2Cd6P4ILF3Qe/DxD060woEBzuPuAJpLRkj7sLl6lwyGd+srdTmVdUHpL7Yv4FlJD2vMHE'
    b'szPTY/x03tHL/FFolotvO4f22PlpPpLNr+Zc3zm7mDnHtq7EBJemY9RlypKwsEJVWK8lXIwv'
    b'QeZ1ZVxiwN4GyLtttuJqLjsPWKaLrrviphtrbK7hiNEPzxi9bwBK5ySwz74Fa4BN1MtNzyGH'
    b'HgSINcAbMOsfZ3Fr37y2a06wcXdY6R2UOUXZLKj/wvWlojmV8s5ZefgK5/JKQhxDkdM7VgEQ'
    b'Ny8e0XLwdb1+FNcABGm5WWBgsXWrqOQOt5RHYQEdsJAw7lhz3I8CuAh7Ew7jAhCwCYR3yVn2'
    b'np2DHwX4FCgSH6KvgMAR+Y5T+hhCAjjidW+8w26t9eT3NHIWgCAEEwOaHAqwikhs4A9HAYcK'
    b'BYpElIhJKFNJIcVEKSVOmvwKB45MnJhZOHORIFFIkrCIkSwl+xyQHCmnzFlyzqVg0wLNBW8X'
    b'LCil+hpqrFRT5So119JAnxYbtdS4iWm5le576MgTPXXu0nMvww1QacRBIw0eMvIoE1SbYcZJ'
    b'M02eMvMsD9Sc2bB+uN5HzV2o+YWULuQHaniV+VLhNJ2QYgbEfHRAnBUBENorZlZcjN4odIqZ'
    b'zchsgTxOSQpOd4oYEIzDeZrugd0f5J5wMzH+K9z8hZxR6P4Gckah+wK5j7h9glrXatNsMAsh'
    b'DUN1qg0IPywqXvCHmvT+aH77wi8VTbG+jjmP+IYu88OCAG1vncu8eZ5ZOdXh/RaoUI8jNbBm'
    b'v1WTCVnW+0X7he/HKVKWOGLoXpXPUQGvzhczyA0KoTCFPCbKBs/uIqEOJtER9cz+ONJEqiXu'
    b'agTpd82l0bmB3yok8K/k1kXGUYucgVy6ZHsfzeuEjqhmbonUhEvkXutSwpRHyvrwbN7Onm3C'
    b'2dPnDs8hjPqMYbtYvVJQu370nnZL21dmrE4RM317bQkdAQefVecuZV1G+hZ/88QZwLvAzHZG'
    b'UaClbKgQf2Vm1/okniHoZr7u5RO0QJ02+uCc7nFMdFnxF1Yto8x7Vrl0xPiRAjkCimgqIfXl'
    b'jWxS9BcmClOMJbQGAgAI5Mi4LV+7IVN1pK1cuKfQRE9h5A/7c46MpjNlgMgVxCFlJze7hYhO'
    b'8hMCndEc4bFchTWBU13H61Q7hPrETCbXilpgNRLYOIqg7mA4pnDL3I+bW+vx5tg+1I1pCUNa'
    b'mA8/IkfDgd30go2a30TO8uewjzBZgnQawqgos8g9qFSk7Lo37wTkO/Fottle54NmdVoCL18I'
    b'D/XCNanCnjuegh1U0TDCom6UB3DbsCiJd5G0Trrjr5huBzz8WELCnsWh8WSz9ryjvIrl1zB/'
    b'hbK5w4wU2r3mgYQgsXVBq+gDXfAToI5EN3o6pSDiAYKvJhflXwyopxTAQ5TVxWv1ZaSwQjLx'
    b'a6wqiQt+IY2E5JrjzB7wbzsQIIijqpFDrD8cBcUaFEulHQT9qgUnJJfgSu12ZGUVytG/D/xF'
    b'WPNF4FNZlAVBghLW3fwV+3ZXfnKX2fT31c9SJ+J5XvGc5I8v21AHole6is1zLCJBZIMnYRc6'
    b'Wj3MyOJwgkUptMu9HYvi1xRaDDJ/gUJLt/mUQjiK31FbtKyJ0idPDfnth4tDOL/mLgsGGFBg'
    b'MwC2gEchuFSfuNZYnX9AfuoBSibNUrL2NivjOuo2k+bmKxndsb5aBxVaKoCpsEXGvDcaqGto'
    b'Wxoau5+bqe97FPPapBxWjZKQaAhVuLUdREji8BqvZBL09VAkTq0BvXWeRvoAkreKV1YttNxp'
    b'tnaLSlUOMgeGD8IU+JMfgauNFs7DCDrbSiEtHtrMrOqUa835kEF+dpk5Prt74HcuOw4z33R1'
    b'Wl4jjCqMMgNAl18W7JWyBhyfmEF4OSVkX9lciwgj5PCDBDhy1iZph2lH5CCgteNDFdVga0pY'
    b'GE0BysLpRvKnUfCrUqSvmb9RirQSmafesO4Sw89FZS/4Lo4xmn9qyqsF5idT3u2Qzfut9D1z'
    b'fVxg3t7yh/EfK+KJH32gjvk/m2s+2XguEicAAAGFaUNDUElDQyBwcm9maWxlAAB4nH2RO0jD'
    b'UBSG/7ZKRSoO1icOGaqTBVERR61CESqEWqFVB5ObvqBJQ5Li4ii4Fhx8LFYdXJx1dXAVBMEH'
    b'iJubk6KLlHhuUmgR44HL/fjv+X/uPRfw10pMNdvGAVWzjGQ8JqQzq0LwFT70ow+9GJSYqc+J'
    b'YgKe9XVP3VR3UZ7l3fdndSlZkwE+gXiW6YZFvEE8vWnpnPeJw6wgKcTnxGMGXZD4keuyy2+c'
    b'8w77eWbYSCXnicPEQr6F5RZmBUMlniKOKKpG+f60ywrnLc5qqcIa9+QvDGW1lWWu0xpGHItY'
    b'gggBMiooogQLUdo1Ukwk6Tzm4R9y/CK5ZHIVwcixgDJUSI4f/A9+z9bMTU64SaEY0P5i2x8j'
    b'QHAXqFdt+/vYtusnQOAZuNKa/nINmPkkvdrUIkdA9zZwcd3U5D3gcgcYeNIlQ3KkAC1/Lge8'
    b'n9E3ZYCeW6BzzZ1b4xynD0CKZpW4AQ4OgdE8Za97vLujdW7/9jTm9wNSpnKaj6yxkQAAD6Bp'
    b'VFh0WE1MOmNvbS5hZG9iZS54bXAAAAAAADw/eHBhY2tldCBiZWdpbj0i77u/IiBpZD0iVzVN'
    b'ME1wQ2VoaUh6cmVTek5UY3prYzlkIj8+Cjx4OnhtcG1ldGEgeG1sbnM6eD0iYWRvYmU6bnM6'
    b'bWV0YS8iIHg6eG1wdGs9IlhNUCBDb3JlIDQuNC4wLUV4aXYyIj4KIDxyZGY6UkRGIHhtbG5z'
    b'OnJkZj0iaHR0cDovL3d3dy53My5vcmcvMTk5OS8wMi8yMi1yZGYtc3ludGF4LW5zIyI+CiAg'
    b'PHJkZjpEZXNjcmlwdGlvbiByZGY6YWJvdXQ9IiIKICAgIHhtbG5zOmlwdGNFeHQ9Imh0dHA6'
    b'Ly9pcHRjLm9yZy9zdGQvSXB0YzR4bXBFeHQvMjAwOC0wMi0yOS8iCiAgICB4bWxuczp4bXBN'
    b'TT0iaHR0cDovL25zLmFkb2JlLmNvbS94YXAvMS4wL21tLyIKICAgIHhtbG5zOnN0RXZ0PSJo'
    b'dHRwOi8vbnMuYWRvYmUuY29tL3hhcC8xLjAvc1R5cGUvUmVzb3VyY2VFdmVudCMiCiAgICB4'
    b'bWxuczpwbHVzPSJodHRwOi8vbnMudXNlcGx1cy5vcmcvbGRmL3htcC8xLjAvIgogICAgeG1s'
    b'bnM6R0lNUD0iaHR0cDovL3d3dy5naW1wLm9yZy94bXAvIgogICAgeG1sbnM6ZGM9Imh0dHA6'
    b'Ly9wdXJsLm9yZy9kYy9lbGVtZW50cy8xLjEvIgogICAgeG1sbnM6dGlmZj0iaHR0cDovL25z'
    b'LmFkb2JlLmNvbS90aWZmLzEuMC8iCiAgICB4bWxuczp4bXA9Imh0dHA6Ly9ucy5hZG9iZS5j'
    b'b20veGFwLzEuMC8iCiAgIHhtcE1NOkRvY3VtZW50SUQ9ImdpbXA6ZG9jaWQ6Z2ltcDphOGU1'
    b'YmY1NS03OGU4LTQ2N2MtOTJmZS03ZTEwZGY0MDBlMDIiCiAgIHhtcE1NOkluc3RhbmNlSUQ9'
    b'InhtcC5paWQ6MmIwYzM0ZDMtZGIxMi00YjkyLWIxNWUtNWQ5NGM5MTA5NWY1IgogICB4bXBN'
    b'TTpPcmlnaW5hbERvY3VtZW50SUQ9InhtcC5kaWQ6ZmViYjI1YTktODc5NC00ZDlmLTg5Njgt'
    b'YjZhYzk5M2JhY2JlIgogICBHSU1QOkFQST0iMi4wIgogICBHSU1QOlBsYXRmb3JtPSJNYWMg'
    b'T1MiCiAgIEdJTVA6VGltZVN0YW1wPSIxNjExNDQwNTM3Nzk2NTYyIgogICBHSU1QOlZlcnNp'
    b'b249IjIuMTAuMjIiCiAgIGRjOkZvcm1hdD0iaW1hZ2UvcG5nIgogICB0aWZmOk9yaWVudGF0'
    b'aW9uPSIxIgogICB4bXA6Q3JlYXRvclRvb2w9IkdJTVAgMi4xMCI+CiAgIDxpcHRjRXh0Okxv'
    b'Y2F0aW9uQ3JlYXRlZD4KICAgIDxyZGY6QmFnLz4KICAgPC9pcHRjRXh0OkxvY2F0aW9uQ3Jl'
    b'YXRlZD4KICAgPGlwdGNFeHQ6TG9jYXRpb25TaG93bj4KICAgIDxyZGY6QmFnLz4KICAgPC9p'
    b'cHRjRXh0OkxvY2F0aW9uU2hvd24+CiAgIDxpcHRjRXh0OkFydHdvcmtPck9iamVjdD4KICAg'
    b'IDxyZGY6QmFnLz4KICAgPC9pcHRjRXh0OkFydHdvcmtPck9iamVjdD4KICAgPGlwdGNFeHQ6'
    b'UmVnaXN0cnlJZD4KICAgIDxyZGY6QmFnLz4KICAgPC9pcHRjRXh0OlJlZ2lzdHJ5SWQ+CiAg'
    b'IDx4bXBNTTpIaXN0b3J5PgogICAgPHJkZjpTZXE+CiAgICAgPHJkZjpsaQogICAgICBzdEV2'
    b'dDphY3Rpb249InNhdmVkIgogICAgICBzdEV2dDpjaGFuZ2VkPSIvIgogICAgICBzdEV2dDpp'
    b'bnN0YW5jZUlEPSJ4bXAuaWlkOjkyYmI0OWEwLWFlZWEtNGEzMy05MzllLWEzYWUxNjM5YjZk'
    b'YiIKICAgICAgc3RFdnQ6c29mdHdhcmVBZ2VudD0iR2ltcCAyLjEwIChNYWMgT1MpIgogICAg'
    b'ICBzdEV2dDp3aGVuPSIyMDIxLTAxLTIzVDE2OjIyOjE3LTA2OjAwIi8+CiAgICA8L3JkZjpT'
    b'ZXE+CiAgIDwveG1wTU06SGlzdG9yeT4KICAgPHBsdXM6SW1hZ2VTdXBwbGllcj4KICAgIDxy'
    b'ZGY6U2VxLz4KICAgPC9wbHVzOkltYWdlU3VwcGxpZXI+CiAgIDxwbHVzOkltYWdlQ3JlYXRv'
    b'cj4KICAgIDxyZGY6U2VxLz4KICAgPC9wbHVzOkltYWdlQ3JlYXRvcj4KICAgPHBsdXM6Q29w'
    b'eXJpZ2h0T3duZXI+CiAgICA8cmRmOlNlcS8+CiAgIDwvcGx1czpDb3B5cmlnaHRPd25lcj4K'
    b'ICAgPHBsdXM6TGljZW5zb3I+CiAgICA8cmRmOlNlcS8+CiAgIDwvcGx1czpMaWNlbnNvcj4K'
    b'ICA8L3JkZjpEZXNjcmlwdGlvbj4KIDwvcmRmOlJERj4KPC94OnhtcG1ldGE+CiAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAKICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgIAogICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgCiAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAKICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgIAogICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgCiAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAKICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgIAogICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgCiAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAKICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgIAogICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgCiAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAKICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'IAogICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgCiAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAKICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgIAogICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgCiAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAKICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgIAogICAgICAgICAgICAgICAgICAgICAgICAgICAKPD94cGFja2V0IGVu'
    b'ZD0idyI/Ps/VMmAAAAAGYktHRAD/AP8A/6C9p5MAAAAJcEhZcwAACxMAAAsTAQCanBgAAAAH'
    b'dElNRQflARcWFhEUcCzgAAAA6UlEQVRYw+1XSw6EIAwtxi3uuQ1H5zTj3h6AWTiaIJ8p2ILJ'
    b'TBM3xrSv79NEgF8vlXnvBXsHNT2aAbdu1Q2tWapYEGPgA94PlYACQtwD30B0MWEJxCw19GJG'
    b'Dgl04Ym2JRcTAxoAMAuixMZMa340UhmNfQSCWtPd4bnvmSRAANDn8H1T3mrwALJtz3wHUI4B'
    b't3qwRkU+SEeuzoxkBlL6W7OQD84NBvDU9woinQwc5QHBFIQxxITrdTMAZgZQggEN7rUlNQ89'
    b'gYIMKC1yAypSsIM4mOAY3HaKAyawXwo4B/b8MyLNG36I/vUGQnpI8C4+/nkAAAAASUVORK5C'
    b'YII=')

