#----------------------------------------------------------------------
# This file was generated by /Users/humberto.a.sanchez.ii/PycharmProjects/PyUt/venv-pyenv-3.9.0/bin/img2py
#
from wx.lib.embeddedimage import PyEmbeddedImage

embeddedImage = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAADbnpUWHRSYXcgcHJvZmlsZSB0'
    b'eXBlIGV4aWYAAHja7ZZbdtwgDIbfWUWXYEkIxHIwmHO6gy6/P2C745lJO0nT05eYmIsASeiT'
    b'mbjtx/fmvuFhWsx5jRZSCAsen3zijI4t88mjpsWPejy8T2F8kbtzgiEStDKHFvb1h5xOBbPJ'
    b'6OmNIiv7xHqdSH7Xb3eKdsvSPer9uitKuyLhOUG7gjyPtYRk8fYI6zbbepzE5ut65e3q9sM4'
    b'InpVYUeYNyFZULPwdED6S04yOoSaBTPoJfQVoyxeDk8QkGdxWm68cvdUzh69Ib+DImHKHQTX'
    b'YIazfSonvZPvCt0I8Y1lKafli7zl08QlyP1trZprbZunyz4gpGE/1HGU0cPCFSGXsS2gRLyK'
    b'fhwloZhD9hYgr0tZVpRCiRhYGnmqlKnRNtpCBS563jiiZS4A1WUmkRMXWRw4+V6ocQSxKgZi'
    b'BXgFUj59oWE3DXOFDIYrYSUTlFFPBderzyhvKmqtpzzhuz5jBb+4JyHc6OR6jVUAQu3IIx0B'
    b'Psr907kKCOoIs+GAeVmnilVpz62eRzJACxYq2vmtUay7AoQIthXOkIDAEkiUAi2RORIhjgY+'
    b'GYqMxfMKBKTKFV6yFwmAY9xtY0+ksZaVpxh3FkCoBIlAg08KrDwuNuRP9IYcyirqVTVoVNOk'
    b'OUjwQUMIMfTLL0eJPmoMMUaLKWYT86YWLJo5S5YTJ8HlqCmkmCyllDOMZmjO2J2xIOeVV1n9'
    b'qmtY42prWnNB+hRftIQSi7mSSq5cpeKeqKHGajXVvNGGVNr8plvY4mZb2nJDqjVpvmkLLTZr'
    b'qeWTGrmJ9aG8To0OajxI9YXxpIatMR4qqF8n2pmBGHsC8dgJIKG5M1uMvGfX0XVmS8LNJsrw'
    b'UjucSp0YCPqNWBud7H6Ru3Bz3v8VNz7IuY7uM8i5ju4Nco/cnlCr/demLOIGof4Z9qAugs8P'
    b'izIb/vCb9Hrr3rvhS9GXov+mSPBrntvatv7f1RQ0ZP16iG93uL/35SVFV5+mF0MGt1o73OxT'
    b'7hXHxXKXi85V5dnI/W7yPSP3ro0Px3yI0fNz97W52TKDtg6dfa5rvR+5302+Z+Q+sPHp8dwF'
    b'+YXfONNDLD6YR6/nl7t4MtbdpN0MN/9Djy6eDePuI9afte5zLpEvRV+K/pi9Df9OJfcTJj8D'
    b'ywWmHkEAAAGEaUNDUElDQyBwcm9maWxlAAB4nH2RO0jDUBSG/6ZKRSoOZijikKE6WRAr4qhV'
    b'KEKFUCu06mBy0xc0aUhSXBwF14KDj8Wqg4uzrg6ugiD4AHFzc1J0kRLPTQotYj1wuB//Pf/h'
    b'3HMBoVFhut0zAeiGY6WTCSmbW5VCrwggQhmHqDDbnJPlFLrG1z1VUtzFeK/udX/GgJa3GRCQ'
    b'iGeZaTnEG8TTm47JeZ9YZCVFIz4nHrdoQOJHrqs+v3EueizwnqKVSc8Ti8RSsYPVDmYlSyee'
    b'Io5qukH9hazPGuctznqlxlpz8heG88bKMtcpR5DEIpYgQ4KKGsqowEGMToMUG2m6T3TxD3t+'
    b'mVwqucpg5FhAFToUzw/+B793axfik36ncALofXHdj1EgtAs06677fey6zRMg+AxcGW1/tQHM'
    b'fJJeb2vRI2BwG7i4bmvqHnC5A0SeTMVSPClIKRQKwPsZfVMOGLoF+tf8vbXucfoAZGhXqRvg'
    b'4BAYK1Lv9S7v7uvc2781rf39AF8Fcp9XazAmAAAPoGlUWHRYTUw6Y29tLmFkb2JlLnhtcAAA'
    b'AAAAPD94cGFja2V0IGJlZ2luPSLvu78iIGlkPSJXNU0wTXBDZWhpSHpyZVN6TlRjemtjOWQi'
    b'Pz4KPHg6eG1wbWV0YSB4bWxuczp4PSJhZG9iZTpuczptZXRhLyIgeDp4bXB0az0iWE1QIENv'
    b'cmUgNC40LjAtRXhpdjIiPgogPHJkZjpSREYgeG1sbnM6cmRmPSJodHRwOi8vd3d3LnczLm9y'
    b'Zy8xOTk5LzAyLzIyLXJkZi1zeW50YXgtbnMjIj4KICA8cmRmOkRlc2NyaXB0aW9uIHJkZjph'
    b'Ym91dD0iIgogICAgeG1sbnM6aXB0Y0V4dD0iaHR0cDovL2lwdGMub3JnL3N0ZC9JcHRjNHht'
    b'cEV4dC8yMDA4LTAyLTI5LyIKICAgIHhtbG5zOnhtcE1NPSJodHRwOi8vbnMuYWRvYmUuY29t'
    b'L3hhcC8xLjAvbW0vIgogICAgeG1sbnM6c3RFdnQ9Imh0dHA6Ly9ucy5hZG9iZS5jb20veGFw'
    b'LzEuMC9zVHlwZS9SZXNvdXJjZUV2ZW50IyIKICAgIHhtbG5zOnBsdXM9Imh0dHA6Ly9ucy51'
    b'c2VwbHVzLm9yZy9sZGYveG1wLzEuMC8iCiAgICB4bWxuczpHSU1QPSJodHRwOi8vd3d3Lmdp'
    b'bXAub3JnL3htcC8iCiAgICB4bWxuczpkYz0iaHR0cDovL3B1cmwub3JnL2RjL2VsZW1lbnRz'
    b'LzEuMS8iCiAgICB4bWxuczp0aWZmPSJodHRwOi8vbnMuYWRvYmUuY29tL3RpZmYvMS4wLyIK'
    b'ICAgIHhtbG5zOnhtcD0iaHR0cDovL25zLmFkb2JlLmNvbS94YXAvMS4wLyIKICAgeG1wTU06'
    b'RG9jdW1lbnRJRD0iZ2ltcDpkb2NpZDpnaW1wOjk2N2I0NjYzLWM0YzgtNDQ0OS1iYzRkLWQ2'
    b'MjY5MzBhY2E4ZCIKICAgeG1wTU06SW5zdGFuY2VJRD0ieG1wLmlpZDplNjYxYTIxYi1kMDc3'
    b'LTQzODctYTkwYS0wOWU0Yjk5ZDBkYTQiCiAgIHhtcE1NOk9yaWdpbmFsRG9jdW1lbnRJRD0i'
    b'eG1wLmRpZDozYThjMWFmNS01YmFlLTQ1MWEtOTQ5Ny0xNjNmYmNiMzZlODciCiAgIEdJTVA6'
    b'QVBJPSIyLjAiCiAgIEdJTVA6UGxhdGZvcm09Ik1hYyBPUyIKICAgR0lNUDpUaW1lU3RhbXA9'
    b'IjE2MTE0NTMxNjczNTQ0ODMiCiAgIEdJTVA6VmVyc2lvbj0iMi4xMC4yMiIKICAgZGM6Rm9y'
    b'bWF0PSJpbWFnZS9wbmciCiAgIHRpZmY6T3JpZW50YXRpb249IjEiCiAgIHhtcDpDcmVhdG9y'
    b'VG9vbD0iR0lNUCAyLjEwIj4KICAgPGlwdGNFeHQ6TG9jYXRpb25DcmVhdGVkPgogICAgPHJk'
    b'ZjpCYWcvPgogICA8L2lwdGNFeHQ6TG9jYXRpb25DcmVhdGVkPgogICA8aXB0Y0V4dDpMb2Nh'
    b'dGlvblNob3duPgogICAgPHJkZjpCYWcvPgogICA8L2lwdGNFeHQ6TG9jYXRpb25TaG93bj4K'
    b'ICAgPGlwdGNFeHQ6QXJ0d29ya09yT2JqZWN0PgogICAgPHJkZjpCYWcvPgogICA8L2lwdGNF'
    b'eHQ6QXJ0d29ya09yT2JqZWN0PgogICA8aXB0Y0V4dDpSZWdpc3RyeUlkPgogICAgPHJkZjpC'
    b'YWcvPgogICA8L2lwdGNFeHQ6UmVnaXN0cnlJZD4KICAgPHhtcE1NOkhpc3Rvcnk+CiAgICA8'
    b'cmRmOlNlcT4KICAgICA8cmRmOmxpCiAgICAgIHN0RXZ0OmFjdGlvbj0ic2F2ZWQiCiAgICAg'
    b'IHN0RXZ0OmNoYW5nZWQ9Ii8iCiAgICAgIHN0RXZ0Omluc3RhbmNlSUQ9InhtcC5paWQ6YWI0'
    b'ZGU0ZGMtMjY5Mi00Y2EwLTlkMmItYTY1MjRlODlmNjZiIgogICAgICBzdEV2dDpzb2Z0d2Fy'
    b'ZUFnZW50PSJHaW1wIDIuMTAgKE1hYyBPUykiCiAgICAgIHN0RXZ0OndoZW49IjIwMjEtMDEt'
    b'MjNUMTk6NTI6NDctMDY6MDAiLz4KICAgIDwvcmRmOlNlcT4KICAgPC94bXBNTTpIaXN0b3J5'
    b'PgogICA8cGx1czpJbWFnZVN1cHBsaWVyPgogICAgPHJkZjpTZXEvPgogICA8L3BsdXM6SW1h'
    b'Z2VTdXBwbGllcj4KICAgPHBsdXM6SW1hZ2VDcmVhdG9yPgogICAgPHJkZjpTZXEvPgogICA8'
    b'L3BsdXM6SW1hZ2VDcmVhdG9yPgogICA8cGx1czpDb3B5cmlnaHRPd25lcj4KICAgIDxyZGY6'
    b'U2VxLz4KICAgPC9wbHVzOkNvcHlyaWdodE93bmVyPgogICA8cGx1czpMaWNlbnNvcj4KICAg'
    b'IDxyZGY6U2VxLz4KICAgPC9wbHVzOkxpY2Vuc29yPgogIDwvcmRmOkRlc2NyaXB0aW9uPgog'
    b'PC9yZGY6UkRGPgo8L3g6eG1wbWV0YT4KICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgIAogICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgCiAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAKICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgIAogICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgCiAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAKICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgIAogICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgCiAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAKICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgIAogICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'CiAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAKICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgIAogICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgCiAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAKICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgIAogICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgCiAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAKICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgIAog'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgCiAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgIAo8P3hwYWNrZXQgZW5kPSJ3Ij8++wq51AAAAAZiS0dEAP8A'
    b'/wD/oL2nkwAAAAlwSFlzAAALEwAACxMBAJqcGAAAAAd0SU1FB+UBGAE0LzOp0sgAAABiSURB'
    b'VFjD7ZTBCsAwCEO19Jv8/3N+yl03aOkYRHfIOwuGxGgmhBCCR74Z8iIB2z2D7ILfxGR3BLkS'
    b'4gAoyiJiZ/0jGidbc7qxHN1VmQCMGMHndpQd4Sxug//uEbW/YiGEEBeBXxoFzUN2OwAAAABJ'
    b'RU5ErkJggg==')

