#----------------------------------------------------------------------
# This file was generated by /Users/humberto.a.sanchez.ii/PycharmProjects/PyUt/venv-pyenv-3.9.0/bin/img2py
#
from wx.lib.embeddedimage import PyEmbeddedImage

embeddedImage = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAABhGlDQ1BJQ0MgcHJvZmlsZQAA'
    b'KJF9kTtIw1AUhv+mFUUqInZQcchQnSyIijhqFYpQIdQKrTqY3PQFTRqSFBdHwbXg4GOx6uDi'
    b'rKuDqyAIPkDc3JwUXaTEc5NCixgPHO7Hf89/OPdcQKiXmWaFxgFNt81UIi5msqti5ysC6KMc'
    b'REhmljEnSUn4xtc9VVLcxXgv/7o/o0fNWQwIiMSzzDBt4g3i6U3b4LxPHGFFWSU+Jx4zaUDi'
    b'R64rHr9xLrgs8J4RM52aJ44Qi4U2VtqYFU2NeIo4qmo69RcyHquctzhr5SprzslfGM7pK8tc'
    b'pxxGAotYggQRCqoooQwbMTp1Uiyk6D7u4x9y/RK5FHKVwMixgAo0yK4f/A9+79bKT054ncJx'
    b'oOPFcT5GgM5doFFznO9jx2mcAMFn4Epv+St1YOaT9FpLix4BvdvAxXVLU/aAyx1g4MmQTdmV'
    b'gpRCPg+8n9E3ZYH+W6B7zdtb8x6nD0CadpW8AQ4OgdEC9V73eXdX+97+rWnu7wfkq3Ju9vHP'
    b'mwAAAAZiS0dEAP8A/wD/oL2nkwAAAAlwSFlzAAAOxAAADsQBlSsOGwAAAAd0SU1FB+UBEQEZ'
    b'N33nX/sAAAApSURBVDjLY2AYBejgPzU0/6eGzUQbwghVzEipd/5TIyz+UzMgRwE9AQCbdAv3'
    b'W4tGRgAAAABJRU5ErkJggg==')

