#----------------------------------------------------------------------
# This file was generated by /Users/humberto.a.sanchez.ii/PycharmProjects/PyUt/venv-pyenv-3.9.0/bin/img2py
#
from wx.lib.embeddedimage import PyEmbeddedImage

embeddedImage = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAF0HpUWHRSYXcgcHJvZmlsZSB0'
    b'eXBlIGV4aWYAAHjarVdblusoDPxnFbMEQAjEcnieMzuY5U8JbHeSTnfS93YcGwWDEKqiIGb8'
    b'9+80/+DjmcQEThJzjBafkEP2BYbY/Snr6WxYz/Xxxyv8vqs31wuPKkJJ+6fEo/1Z7y4Huyiw'
    b'+MaRtONFvX+Rw+FfHhwdI5NGpHY/HOXDEfn9wh0Oyp6WjVnS7RTq2GU/ZyL7NvoIch/2p98J'
    b'2euMccj7QY4snp78DoD0doYKDIenJ7yBxbADyXqezpCQZ3myN1GZR1Quy31R/wAKxV1vUHGf'
    b'zHiVT+sdP9QfDs1K8c3I1K6R7+pLuth1l2S95+xi5hx7diVEpDQek7qyowYaVqScVreIK+Fm'
    b'2GldGZcYsLcB8m6brbiay84DlumC66646cYqm2sIMfjhE0rvG4DSOqHks29kDXAKernpE2Xq'
    b'wMtTA7yEWn/F4ta4eQ3XnGDg7tDSOzhzSgWjj9+4vnQ0p1LeOStXrhCXVxIiDEVOn2gFQNw8'
    b'ecQrwef1+FFcCQjySrNggsXW7aKyO7ilPKIFNKEho9xrzaV+OECKMDYjGEdAwEaQ30Vnk/fJ'
    b'OeRRgE+BI/EUfAUEjtl3ROkDUQQ44nVs9ElutfXsdzU0C0AwRUqAJlMBVgHCBv6kIOBQYeLA'
    b'zJETC2cukWKIHGNMUcWvJEohcYopJUk5FSEJwhIliRjJUrLPBHHkHHPKknMuBYMWeC7oXdCg'
    b'lOor1VC5xpqq1FxLA31aaNxiS01My61036lDJ3rsqUvPvQw3QKURBo840pCRR5mg2qQZJs84'
    b'05SZZ7lQc2bD+ul6HzV3ouYXUtowXaiha0qnC6dywooZEPPBAfGkCIDQXjGz4kLwRqFTzGyG'
    b'shF7RMkKTneKGBAMw3me7sLuA7k73EwIf4WbP5EzCt1vIGcUui+Q+4zbE9S67jbNklkI6TLU'
    b'pFrC8kOj4gVfyOL7pflphx86mmJ9HXMe5hu+zIsGBG9vxWXejGfWFOvwfhtcuIcRG1ize9Vo'
    b'KMvqX/S88H05RcoyR6Du1fkcFfBqfTGD3WCikpjymNg20uwuMPbBKFoG1oPFi5InpJZT10mw'
    b'3qsujp4a+K1GBP9Kbl1kHG6hGdDSZdvb0jxWaIndzC2Tm6QSUq91OUmcR8z68hi8HWO2iWRP'
    b'nzsyh2XUZ6CdYs1Kwd71Mnt6Wtq5MmOdFFHTd9aW0bHgkLPq3Omsy4jf4m/uOAN4F5jZziAK'
    b'tJQNFdZfmdm1PjlNIh3M1918ghbYp42+OKK7wvRY9T+Y1ZqUeW9WLh5m+EyBHABFMJUhfXkj'
    b'GxX9hYnCFEKh1kAAAAGNDHvmazQoVYds5ZJ6pCYahZEP9uccEg6dMQPEVEEcVnamZrcRcJJ8'
    b'QqCjNIdxNVdjVSCqM7zOtcOod8xM7Fr5mKB5TnqPQmeHU1ULB61u83yuXjVaLJi3wdkQUa/F'
    b'frvqG7T1tZ6dHWCYlyrBawMYWVyDvmN7WvOyeWQH7WZFjbGpQEZGlL2wrNWFsxt6dzXEmyFo'
    b'hb8nOK54jtgiJO4k+BWWMsecHHKldjtyo8l/xE/zQNBv+Yk9D3ctOAIQFMJu4WpeFcLcSYR8'
    b'oyN1JQMbNijYd77zDZHMpWHLkI58JGz3s8gSnaV3h/pk1/2XImlu1NJ+dH0hlRpd5Y7jZ9b1'
    b'EdcugkMVpHwrg0pIaZPCc70/G4ENoOlIufg9NdDJfMfWn5DVfMfWn5DVfGbr2Kj2iNDPXL5k'
    b'qiY74l/pTTwHgX7KUvOOjL5kKbTTdKp7NSL0TTzW82GCLIa59C+cOl/WDmBT59na7dZAqDfn'
    b'C7+kErV14os/+8sJatUPzmzXGeEemCsR5hfW62pu3szEzS6pmHvofrS324GpdkacN8+E7Env'
    b'BKyd4pjj6g1XyGJu7UOMLhaav4X9Ofw/gf3hSGD+5Az7LHzzl2Bd/czro+N7pbkb4l4ufuTL'
    b'/EIwbzia+NMChTf/A2rfAIuBtwsVAAABhWlDQ1BJQ0MgcHJvZmlsZQAAeJx9kT1Iw1AUhU9T'
    b'pSIVByuKOGSoThaKijhqFYpQIdQKrTqYvPRHaNKQpLg4Cq4FB38Wqw4uzro6uAqC4A+Im5uT'
    b'oouUeF9SaBHjhcf7OO+ew3v3AUK9zDSrIw5oum2mkwkxm1sRQ68IYAD9iCMkM8uYlaQUfOvr'
    b'nrqp7mI8y7/vz+pR8xYDAiLxDDNMm3ideGrTNjjvE0dYSVaJz4nHTLog8SPXFY/fOBddFnhm'
    b'xMyk54gjxGKxjZU2ZiVTI54kjqqaTvlC1mOV8xZnrVxlzXvyF4bz+vIS12kNI4kFLEKCCAVV'
    b'bKAMGzHadVIspOk84eMfcv0SuRRybYCRYx4VaJBdP/gf/J6tVZgY95LCCaDzxXE+RoDQLtCo'
    b'Oc73seM0ToDgM3Clt/yVOjD9SXqtpUWPgN5t4OK6pSl7wOUOMPhkyKbsSkFaQqEAvJ/RN+WA'
    b'vluge9WbW/Mcpw9AhmaVugEODoHRImWv+by7q31u//Y05/cDZsByou+2BFYAAA+gaVRYdFhN'
    b'TDpjb20uYWRvYmUueG1wAAAAAAA8P3hwYWNrZXQgYmVnaW49Iu+7vyIgaWQ9Ilc1TTBNcENl'
    b'aGlIenJlU3pOVGN6a2M5ZCI/Pgo8eDp4bXBtZXRhIHhtbG5zOng9ImFkb2JlOm5zOm1ldGEv'
    b'IiB4OnhtcHRrPSJYTVAgQ29yZSA0LjQuMC1FeGl2MiI+CiA8cmRmOlJERiB4bWxuczpyZGY9'
    b'Imh0dHA6Ly93d3cudzMub3JnLzE5OTkvMDIvMjItcmRmLXN5bnRheC1ucyMiPgogIDxyZGY6'
    b'RGVzY3JpcHRpb24gcmRmOmFib3V0PSIiCiAgICB4bWxuczppcHRjRXh0PSJodHRwOi8vaXB0'
    b'Yy5vcmcvc3RkL0lwdGM0eG1wRXh0LzIwMDgtMDItMjkvIgogICAgeG1sbnM6eG1wTU09Imh0'
    b'dHA6Ly9ucy5hZG9iZS5jb20veGFwLzEuMC9tbS8iCiAgICB4bWxuczpzdEV2dD0iaHR0cDov'
    b'L25zLmFkb2JlLmNvbS94YXAvMS4wL3NUeXBlL1Jlc291cmNlRXZlbnQjIgogICAgeG1sbnM6'
    b'cGx1cz0iaHR0cDovL25zLnVzZXBsdXMub3JnL2xkZi94bXAvMS4wLyIKICAgIHhtbG5zOkdJ'
    b'TVA9Imh0dHA6Ly93d3cuZ2ltcC5vcmcveG1wLyIKICAgIHhtbG5zOmRjPSJodHRwOi8vcHVy'
    b'bC5vcmcvZGMvZWxlbWVudHMvMS4xLyIKICAgIHhtbG5zOnRpZmY9Imh0dHA6Ly9ucy5hZG9i'
    b'ZS5jb20vdGlmZi8xLjAvIgogICAgeG1sbnM6eG1wPSJodHRwOi8vbnMuYWRvYmUuY29tL3hh'
    b'cC8xLjAvIgogICB4bXBNTTpEb2N1bWVudElEPSJnaW1wOmRvY2lkOmdpbXA6MjViNmYwYTAt'
    b'NTM1Mi00NDk5LTgyN2EtN2NlODZmNzdjY2FiIgogICB4bXBNTTpJbnN0YW5jZUlEPSJ4bXAu'
    b'aWlkOjcyMDJjNTgyLTI3NTItNGVmOC1iNDYxLTg5Njg1ZTc5MjM3YyIKICAgeG1wTU06T3Jp'
    b'Z2luYWxEb2N1bWVudElEPSJ4bXAuZGlkOmJlYzkzMzRjLTE5YzMtNDlkOC04NjhlLWU3Y2Jl'
    b'NWFlMmEwZSIKICAgR0lNUDpBUEk9IjIuMCIKICAgR0lNUDpQbGF0Zm9ybT0iTWFjIE9TIgog'
    b'ICBHSU1QOlRpbWVTdGFtcD0iMTYxMTQzODUyMzM1MzQxMiIKICAgR0lNUDpWZXJzaW9uPSIy'
    b'LjEwLjIyIgogICBkYzpGb3JtYXQ9ImltYWdlL3BuZyIKICAgdGlmZjpPcmllbnRhdGlvbj0i'
    b'MSIKICAgeG1wOkNyZWF0b3JUb29sPSJHSU1QIDIuMTAiPgogICA8aXB0Y0V4dDpMb2NhdGlv'
    b'bkNyZWF0ZWQ+CiAgICA8cmRmOkJhZy8+CiAgIDwvaXB0Y0V4dDpMb2NhdGlvbkNyZWF0ZWQ+'
    b'CiAgIDxpcHRjRXh0OkxvY2F0aW9uU2hvd24+CiAgICA8cmRmOkJhZy8+CiAgIDwvaXB0Y0V4'
    b'dDpMb2NhdGlvblNob3duPgogICA8aXB0Y0V4dDpBcnR3b3JrT3JPYmplY3Q+CiAgICA8cmRm'
    b'OkJhZy8+CiAgIDwvaXB0Y0V4dDpBcnR3b3JrT3JPYmplY3Q+CiAgIDxpcHRjRXh0OlJlZ2lz'
    b'dHJ5SWQ+CiAgICA8cmRmOkJhZy8+CiAgIDwvaXB0Y0V4dDpSZWdpc3RyeUlkPgogICA8eG1w'
    b'TU06SGlzdG9yeT4KICAgIDxyZGY6U2VxPgogICAgIDxyZGY6bGkKICAgICAgc3RFdnQ6YWN0'
    b'aW9uPSJzYXZlZCIKICAgICAgc3RFdnQ6Y2hhbmdlZD0iLyIKICAgICAgc3RFdnQ6aW5zdGFu'
    b'Y2VJRD0ieG1wLmlpZDo0Njc2ZTllZC1lMTEzLTQ4ZjgtOGE0OS1kMTkyZjdlM2ZhM2EiCiAg'
    b'ICAgIHN0RXZ0OnNvZnR3YXJlQWdlbnQ9IkdpbXAgMi4xMCAoTWFjIE9TKSIKICAgICAgc3RF'
    b'dnQ6d2hlbj0iMjAyMS0wMS0yM1QxNTo0ODo0My0wNjowMCIvPgogICAgPC9yZGY6U2VxPgog'
    b'ICA8L3htcE1NOkhpc3Rvcnk+CiAgIDxwbHVzOkltYWdlU3VwcGxpZXI+CiAgICA8cmRmOlNl'
    b'cS8+CiAgIDwvcGx1czpJbWFnZVN1cHBsaWVyPgogICA8cGx1czpJbWFnZUNyZWF0b3I+CiAg'
    b'ICA8cmRmOlNlcS8+CiAgIDwvcGx1czpJbWFnZUNyZWF0b3I+CiAgIDxwbHVzOkNvcHlyaWdo'
    b'dE93bmVyPgogICAgPHJkZjpTZXEvPgogICA8L3BsdXM6Q29weXJpZ2h0T3duZXI+CiAgIDxw'
    b'bHVzOkxpY2Vuc29yPgogICAgPHJkZjpTZXEvPgogICA8L3BsdXM6TGljZW5zb3I+CiAgPC9y'
    b'ZGY6RGVzY3JpcHRpb24+CiA8L3JkZjpSREY+CjwveDp4bXBtZXRhPgogICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgCiAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAKICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgIAogICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgCiAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAKICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgIAog'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgCiAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAKICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgIAogICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgCiAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAKICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgIAogICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgCiAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAKICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgIAogICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgCiAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAKICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgIAogICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgCiAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAKICAgICAgICAgICAgICAgICAgICAgICAgICAgCjw/eHBhY2tldCBlbmQ9Inci'
    b'Pz64r5k3AAAABmJLR0QA/wD/AP+gvaeTAAAACXBIWXMAAAsTAAALEwEAmpwYAAAAB3RJTUUH'
    b'5QEXFTArE+TILwAAAL5JREFUWMPtl0EOhCAMRYthW/fchqN7G/fDAXDhZJKBiMX8CkaaGBNM'
    b'2udrxUD09jAH61Ex919MXRtY1k91Qu/mKgtqBr7wsWkLJBDqM3AGccsQliCsVtFkGBEt4MKV'
    b'va04QAaYiMIhRMmGlSXXiwlXnC/BngCEn1rvDHlnsmf5OhSgDIVoGXAfCMn9doD64l38jsEA'
    b'3BKAezDwQAArne59f+ds01nWePkLABoI2gZSE5jiYwi1T0aies0NjNgAV34zR89gM9IAAAAA'
    b'SUVORK5CYII=')

