#----------------------------------------------------------------------
# This file was generated by /Users/humberto.a.sanchez.ii/PycharmProjects/PyUt/venv-pyenv-3.9.0/bin/img2py
#
from wx.lib.embeddedimage import PyEmbeddedImage

embeddedImage = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAABhWlDQ1BJQ0MgcHJvZmlsZQAA'
    b'KJF9kT1Iw1AUhU9TRZGKiB1EOmSoThZERcRJq1CECqFWaNXB5KV/0KQhSXFxFFwLDv4sVh1c'
    b'nHV1cBUEwR8QNzcnRRcp8b6k0CLGC4/3cd49h/fuA4R6mWlWxxig6baZSsTFTHZV7HpFAP0A'
    b'ZhCRmWXMSVISvvV1T91UdzGe5d/3Z/WqOYsBAZF4lhmmTbxBPLVpG5z3icOsKKvE58SjJl2Q'
    b'+JHrisdvnAsuCzwzbKZT88RhYrHQxkobs6KpEU8SR1VNp3wh47HKeYuzVq6y5j35C0M5fWWZ'
    b'67QiSGARS5AgQkEVJZRhI0a7ToqFFJ3HffxDrl8il0KuEhg5FlCBBtn1g//B79la+YlxLykU'
    b'BzpfHOdjGOjaBRo1x/k+dpzGCRB8Bq70lr9SB6Y/Sa+1tOgR0LcNXFy3NGUPuNwBBp8M2ZRd'
    b'KUhLyOeB9zP6piwwcAv0rHlza57j9AFI06ySN8DBITBSoOx1n3d3t8/t357m/H4AcFBypsYq'
    b'MmAAAAAGYktHRAD/AP8A/6C9p5MAAAAJcEhZcwAACxIAAAsSAdLdfvwAAAAHdElNRQflAREB'
    b'ASPlJhPfAAAAaElEQVRYw2NgGOmAkQK9/6lsHsWW4xOni+VkOYJpoNPAqAMGPBEO2WxItaw3'
    b'mghHHcBERoJDwQoKCgysrKz/sciN5oJRB4w6gK454P9AWs4wEI4YPo1SWpV6/wfScpo44j+d'
    b'9Y0C+gEAcUkibLR7Ba8AAAAASUVORK5CYII=')

