#----------------------------------------------------------------------
# This file was generated by /Users/humberto.a.sanchez.ii/PycharmProjects/PyUt/venv-pyenv-3.9.0/bin/img2py
#
from wx.lib.embeddedimage import PyEmbeddedImage

embeddedImage = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAAK3RFWHRDcmVhdGlvbiBUaW1l'
    b'AERvIDE0IE5vdiAyMDAyIDIzOjMxOjQ0ICswMTAwhFAcSAAAAAd0SU1FB9MDBBUaLX+j7pMA'
    b'AAAJcEhZcwAACxIAAAsSAdLdfvwAAAAEZ0FNQQAAsY8L/GEFAAAF50lEQVR42u1WbVBUVRh+'
    b'7t57dxcWl+VDBURJwQSFpETQEgrtiwIdP9KatJl0JmfKZrSssalmGsdq8ofTZE79M8q0HMcv'
    b'oiy/AhVBDEldHFFYFpYFgXVhd2HZj7u399xrAjX4/aOZfGcOZ+95zznP877vc84BuG//d+Pu'
    b'eocF5eHobV2IgFREbRoEYTQkSYYUsAGaSmj4fdBZf8KhD4P3lkDOHhEJhlXwdr8XlZQ0cmLq'
    b'BIxPioVeD3gDgN0ho6GhFY76evhtLRaEj34Xhwt23RsCr9ROQE/jD1HxCdMLnpqOaWM1iNQC'
    b'NhfQ2gM4fUAvxRsIARYaczv74Tj2qyz1i5tw5Pl3aAf5zgksr30Mjua92XlZsYvz4hEXBpxt'
    b'B851EqgfCBKon8B9rJfU336Ck3mg69AB2d8jrcfRwo/ujMBr5jw4m0qLih6PWJRpgI8AjlqA'
    b'Hp8aUyikgvkYAfL5qBReSSXCBCATWvvenSQQQy6OFJ5kW2puGfx1czpcLfsXLciPeHmaAV6K'
    b'9nADpZk219EuWoF6HRBGGpCDAQT7vRCoLHoaE8jHyyqYKTuXR8D96dAMLK8wQhQ2IsQ9Cp32'
    b'EL48uBZYG7oO/mp9JPob/3juyRnJS3MilcgOW2k8NBCZPyCjpvo8rJcafZCEOvL1UUpStCN0'
    b'o2ImpXPhCQnwEWkQKfve3XLII03FicXn1AyEvJsfnmBaWfxmVkbqSKzB6qdXD4med36dmZmS'
    b'PD8rEjyBnaADpqWVPNU1TAQ6O5zY82Npr9XS+T4MiXEoKXwEpYWz8MvceL9PO6vt+NHKzppq'
    b'aAmcMQ4fl8xBds8bVAI5d9UzEyHS1+K8h6hw3RuwpiFNcb3duHCEgVvyYl4y4klwFS1Q5jEi'
    b'DLyppQNHfjvehIi4HOya8wm+z+oeRF3GvvwKxGQ+4bpU97vLYoHASMclkkvKGSDA8U2d3R54'
    b'fGq9luVPCYO79RusqDbBad300uypXHoMUG2nZWwRgetoXpfTg6NlNXYYk2ejeLp5WP3sSvfB'
    b'mLK8q/aUT0OIOlMUK9/EAQJavuxEQzfCtaqSpyZFI238yGxwnoqMBxPHzXxAiyaKy0U1FDk1'
    b'A2yj3YdPBxCd+AK2TrHcVMT7Z1nA6Uo8LTYI4bSY05gGZQDl5+wuJT0Cpx6fpXmpECPC0uZm'
    b'J0NP4y10oWg51R9GRA9Uks443Wf4KqPilk8Sry3xttsV7RABboCAmFjVdNXjDQbV9LJBVuP1'
    b'i3KQYORQ7xiImpWo7Wof6i+31cMQ//HtXCMI+k/3O7vAKa9CyD1AYPOEPgjG09arXgWIoybL'
    b'auvuU6SkEGLRh5PwSqouyIgwrcMX4/tvi4AxtSHY1xuSvLRMIzSzIeG6U9SVnWntyZ0zifTn'
    b'U8qCkKwcdSVy9oP1dbYeONq7gtCKy7CyegWkkJ4m6oi1BfoRG7El7fzwYkzzyQX7XT5Hp4lC'
    b'N/+DQKjcfMWDgslqtPLghbJKSKIWFxWBJQUzRJ7j5mt4jeLgOBHtDtesgxW1RVhmnozvprQN'
    b'rwPB5W6zmSCIVUMJjEo8ecF+kcWuYwRCgxdd++boT2QYj4iESOXRCUrq4xMkgjHRsWiwxZka'
    b'W3tm0tTdwxLgOMnT3iYhEHlkQAPM3tB7wBtr2tx+5V5nJFhjouSu9azJBBiS1J59izSXXhdU'
    b'/dmCRuuVqxCjK2+oA57nZI3+FI4V2odmgJleW1bX4Z6ZPz6GSjuQffmaHpRToFEXMfd5qxPV'
    b'F23sNuyEOGIHjGM+x5ZU+w0JyHIYOGHb359DCYh8udnRt+7ZlBjlCWXGgNm5ZY0RaHb4ceJi'
    b'K6outfsh6w9AIxfDOboU+zJ8uBXTmczw9GwfVN1Btlk2iu6Ljm3zJgndXtXLyuCircsud6Ks'
    b'vl3udnNn6TwWIxS7HZvirtwS6A3s3/+QbGgufysrOjdrjAGVTR4cbLiCCzZnB12LO2CILcYH'
    b'I8/cLehNCLSko9exFcHgWBJABUn/W1jH/oyd8f57CXzf7tt/xv4CIgdcs5rCaNcAAAAASUVO'
    b'RK5CYII=')

