#----------------------------------------------------------------------
# This file was generated by /Users/humberto.a.sanchez.ii/PycharmProjects/PyUt/venv-pyenv-3.9.0/bin/img2py
#
from wx.lib.embeddedimage import PyEmbeddedImage

embeddedImage = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAK3RFWHRDcmVhdGlvbiBUaW1l'
    b'AERvIDE0IE5vdiAyMDAyIDIzOjMxOjQ0ICswMTAwhFAcSAAAAAd0SU1FB9MCGhclGYjr7WgA'
    b'AAAJcEhZcwAACxIAAAsSAdLdfvwAAAAEZ0FNQQAAsY8L/GEFAAACRElEQVR42mNgGGjAiMzh'
    b'CdlW+eX7n0BhSTGd339+ffj15cPhfwLC03/NsT5A2AD3/X0G7voFnhaCjMx/GRj4ORgYfgPp'
    b'aSvOv3nx9V/hn9kmS3AbYLvSTsbO+gCfijQjM5ArDNTMDWSwAmXN5BgYFmy+/un++x/xv6ca'
    b'bcBugOOyZcqJkZHvL97//fXN0yOM/xm+ConzOjjZ6fOw/WdgEORmYFi8/ez1V584jBg+P/3H'
    b'q6iy4+/vn1e/dWvlMoH0c0nLWn259+7/u6sPgn8utHX6scjW99krBu3t+8484+FkYPj3j4Eh'
    b'0sVAU4TnyzoGVtaSubFKjirCjKkgvWADWLh5xD4+eXaaYYfTZrjbFho8evuBy23vmTu/OFgY'
    b'GER4mBnExQVtrI3lqkHufvft52O4AUyMjL9/vHl1BCOE5mtfvff8w9Z/fxgY/gNdEWSqyptg'
    b'q8z17jsDw9vPPz+ALQcRvz6+fcDwn/kpSpQW3Sr/8v2r5vfXb/5sPH2DId5eA6iYkeHzTwaG'
    b'159/MDAy/n8GN+Dbm9enBFUV1d7DdEe8ZTdU+t5a6afK/Bwo+AfoAmDAMnz8wcDADtRx/dkn'
    b'oINYLsC9IKwq8RpoJBPc+hXCP8/e/zY9f+HtT+vPv2b4CjTgCxCzAKOWG2jAtfc/vzP+/3sO'
    b'bsDbA0wN3AKcL5C98K1XLff2C1apfZdeTOvYdff+mjOP/gsCY0SUB+iSn3+ffu8334iRlPGC'
    b'qrvWfIwf26T4uUze/2Je+bJGNYnsDERVAAAJF+oOQNYRZAAAAABJRU5ErkJggg==')

