#----------------------------------------------------------------------
# This file was generated by /Users/humberto.a.sanchez.ii/PycharmProjects/PyUt/venv-pyenv-3.9.0/bin/img2py
#
from wx.lib.embeddedimage import PyEmbeddedImage

embeddedImage = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAAK3RFWHRDcmVhdGlvbiBUaW1l'
    b'AFNvIDE3IE5vdiAyMDAyIDE5OjE3OjQ2ICswMTAwQcC18QAAAAd0SU1FB9MDBBMmG8dnfkcA'
    b'AAAJcEhZcwAACvAAAArwAUKsNJgAAAAEZ0FNQQAAsY8L/GEFAAAGaklEQVR42u1XSW8cRRR+'
    b'VdU9PUuPZ2LHy8hJSOyAEk4gIQQoIgQkThy4cAyIA0ckIggSBxAohxzggsSFE5xAQiKIE4uE'
    b'ULhwYseEYMA2AaGEeDL2eJbeqnjvVVdnvP4BGE9NVVdX1fve97YywH/9I9zgxS9+C9640Duf'
    b'CvNkPzLNR45m8NKJBPopgBSClxpjIMs0aJNCmhp8pj4DneE8jjMcZ1kGBluKc9pk4IsM3lts'
    b'woXLdaiauOOb5K2nTx174dxThyOS6zkAb344OH/j6uoZtbwEWZyC9iag9dgdMDlzCKQU2NQm'
    b'5ATGaI2CrNA0TbmnliQJ9imv+fvPZWgsd2B+ygfle82lXztnXv/4W1QLnt8EYKjNabWyBELi'
    b'Q8kjtUEIS5DWBgEA9Hq9AoBG4dRIMAmi3j37vs9MMVDq8KzetctQDnyYOzoHK99deWIbgHIg'
    b'9w+IaBJsBAtkG4nCSrC4uAjD4RDfye22zNcRmNnZWV5DgAxYMfG1RVDlElRmboNQmalBvq8A'
    b'QBtZOG4kAPjlA0YPr9frEARBMcdmGGk0RyZw726enUHtyD1ILM7TH5oItgLgQz3Jm61A1NLA'
    b'poPm5+e3ae7s73yA7B/H8U3wuXJ+uB9NQw8ZwI4AUA7Rxixo3CbQs3VWHETvlpaWWBABZHpz'
    b'rUdZoPlms1ms0aSAsWtxNSjrQLswkJvAWdg5Fm0mAN1uF6Io2tH2bkzrG41GAbxgkCKJQIys'
    b'3wZAKsVR4MxgtLFxnWs6PT1djB0wmxuywhzOB4pQRe3ZoEQEHq6E3BmAdUJgBogmJA9jPN0E'
    b'gByQBI8CoF4hcLfGeb8DxWuoJ2YF7pFmDwbYCWWRH91B7vCVlRV2MLGFxq1hODExMcIAv8Sv'
    b'pV+ZPUwghDWBIgQUUi615gBIU59debtwx8yoM7ISZBLkQDqz7mYC6wPWBCIPn9EooPBqtVqF'
    b'f4z6gGPKZcdR+hkEjRWaRxhmYncGPM/aH6UrBJrGA+h22pw82DRgKR0FQHOjwnWmizFpEQ96'
    b'eBZFlk1uxCyY3RgQLlwErA4MfPRNB+KkXYSOzPcyJ8aypEkrbXsqTgJycMKC9XFhOx7ngkbH'
    b'CCX3YkCy/UnQpesSfryogI9E7aWyTsQmUFYjoUSeO5T1ETf2gHuVv/ew96XmfewHOwIwRLti'
    b'tUgzH398z6K2PjmSpp02MgcgbLW0z7ropXtPL6ln5fZggJ6IAZOjEHk0aIyOjGf5CBvvHPME'
    b'Rto1CF4q6zwFMGmsU+cgiTGzuxMazFI5A4VwNgw8MP47rixhnsBLBc5lJuN6T6k6TrAQJREk'
    b'kYYkjjB5JeiIKXTVOPTLLU4+dHZpah5N4jOYHQEwMA/txj6f047aJijk7KNH4PCtx6HfvQHd'
    b'9XW40W5Dp7MO1zsxBJUQi88shGEdmlgDqGTPzkzCvY+/DIP6HBKUcUG663AdfrgaW4feLQqs'
    b'eSzRzvb0s97twSdf/gGnX70ME5MhBPUymOo0nDtxDaphCKVKHfxyDVRQBVmqgAioNaAyNYe7'
    b'E0gRwLHWGPz0zypkuxYj9mLFycICtCA8DEm6BfWHfUi0giijCwv6ROZDI2yg5lVsYdGIARA+'
    b'1xLgGMozIvcStmbxmwAw67F9hA1DB4qcZ2OjB/2kBuUmalvzwac7oy+x7IbQGAuhWrPCx8bG'
    b'oFqtIsUJV1IOU0NNWlbZMfOQ2wYAU63n2UJkC4j1AYn+T5fRge5DdV8TbY4xjXc77XsQ1gPU'
    b'2AIgzUk4rRVZbNO5zIVrYXOIFHlG3YGBLE6utLU+ONnwGIADITGrrKPjReUJKI+VsSQjALzd'
    b'alVirWskHDWvVCosnNaaZAh0HaWrvMiZZTaUKP7HKLKvG9x5/ND97dVk4Xo7wvs7ZTPFB1CJ'
    b'zjASSBhKQ+erQFYuQ4Z3gxC1bzSs8I2NDVhbW2MA6911a8E8J0jOhJJrAtWKONXtbQx89syB'
    b'5dvP/vLQpYVLn5s0Pd66ZdwygRu8UgBzBxrwypSEsbACtWoNPGyzM/s4KUXopDFe1ajRlU1j'
    b'ESPVVOCBxP0K13x1FeexX/j0e3Te4J2uczPY8jn57ELr64WFd5MoOolQsSIm8Nypn2F86iAE'
    b'WC39EjohJiQPfcBg4qIIsS2CwXAA0WCACWoI719cg7/kfZhXUvY59EmqCYNSIN9+8O6DZz54'
    b'7eEI/v/g518C+3noLhkeJgAAAABJRU5ErkJggg==')

