#----------------------------------------------------------------------
# This file was generated by /Users/humberto.a.sanchez.ii/PycharmProjects/PyUt/venv-pyenv-3.9.0/bin/img2py
#
from wx.lib.embeddedimage import PyEmbeddedImage

embeddedImage = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAK3RFWHRDcmVhdGlvbiBUaW1l'
    b'AEZyIDIxIEZlYiAyMDAzIDExOjE3OjMyICswMTAwvynnCQAAAAd0SU1FB9MCGA0OEUv4dh4A'
    b'AAAJcEhZcwAACvAAAArwAUKsNJgAAAAEZ0FNQQAAsY8L/GEFAAABY0lEQVR42q1Tv0vEMBR+'
    b'Se+i0MXNsbuOvT9FHBSlR70cIji4ODq7iKiDZDoUVIqODnKLiyDYelMXf+zicA6OvbYmqalp'
    b'LHqgH7y+lzTfl++9UoA/Aqlitz8MiW272WgEv8VrHEd72/OtUmX/+j2MX9J8XNw/DPP1zSAU'
    b'3IZ4WIS4M9MYrp4BJvnOhAirqBuYv0dFVph1bJhyHLcUELYACPQDJokNHpiTltoUzo+ZrC1N'
    b'YK3jQZ6mYAgAzC1TsJufLqzCid+hhagmgPKk5FQELk+ZPCgI7RUKZz0m3YgWMPoS8H2/XmDB'
    b'K26zCXfBc7dLpRsTfI71Ahe8X8KJTR4ya7YppcAYK+usbgbCgbhdzUHvWxEVKg7SJJGL4IjJ'
    b'wZm3mxBCilMRMB38hEwXUIuT3ncHeu+6A3OI0eDxzd1Y9YrvjBBgjGWYvQvc3D6JFMmzanPr'
    b'8C7Ms2ysn0mQD3YWW/Af+ADDIemRfOJNcwAAAABJRU5ErkJggg==')

