#----------------------------------------------------------------------
# This file was generated by /Users/humberto.a.sanchez.ii/PycharmProjects/PyUt/venv-pyenv-3.9.0/bin/img2py
#
from wx.lib.embeddedimage import PyEmbeddedImage

embeddedImage = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAABhWlDQ1BJQ0MgcHJvZmlsZQAA'
    b'KJF9kT1Iw1AUhU9TpSIVRSuIOGSoulgQFXHUKhShQqgVWnUweekfNGlIUlwcBdeCgz+LVQcX'
    b'Z10dXAVB8AfEzc1J0UVKvC8ttIjxwuN9nHfP4b37AKFaZJrVNg5oum0mYlExlV4VA6/woQf9'
    b'GEWvzCxjTpLi8Kyve+qmuovwLO++P6tLzVgM8InEs8wwbeIN4ulN2+C8TxxieVklPiceM+mC'
    b'xI9cV+r8xjnnssAzQ2YyMU8cIhZzLay0MMubGvEUcVjVdMoXUnVWOW9x1opl1rgnf2Ewo68s'
    b'c53WEGJYxBIkiFBQRgFF2IjQrpNiIUHnUQ//oOuXyKWQqwBGjgWUoEF2/eB/8Hu2VnZyop4U'
    b'jALtL47zMQwEdoFaxXG+jx2ndgL4n4ErvekvVYGZT9IrTS18BHRvAxfXTU3ZAy53gIEnQzZl'
    b'V/LTErJZ4P2MvikN9N0CnWv1uTXOcfoAJGlW8Rvg4BAYyVH2use7O1rn9m9PY34/WhNynXF0'
    b'SXkAAAAGYktHRAD/AP8A/6C9p5MAAAAJcEhZcwAADsMAAA7DAcdvqGQAAAAHdElNRQflARAV'
    b'LiG6pyZXAAAB20lEQVRYw+1WwZXbIBD95O1ddGBYFxJKoROrhJSgElQC2wEqwNG4g1EF5LAe'
    b'h1WMBY42uey8x2H4An2YPzMAK/PeJwCfNq773+wb/rO9lABjHIxx2QwBIGitobUGM4OZH2xt'
    b'ruO6mgKIQhsB507ZzBuAAGMMvPdqGIZERA8IOADfb14IaCMgpjVD6yU7FTAMQ1qfXm7mo13A'
    b'3IFZt4fg98YLvDdK/NLJtdbw3qv1/DBQeooAUUAI7zeQK3ccx7uxvxJI6/lx/AFmfff6NwmU'
    b'Fv2TLHDOwTm3249CCAghtBE4nU67nvYegc1CRERQSqlpmo6XywXTNB1zX/TAzMjxxynaQMBa'
    b'q/q+TzHGszFGxRjPub8s7ym6LAty3Fqr/koDYvM8J2utijG+ElFi5qP3/qf4XdcBALquQ47P'
    b'85x2IWCMQUrpttnhcDhn7h+FqIQ/HYK1BiTmJW1I7AXf0kKzBiTmJW1I7AXf0kKzBiTmJW1I'
    b'7AXf0kKzBmq1UVpXTeBe0di7CG0S2JvEVy/YtReIrfO+VBeezoIs329vwb7vP+AppVT6TvDd'
    b'e0GO19SFT+8Ftd81a6C2J0isW98F1QS2eoLU/NZ3wUstga2eILFufRdUE6jtCa3vgq9e8Au2'
    b'7DRA5e6QQgAAAABJRU5ErkJggg==')

