#----------------------------------------------------------------------
# This file was generated by /Users/humberto.a.sanchez.ii/PycharmProjects/PyUt/venv-pyenv-3.9.0/bin/img2py
#
from wx.lib.embeddedimage import PyEmbeddedImage

embeddedImage = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAABhWlDQ1BJQ0MgcHJvZmlsZQAA'
    b'KJF9kT1Iw1AUhU9TpSIVBauIOGSoThZERRy1CkWoEGqFVh1MXvojNGlIUlwcBdeCgz+LVQcX'
    b'Z10dXAVB8AfEzc1J0UVKvC8ptIjxwuN9nHfP4b37AKFWYprVNgZoum2mEnExk10RQ68IoAd9'
    b'CKJfZpYxK0lJ+NbXPXVT3cV4ln/fn9Wl5iwGBETiGWaYNvE68dSmbXDeJ46woqwSnxOPmnRB'
    b'4keuKx6/cS64LPDMiJlOzRFHiMVCCystzIqmRjxJHFU1nfKFjMcq5y3OWqnCGvfkLwzn9OUl'
    b'rtMaQgILWIQEEQoq2EAJNmK066RYSNF53Mc/6Polcink2gAjxzzK0CC7fvA/+D1bKz8x7iWF'
    b'40D7i+N8DAOhXaBedZzvY8epnwDBZ+BKb/rLNWD6k/RqU4seAd3bwMV1U1P2gMsdYODJkE3Z'
    b'lYK0hHweeD+jb8oCvbdA56o3t8Y5Th+ANM0qeQMcHAIjBcpe83l3R+vc/u1pzO8HCityffgL'
    b'IvEAAAAGYktHRAD/AP8A/6C9p5MAAAAJcEhZcwAADsMAAA7DAcdvqGQAAAAHdElNRQflARAV'
    b'CAbccxAYAAABSklEQVRYw82W4Y3DIAyF7YoBGMUjMIpHyAYxGzACo3QERmED358Q3eUaJQG3'
    b'qaUoEiDx/PEwBjgIZlYA0OVvHg+4OU4LKKUAM2tKSW8TkHOGUoopAXd2YQgBQghQawVmViKC'
    b'aZrwYwRCCDDPM3jvTUlcNqGIoIiA997EE5cFqKpakui+hlYkugVYkRguRKMkhgWMkjArxb0k'
    b'zAT0kjB/jK6SMBdwlYSz2hgRUUTWbJ/P559XdO/tcIboVURevqKLCFsCLWMRQVVdMyciIKJ/'
    b'61+NDQloGf/G3jbKOePb6gAiYoxxPePROuCszrodQ4wRUkq7Z94toGW8dETreK0VYoyw9YJZ'
    b'tLa8fdv2vM2LiKqqLp443caf9gARATPvurnXC+6KgDPuvuqFx2jmbb55ARER7oheLzhrIdvb'
    b'cuSZj92WtxNoXjiq/V8XP/W1H4e21fP2AAAAAElFTkSuQmCC')

