#----------------------------------------------------------------------
# This file was generated by /Users/humberto.a.sanchez.ii/PycharmProjects/PyUt/venv-pyenv-3.9.0/bin/img2py
#
from wx.lib.embeddedimage import PyEmbeddedImage

embeddedImage = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAABhGlDQ1BJQ0MgcHJvZmlsZQAA'
    b'KJF9kTtIw1AUhv+mSkUqInYQcchQnSyIijpqFYpQIdQKrTqY3PQFTRqSFBdHwbXg4GOx6uDi'
    b'rKuDqyAIPkDc3JwUXaTEc5NCixgPHO7Hf89/OPdcQKiXmWZ1jAGabpupRFzMZFfF0CsC6KOc'
    b'RkhmljEnSUn4xtc9VVLcxXgv/7o/o0fNWQwIiMSzzDBt4g3iqU3b4LxPHGFFWSU+Jx41aUDi'
    b'R64rHr9xLrgs8J4RM52aJ44Qi4U2VtqYFU2NeJI4qmo69RcyHquctzhr5SprzslfGM7pK8tc'
    b'pxxCAotYggQRCqoooQwbMTp1Uiyk6D7u4x90/RK5FHKVwMixgAo0yK4f/A9+79bKT4x7ncJx'
    b'oPPFcT6GgdAu0Kg5zvex4zROgOAzcKW3/JU6MPNJeq2lRY+A3m3g4rqlKXvA5Q4w8GTIpuxK'
    b'QUohnwfez+ibskD/LdC95u2teY/TByBNu0reAAeHwEiBeq/7vLurfW//1jT39wM3E3KPaUPo'
    b'wQAAAAZiS0dEAP8A/wD/oL2nkwAAAAlwSFlzAAALEgAACxIB0t1+/AAAAAd0SU1FB+UBEQIL'
    b'Onnk7cwAAABTSURBVDjL7ZIxDgAhCAQHv8mDePZa2RA9zGlxxU0DCbBsCPAVlHJN6qqGqzil'
    b'LZoE2I71IZCbrdqcBXhwYOkG2hVfEhEC5O6yY7VTB29/RvzcowO+piA+6LC3hQAAAABJRU5E'
    b'rkJggg==')

