#----------------------------------------------------------------------
# This file was generated by /Users/humberto.a.sanchez.ii/PycharmProjects/PyUt/venv-pyenv-3.9.0/bin/img2py
#
from wx.lib.embeddedimage import PyEmbeddedImage

embeddedImage = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAAKnRFWHRDcmVhdGlvbiBUaW1l'
    b'AFNvIDUgT2t0IDIwMDMgMjM6NTA6MTAgKzAxMDCmmQ8LAAAAB3RJTUUH1QgQDgMk8/6hegAA'
    b'AAlwSFlzAAAK8AAACvABQqw0mAAAAARnQU1BAACxjwv8YQUAAAcZSURBVHjaxVd9bJVXGf+9'
    b'X/e2t/Tjwm1LOyobjtGBVIhIddEQOxAymWPMRFrn1mH/GKQNf5g4VGbMyP4xMEjKEuNCtimJ'
    b'kxnIssSohc2pgAgaiWuCYPlowfXzft/7fp/jc877sgLtxdvEZO/t6Xu+3vP8zu/3PM95X+AT'
    b'vpR7jf2IruHh4add1z2jadrriqJ83fO8f+i6/ivO+RcNw7h2+PDhq4cOHVJ7e3s5PcP/bwD2'
    b'7NnzdDQa/fnFixePOI7zeENDQ20ulxu3bbs+kUgkLctKFItFt7m5+Tjdv2qa5hgB2x+LxTry'
    b'+fxHBPgggdxMfdmhoaG3BgYGvNnsaKUANDU17r1x4/rY0aO/fuLhh5fdn0wm15hmYSVjvp7N'
    b'5r5i29Y3iRk/m81uI+O/JJC1xNDzBMyg9peJne/SBjalUqmt8Xj8MxcuXDhaNoBXXjnzciSS'
    b'+EZLy9rmZ555udOyiu0jIxeq1qx5Nq5o6mfHx68sampadZoxp6pQSH+ewOzVNPVmoVDcaNvm'
    b'Ds7ZKao/kcmkv0VzjjmOt6etre3k4ODg8N221NkA5POTnRs3PlXX07PVeO65B9seeWRpYmoq'
    b'ha5vf+3ZJ++Lt6fSWbS3dxxYv37HzkwmidbWLUeWL+/6caGQRUPD6t2LF2/Ybpp5zJvXsmnl'
    b'yl1F0yyaxaLZMZutWQF4HoNh6JKh8+fP4qWXfoDHHtuMFa3zceRP7yJeF0dPz3po2iDS6TwO'
    b'HNgR6+xcXT0xMYmursc/R2VtMjlFIL/UvWpV8zvkI7GamgcfLRsAOQ983xd3ZWoqifr6Buzc'
    b'uRNH334bf7h8ExQcOHHiBHbv/iG6u7djdHQc27ZtxbJly9HRsRYHD36fwEWwa1cXRkYGQFIQ'
    b'M63lh8aLLx6/8v77eX71qu0QCH7t2jU+OTnJReP085v4eDrLabd83779NDbML1/+N9+y5Ul+'
    b'7tx5furUWd7S8il+7Ng7/MMPL3FyZt7X9z3+wgvHP5jNlj5bJ20ejDGih8kwXdS8EKqqypht'
    b'q6uEUVuNCNW3d3fTTlXU1NXh1f5XoesG5i9YgIHfnUR1TQ0SiQa89rM3sbDpAbzxxmmUDYBz'
    b'Xxq7lFe0oTFq+xFq0y8KtNP9XAowHBFCcagENjJBc/R6GVKFHD1Zex9MVUHaBla3r0NyIkU+'
    b'FS0fgEhoHtHwUBXzFjfCuJWvRCbRyeLKOOCaVHyF5gEOozFVh0P1NAFzWSVsjwdzWAUKdhya'
    b'ivIB+D4H8xkYZ8qMyZ6HGgGRNFBolDPBWFBkO6yLhhgTfZOTHv7ozQFAsADHmAmlkIIkQBWG'
    b'KoClFKJXaGe6FfAiiobpuhoWRQ0WFzs3PTHG5uYDIgyrdY5F84hiWsAXNNOuVaroagDSJcrp'
    b'T949FhQxzxV1P3yG5tk5reQxVZIBn56uUDlqyQOEF8gNqIEnfDoabDtg6k4Zbm8roYBSgrky'
    b'QHGIUVNRrLT0SShi0UqSgLZ3lSRQzZn0f9xWAqyirtE/2wvBlQ+AooAAzNMZmiqnJXB1AYRJ'
    b'Q5JuHt796bagv7FK4pdtJv3BwIb1K5r6+8sEILYsElGUJJhPdPtasDtGs3XuYQmB4upd3n8b'
    b'7SrNj7w241VjadkMCPQCgMe44ofOxXgAQKMOU0AMaeWYBiLminZFJFjnWG8vCszC7wcH8YsP'
    b'zsxNAk4ApkyOsxOBR0sDFIZfID3OUJ9mBX7h82kAlPwkUBE54kp7ReRNE0XXQamrJABGJRHl'
    b'WNFARtyAWp+iwSCr6+rJmBUwJQzTEfAxiDAQ5OXTBJ86HdebKwAmJaDTOIgAJTQm9QnOCaE5'
    b'bst+s2iOgmXBdhzMj8WCjv67skEflHtI4OM/JkNyPPQBksEmCdbZHO+NkuFCAEBIsLgmeO54'
    b'bx+m3Lw8R0zbRpGMi/qyxkbs63xKAhcG/z4ygjf//NfSDMizgBZuqlTQuoCMhwyKPFCheNiw'
    b'kCQoTnu+ZoQ75pbUXLDn0JkhjDMqrng2eMFBhI51V8Tt//SB4KVAJhMW6spvhQim9RedLCT2'
    b'7NAQsgTApcGYYWBJIiGNj+VyuDQ6ighlJYMA3MxkygBAi4zZimLSYWR5QYKxo0IChpNjgQS3'
    b'ANwfStD/2/fuWGc/0S42MjQ+jhP//NfcokD86igTPlQNeeLI93cKr5ji4lGKDOSmE5CQwPoO'
    b'vyMSql5XgmigDv3Wy0DfzA+he0gQ0F+hBU4ojlcphYgOke30kIGwn9921ujhqjohDGgv+f1T'
    b'KhUzGcMqIXccTt8JJgoFB0VuoKJyCW785SNYqTRM04ZlOfIuSqEg7g7a2hbJdPC369elM95I'
    b'pUoCmPXbsKfnp7+hXLBCVY1KVdXyjPEMbSTDoWQQiWYU103TC0aGmMooipohrBlVlW06O1l2'
    b'795tm+vfqvnJjIX77vkx/Mlc/wUuxQSZPx4QZAAAAABJRU5ErkJggg==')

