#----------------------------------------------------------------------
# This file was generated by /Users/humberto.a.sanchez.ii/PycharmProjects/PyUt/venv-pyenv-3.9.0/bin/img2py
#
from wx.lib.embeddedimage import PyEmbeddedImage

embeddedImage = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAKnRFWHRDcmVhdGlvbiBUaW1l'
    b'AFNvIDUgT2t0IDIwMDMgMjM6NTk6MDEgKzAxMDAwUS/rAAAAB3RJTUUH1QgQDTkaFXDc8QAA'
    b'AAlwSFlzAAAK8AAACvABQqw0mAAAAARnQU1BAACxjwv8YQUAAAIjSURBVHjapZNLaFNBFIb/'
    b'uXNfeUAMkURJKqKIJrabaqHqQlxYWhXBtRBcSKAufCy6kK5UBDcWRJAoUsG9WyvougRc1JW2'
    b'+GiVLhRqTFvb3JvcmfFkUjEXEjcdGObe4fzfOf+ZGWCbg3X+lEqXs0qpZ57nBzR+2LYjTdP8'
    b'wBiWaa9G3xuu61bK5XLzr8bsBCQSw/dTqZxZqUwXksk936QUX1ZWls8CwX7O+VvH4eu1WvUM'
    b'hd7sCsjl+s+PjGTs3xuH+NrXxezxcxePff74HgsL88jnh/sYczZnZ2d+9gT4vodMeie7fuMq'
    b'Ps28gJdxMVA4TYC9eDc3hyNHB6NLS4dlpyYEkEJglcfBI3Ec2J3F6tBJiAaQT/fj4IkLMCxg'
    b'fvGN0RMQECBmKNgWg60aMEmgox1aFeDaQMwM9T0MEASwDKaDhZCoBwT1Ac4Bm6ZH1QwO7bN6'
    b'W5AC1bpkBjMQ8wOsk0ARJEmS1DRlbrkPEAIY4QokIlxRmVS1kthBoZkYZWFaiAelol7/Y6GN'
    b'dwhrKkG9ACKPWFtE2elyAVQVbkHpvTtgIYCSCr8owCDfcU/BDLYyXylqse/7mCyO6l7de/K6'
    b'2ykEcCgha00ZQFEzWxmvTT3XoMlLo7j7+BXQusjNLhaoBkQdzuJRskFHJ12yNaE0yLzN2hY8'
    b'Cpv694ZChzo+/vR7X25Xiux6bK3qbVpxr9lo1sfGBhKnXhbSOqug+TCs29b4Ax6q1zvJMoHc'
    b'AAAAAElFTkSuQmCC')

