#----------------------------------------------------------------------
# This file was generated by /Users/humberto.a.sanchez.ii/PycharmProjects/PyUt/venv-pyenv-3.9.0/bin/img2py
#
from wx.lib.embeddedimage import PyEmbeddedImage

embeddedImage = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAAK3RFWHRDcmVhdGlvbiBUaW1l'
    b'AERvIDE0IE5vdiAyMDAyIDIzOjMxOjQ0ICswMTAwhFAcSAAAAAd0SU1FB9MDBBYAJcMTIiMA'
    b'AAAJcEhZcwAACxIAAAsSAdLdfvwAAAAEZ0FNQQAAsY8L/GEFAAAF7UlEQVR42u1We1BUZRT/'
    b'3dcuj2UVlkUFVuUhYZohkU9SCBXNptFx0ho1x6nx1Zh/ZNrDHjM65eRk5l/Zy2xyRp0pIg0n'
    b'J01RAw0DCkJAHj6QZWGBfcA+772du5flMRpS+ld5Zs7st3fvd87v+53fOd8C9+3/bszf/7SD'
    b'RbYpF6K8BJI0DQw3GhzDQoYZPFsCTsiHn83Dqafd9x7A3B/nwNu8G8MMD+mTxmNsUhxiDCHg'
    b'OMBuF2FtNsNcXwf7zZYmRIa9iUMLv6RQ8r0BMKdgM0THzuhZOdxjaQZMMKih3T5AYAFDGAJA'
    b'rjuAkno3Lp0vkp2drT8hwrQCX82w3B2AnII1YLs/Tlm8hMkcA1zrAJookUwAQnhAS4k15AJ5'
    b'nA5IJnAWD3DqfC2qSv9sQFTyAuyfWP3vAMw+Pg6ipSxx6fKwJAOHylZKRicOF9TE2h4AirP0'
    b'nKOdLHlMOKAjVi5VWnD29IVmGONnY1967VABsL0ryb5dnzYtTB/OocKinjRMSwlD6PShtKbP'
    b'UHKBgAiUmGfVdxzEQDuxNCklBtk5U0bB2lSANXXR/4yB6fnx0DjqE55ZLvg8ahJGkmG7Ugmn'
    b'+Qa8rm6Z5XkMj4lmklPHYUyCEbJPZYAjIHwPoHACWlTWgJKympPQ6nKxP1MckG1TzVy47QsR'
    b'OuwC9ow7RE9klQG2bVHY2CRBpFrzRLnH2or6o4dd1rrGDzxd7FRZ0BhEhJisna5nLxSeunCi'
    b'oDBQBo2glkIBoYDxeYGsjATExkfnQKN9dUDyjZfTOY/l2LxHTJsMvO0g1v76dj8GPjscNWv+'
    b'0ghTHERnF26cyLNClzAH32eW3UqazGDVia2cxO1YtiibC9WyxJYKQgGj4dWgHx4544F+dAY+'
    b'TKzA1k4B5ksX1z81OW3NzEjkk0zf+eJUCw7kjFQZkJGqjTKC15CqLxbK1FJrb588gFnGgdyd'
    b'osaw/ptjZyWFeqVkQSagdAzFeXLGg1q42j8KbOlq3JKSNCJt/qRIHL+iCplQin0iZJhRgk4D'
    b'T5sDXoerAvlZ395RPZ9P/tQjanYXnClDqEbVQRCE5AemphoRGcFk46XS14jWbS/Om4Dym4BS'
    b'5stN1N88V9QPgKQRqJ7OpgaKoD2inmMIFtv8+vVrbSU1V9ug7Gd7WpMh95NIF09LYdDR9u6y'
    b'zAdCfD0RlWHW0GpTEJ/r14acX9nosVL/sVzhUFsIO5f4YDSt/aG4yq8Mp95SkJMskDJSh8Xz'
    b'0pGREB2YpMpzhf7aVruSpx8ABq0yKdhjtytD9/KQASi2N/U3mQk5cOb3q4HBFWBBEST95KVS'
    b'TEmMgl/qA6ZYs81lBxdbrqx5FQDb4LPbUyWPx4WkBOsdk26o0ENyxlK5XHC5XRDte4squlc8'
    b'/vAYbaAl0VcOWeori8LQ9Y5uWugvYk+ir48Bjil3tZqph3Q2fDJdHDT5uj82o/OmWcuIVYLf'
    b'2cjwPjNYvhQ+v6a00Ura6ksePHXwuyLU2habMkDOBcOpDLD8L87m68oUGvxuX1eephE73t++'
    b'cS6TFAW0OEm4XjA+kXqTiidJqnxZ5lZnemZEjbVLme9nBwIIlQq7re1uhOj9gwJwe0xRxnBm'
    b'nBE4Tw3j8asXFt/PuR4N9C9DkA2lA6ptLi98povBkGoJClbaIISfppVmUADd/Emz2Vq2YV8p'
    b'6qiXdXQ5aQU1MQPVg6cNei/99E6zg5TO6cvwXohzIICACQepNbSDAjiS3g1n7DRzl7zyu3PV'
    b'Z3YdOi/9XN4ID9UgXKtSzLJ9QAacnrRxmQYdDYxz/UPyvSsNnwcuPOuOHZA3ke5LfK24+HJ1'
    b'SnGdbXVx5bVVcXGRo2alxiNjbGRgGgbUjz4ASv9Xtbkoj3YAAOaOCYdiWzoE+JuegCS/ANaT'
    b'OzPZKMxJjYUpiu8V5nAq13NHayQ3FxeLV3Qt9xZAf3urJR7e9lVw2VbHGCMSF4wfxWQmRKLK'
    b'4sDuElsJtpkevfcM3M520X8NS3EWZO3zREEWDQELIuJW440RZXcf/L79l+wvBAcRVtqAmzgA'
    b'AAAASUVORK5CYII=')

