#----------------------------------------------------------------------
# This file was generated by /Users/humberto.a.sanchez.ii/PycharmProjects/PyUt/venv-pyenv-3.9.0/bin/img2py
#
from wx.lib.embeddedimage import PyEmbeddedImage

embeddedImage = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAAXNSR0IArs4c6QAAAGxlWElm'
    b'TU0AKgAAAAgABAEaAAUAAAABAAAAPgEbAAUAAAABAAAARgEoAAMAAAABAAIAAIdpAAQAAAAB'
    b'AAAATgAAAAAAAABgAAAAAQAAAGAAAAABAAKgAgAEAAAAAQAAABCgAwAEAAAAAQAAABAAAAAA'
    b'yJjDqAAAAAlwSFlzAAAOxAAADsQBlSsOGwAAAflJREFUOBFjYEAC////Z7G0tHzi6ek5C0kY'
    b'L5MJTZbxz58/Px49euRXWlqaiyaHlYtuwP9///791dXVFf/48WNNXl5eLtBVjFh1QgXRDWAA'
    b'GsDg6+v7Myoq6sGnT5+qgYYk4jMEwwCQwX///mW3t7c3i4iIePjhw4fWwsJCkCFY1bJgcx5Q'
    b'MVjY3d3dGMi+smTJkrbi4uJ/QPYiRkbGf8h6sBqApIDZw8NDi4mJ6frixYs7ysvLgWb8XwI0'
    b'5C9MDVZnwSShNIubm5ssMEzePn36dArQJZFnzpxhhakh5IIPQIU/U1JSPr19+1br1KlTDMrK'
    b'yos5OTm/AsXXgwzBagDUn28zMjLuxsbGCj5//lzu+/fvu4ABe4CFheU7Dw/PZZBmDAD0H4ux'
    b'sfHNmTNn/qyoqLipqqr6f/PmzR9v3bp1EmjQV6BL/NE1oYcBKNH8nzJlCtubN29eW1hYpEyd'
    b'OvUXMD0IfPny5RfQFVpz587lRTYE3YD/wsLCQrKysse0tLQyFy1atBCk+dmzZ2J9fX23gOmj'
    b'9dixY97IBqCHwV+grfG8vLxPi4qKLsvIyLDZ2tom9vf3TwSGvhTQi4xAV8BjANkgnOwjR47w'
    b'AnPoHzs7u/9AQyZNnjxZClkxuguQ5cBsDg6OHw4ODs6fP39mVlNTu5Senv4GWREA2WTcD2vq'
    b'MgUAAAAASUVORK5CYII=')

