#----------------------------------------------------------------------
# This file was generated by /Users/humberto.a.sanchez.ii/PycharmProjects/PyUt/venv-pyenv-3.9.0/bin/img2py
#
from wx.lib.embeddedimage import PyEmbeddedImage

embeddedImage = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAK3RFWHRDcmVhdGlvbiBUaW1l'
    b'AERpIDE2IEF1ZyAyMDA1IDEzOjU3OjUwICswMTAw0YaYRwAAAAd0SU1FB9MIDBEFIpcrTL4A'
    b'AAAJcEhZcwAACvAAAArwAUKsNJgAAAAEZ0FNQQAAsY8L/GEFAAACR0lEQVR42qWSXUhTYRzG'
    b'n3c7Z6sjqWVmGPSxtFBDIrIyjbJAIwj6gHYVMbEvDboIDCqEcgR1I9FFWyVDiqJyfpSSRVTe'
    b'zKNld7kPRIvy2DbP3HGb8+yIb0fDumizQc/Fn/fi/f94n+d9gP8UmT+IY372RVt7bWhaOcmk'
    b'LF0dkcYnwiPDLZTRXblabxYWBHjcbobn+Y7lhUUVGzbnYSToQHB6J/zeAB3ttAnRgK/0+o2b'
    b'X+IBNLPjA99Tk1awtaJUXdbCg90PS5CuuKBhOZJ+oHqVXqe3JHrBHECMyKbsgnx4ZzzwS35w'
    b'Wh04Rsa6FYMgGgaMYUv56arK7HgAZnbQlNQcKexA0aMSLGZ0qjGKXc+KMDWmoLWyG3LWWiKN'
    b'j69XrwpxAbGQJI6Ei1PeGPuQSljssW/H2yO98CkyBlwZQEgAIURMaCEsDHWIYwEMePMgMQwm'
    b'/bFfy99zsSjLgIjHMfi4ucWZEAAtWx9+1zQ6EdPQ3iEDnp7oRv/nZWC5NEx+bKdywLvydtOT'
    b'18+PFXMJe3DpYm2uTs8+IIYd2/SZa6gSkRB1vv8xMfqNNTdYM/vvn0PZy8Y2MjRlJC7E/gLM'
    b'60yVqVAKBnPkmCI6evt6Lly+ZtlIXaaDeyXAqcZg5zvB+46Sr5CTqurZupq06TLYqK2cUs95'
    b'SpsPUWrMeEXzwSUFmPtmNSt6eMk9enefCqmmEftxWtdgdf8J8R9Sfc6gNXQKnQ5LtMsNX+kt'
    b'kJD46XcPkoRQ2h6tNpfs36S13hkOeIXGpC0spJ9CUvihw/jnbAAAAABJRU5ErkJggg==')

