#----------------------------------------------------------------------
# This file was generated by /Users/humberto.a.sanchez.ii/PycharmProjects/PyUt/venv-pyenv-3.9.0/bin/img2py
#
from wx.lib.embeddedimage import PyEmbeddedImage

embeddedImage = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAAXNSR0IArs4c6QAAAGxlWElm'
    b'TU0AKgAAAAgABAEaAAUAAAABAAAAPgEbAAUAAAABAAAARgEoAAMAAAABAAIAAIdpAAQAAAAB'
    b'AAAATgAAAAAAAABgAAAAAQAAAGAAAAABAAKgAgAEAAAAAQAAABCgAwAEAAAAAQAAABAAAAAA'
    b'yJjDqAAAAAlwSFlzAAAOxAAADsQBlSsOGwAAAslJREFUOBGNU01LG1EUvZmZfBiizQcR4kg0'
    b'qcagBEpETAJSRGkx0CzyB9wE+kNc6i4UqS214KIgNHQhFHRVKoIkYrsoqUVDSU1UiIlNzPdM'
    b'puelOJC2iz54k/fue/fcc895IcJQFIULhUJJtvyfOTg4qMRisTDLFdiHDVmWyOOJkNv9kHj+'
    b'K2buhyxrbI1GwygIPHGcDrdm6fZWolzuLUlSs5unAiiKRJOTUVpaWr7o7z846HROpwuFEtdq'
    b'tchms37W6YynHBc2nZ3xj7e3P6JgrReA57WUSr2kq6uEUK2eDvf19TubzSbH8zxpNBozgIZ5'
    b'ftWgKB4ql/NgKPYCSJJCc3Mizc/P22VZsSOpimnA5DmOG2m326JOpxNKpQJtbaWp1ZJ7AZgG'
    b'i4uPOtFo9PX5+XmxVCrVIJZ9YmLiablcTiWTyXcLCwsxMHHv7LwnsOsFYDtJkjR6vX7Ebrf3'
    b'WSwWCRUtCNfRhmlsbGxSlmVTvV5nrnWT2YdTV1jgQCkUCt8zmcyVKIqRXC6X3d/ff7a3t/cG'
    b'oL7j4+PNm5ubbwBW01QXWIQxGBgYeDA6OnoLqoahoSF/p9Npu1yunzgbcTqdc2DggB5/A2i1'
    b'WorH45rd3d1pCAeRWoRKAdAmQRC6PWMfgh6UzWYJRbogKgN2MRwOUyQSqaBCA6d1dNQ0GAzj'
    b'ACtgz9oFgbq4srJCtdrvd6BqAKo0NTUlu93uTbB5Dhc2U6lUPBgMfoCwr0wm03qlUlmfmZn5'
    b'AoHxkP6wkfFBZd7hcCxZrdYMAIugfg8X7/v9fhN+NT6f7xNAPKy9u6EyYAFmD6qPp9Ppk6Oj'
    b'owuj0Rg8PDx8gbgelKuJROIEYv7bBbw2Am26vLzE27c9MZvNzXw+b4ady8ViUQQjORAI6K6v'
    b'r72sf5x3SagiMhfW1tZoY2ODqe66cwJxN6qy/wNzZfZOPK/X2wX4BaLZZI5jTh0zAAAAAElF'
    b'TkSuQmCC')

