#----------------------------------------------------------------------
# This file was generated by /Users/humberto.a.sanchez.ii/PycharmProjects/PyUt/venv-pyenv-3.9.0/bin/img2py
#
from wx.lib.embeddedimage import PyEmbeddedImage

embeddedImage = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAEinpUWHRSYXcgcHJvZmlsZSB0'
    b'eXBlIGV4aWYAAHja3VdJcgM3DLzzFXkCAXB9DjdU5Qd5fpqcxZYsKWPZySFDiwuIARtoEFM2'
    b'468/1fyBh12wxvmYQg7B4nHZZS6YJLs9ZfVk3erXw/sW1jdyc24wRIJRtmUKu/4hp9PANhTM'
    b'/CdDqe0b9XYju91+ujO0nywT0Zz33VDeDQlvG7QbKJtbNuQUP7tQxzb2w5O0/czsXLqF/WUd'
    b'Eb3ucY4wDyGx6Fl4AyDzR0YKJoSeRXiJlsSh93K4hIA8ipP9hMrcs3LO6In8jhQJm9xAcBvM'
    b'cI4P5eTv5LtBs0L86WRp58k3cp/P7LoJ8vyp9mRUx+ZdcQEhDbtThytrBsWKkMt6LaBF/Dzm'
    b'cbWMlgyyt4HybputaI0yMWhRctSpkNJYY6MGiI4HR4zMDaxMWZLImZtYA5bcbKQcJUuXBOYa'
    b'6BVI+cRC69y8jmuUcHAnaDLBGM1UMLP7jfbUkOpMeSKbzlgBF88kBIzJ3OyhBUJIjzzyK8BH'
    b'u38mrwIG/QpzgoPF1s1E9bTn1swjWUQLFD3G7a5R7LsBhAhne4AhAQM2kHgKZCNzJEIcE/gp'
    b'MJRYHFdQQN5zB0p2IgHkJJ5n451IS5c9b2LULBDhJUgENVkKuHIobMif6BJyqHjxznsffPTJ'
    b'Z1+CBBd8CCGGWfxKlOiijyHGmGKOJUlyyaeQYkom5VQyZ0Fx9DnkmFPOuRQcWmC54O0ChVIq'
    b'V6mu+hpqrKnmWhrSp7nmW2ixJdNyK527dNSJHnrsqedeBg2k0nDDjzDiSCOPokg1FXXqNWjU'
    b'pFnLyRqZjdYv7TprdLDGi6mpGE/W8GqMhwma5cRPzsAYOwLjcTKAhObJmU3kHJtJ3eTMZlQ2'
    b'8QyUfpLTaTIGBt0g9kondx/M3fBmnPsRb3wwZyZ1v8GcmdQ9Ye4rbw9Y6/Nr06yYxdC8hjOo'
    b'VnD9oFQ44Q/fpGPUZLkO1X26b2nVkayMuTL7Nh+Cd9fmXQNpm+qB3tgvblxwa/o0P7m7c1PX'
    b'YDOG2lvLlYOOLiMiSGAu9M5au7Yeg3DJXjJ3FPGIjPRqBzhpSJxZn6OGYCLHCmWoD7xb+gha'
    b'k5eSm6IkTVQV5R8f4oCjtDpw1RVU+hodcEYV3xMXb9xwFXVgWvexSfXryNyG69pzbnk5hQz2'
    b'WlYC5ToGuYHc7Oo28uDTvP0vXLL/6NHpkPmhR6dD5oVHz/w5+a8N13xPAfOa+uspYOzG/xh8'
    b'TFAYBF4Afq9V4WxPaSRamD/AtxBVGYEdfWifd0272+KBIJUtMLeWUmAp1s8gf0Q7Up74WsWA'
    b'UqDO2Cbq72ClYdtUy7GrhqGj0FNQuPELllm4fgJrgcIne+FasD7IGNRG/nQhr5BhrlzIK8ae'
    b'3v7HxeK5OXMlU05jL1aGL6u+Xpl9+S03Hnjxfqm9X5vjkB8b+hDYyy49Gs0z4r97gPkpkseG'
    b'bin9ljnzO3hg6L2I/DuIVkDMexF5cWm/N34NiPmdUL9j6EmKmN/Bc9HQlRT5zxBdvjT/0qX9'
    b'f5cRUfxbkPEt/xtjgtcEvAQmSwAAAYVpQ0NQSUNDIHByb2ZpbGUAAHicfZE9SMNQFIVPU6Ui'
    b'FQc7FHHIUJ0siIoILlqFIlQItUKrDiYv/YMmDUmKi6PgWnDwZ7Hq4OKsq4OrIAj+gLi5OSm6'
    b'SIn3JYUWMd7wyMd59xzeuw8QGhWmWV1jgKbbZjqZELO5VTH0igCiCNI3IzPLmJOkFHzr6566'
    b'qe7iPMu/78/qU/MWAwIi8SwzTJt4g3hq0zY47xNHWElWic+JR006IPEj1xWP3zgXXRZ4ZsTM'
    b'pOeJI8RisYOVDmYlUyOeJI6pmk75QtZjlfMWZ61SY61z8huG8/rKMtdpDSGJRSxBgggFNZRR'
    b'gY04/XVSLKRpP+HjH3T9ErkUcpXByLGAKjTIrh/8DX7P1ipMjHtJ4QTQ/eI4H8NAaBdo1h3n'
    b'+9hxmidA8Bm40tv+agOY/iS93tZiR0D/NnBx3daUPeByB4g+GbIpu1KQllAoAO9n9Ew5YOAW'
    b'6F3z5tbax+kDkKFZpW6Ag0NgpEjZ6z737umc2789rfn9AE1Ccpjs6S1dAAAPoGlUWHRYTUw6'
    b'Y29tLmFkb2JlLnhtcAAAAAAAPD94cGFja2V0IGJlZ2luPSLvu78iIGlkPSJXNU0wTXBDZWhp'
    b'SHpyZVN6TlRjemtjOWQiPz4KPHg6eG1wbWV0YSB4bWxuczp4PSJhZG9iZTpuczptZXRhLyIg'
    b'eDp4bXB0az0iWE1QIENvcmUgNC40LjAtRXhpdjIiPgogPHJkZjpSREYgeG1sbnM6cmRmPSJo'
    b'dHRwOi8vd3d3LnczLm9yZy8xOTk5LzAyLzIyLXJkZi1zeW50YXgtbnMjIj4KICA8cmRmOkRl'
    b'c2NyaXB0aW9uIHJkZjphYm91dD0iIgogICAgeG1sbnM6aXB0Y0V4dD0iaHR0cDovL2lwdGMu'
    b'b3JnL3N0ZC9JcHRjNHhtcEV4dC8yMDA4LTAyLTI5LyIKICAgIHhtbG5zOnhtcE1NPSJodHRw'
    b'Oi8vbnMuYWRvYmUuY29tL3hhcC8xLjAvbW0vIgogICAgeG1sbnM6c3RFdnQ9Imh0dHA6Ly9u'
    b'cy5hZG9iZS5jb20veGFwLzEuMC9zVHlwZS9SZXNvdXJjZUV2ZW50IyIKICAgIHhtbG5zOnBs'
    b'dXM9Imh0dHA6Ly9ucy51c2VwbHVzLm9yZy9sZGYveG1wLzEuMC8iCiAgICB4bWxuczpHSU1Q'
    b'PSJodHRwOi8vd3d3LmdpbXAub3JnL3htcC8iCiAgICB4bWxuczpkYz0iaHR0cDovL3B1cmwu'
    b'b3JnL2RjL2VsZW1lbnRzLzEuMS8iCiAgICB4bWxuczp0aWZmPSJodHRwOi8vbnMuYWRvYmUu'
    b'Y29tL3RpZmYvMS4wLyIKICAgIHhtbG5zOnhtcD0iaHR0cDovL25zLmFkb2JlLmNvbS94YXAv'
    b'MS4wLyIKICAgeG1wTU06RG9jdW1lbnRJRD0iZ2ltcDpkb2NpZDpnaW1wOmRmNGNlZTA5LWQx'
    b'OTQtNGM0ZC1hYTU5LTZmYjYyOTRkYzEwOCIKICAgeG1wTU06SW5zdGFuY2VJRD0ieG1wLmlp'
    b'ZDoyZDNlNjI0My04ZDM5LTQ0MDItYmVkOC1jYjM1M2JjY2E3OWIiCiAgIHhtcE1NOk9yaWdp'
    b'bmFsRG9jdW1lbnRJRD0ieG1wLmRpZDpmOGU5MTI2ZC0zYWM4LTQ5MWMtOTcyZi1hNTQzNzQ3'
    b'ZmU3YjciCiAgIEdJTVA6QVBJPSIyLjAiCiAgIEdJTVA6UGxhdGZvcm09Ik1hYyBPUyIKICAg'
    b'R0lNUDpUaW1lU3RhbXA9IjE2MTE0NTc0OTY0NTQwMDEiCiAgIEdJTVA6VmVyc2lvbj0iMi4x'
    b'MC4yMiIKICAgZGM6Rm9ybWF0PSJpbWFnZS9wbmciCiAgIHRpZmY6T3JpZW50YXRpb249IjEi'
    b'CiAgIHhtcDpDcmVhdG9yVG9vbD0iR0lNUCAyLjEwIj4KICAgPGlwdGNFeHQ6TG9jYXRpb25D'
    b'cmVhdGVkPgogICAgPHJkZjpCYWcvPgogICA8L2lwdGNFeHQ6TG9jYXRpb25DcmVhdGVkPgog'
    b'ICA8aXB0Y0V4dDpMb2NhdGlvblNob3duPgogICAgPHJkZjpCYWcvPgogICA8L2lwdGNFeHQ6'
    b'TG9jYXRpb25TaG93bj4KICAgPGlwdGNFeHQ6QXJ0d29ya09yT2JqZWN0PgogICAgPHJkZjpC'
    b'YWcvPgogICA8L2lwdGNFeHQ6QXJ0d29ya09yT2JqZWN0PgogICA8aXB0Y0V4dDpSZWdpc3Ry'
    b'eUlkPgogICAgPHJkZjpCYWcvPgogICA8L2lwdGNFeHQ6UmVnaXN0cnlJZD4KICAgPHhtcE1N'
    b'Okhpc3Rvcnk+CiAgICA8cmRmOlNlcT4KICAgICA8cmRmOmxpCiAgICAgIHN0RXZ0OmFjdGlv'
    b'bj0ic2F2ZWQiCiAgICAgIHN0RXZ0OmNoYW5nZWQ9Ii8iCiAgICAgIHN0RXZ0Omluc3RhbmNl'
    b'SUQ9InhtcC5paWQ6NWY3MDI4ZTEtMzJkYS00YzExLTgxZmEtNzNmYjI4YzhlM2QzIgogICAg'
    b'ICBzdEV2dDpzb2Z0d2FyZUFnZW50PSJHaW1wIDIuMTAgKE1hYyBPUykiCiAgICAgIHN0RXZ0'
    b'OndoZW49IjIwMjEtMDEtMjNUMjE6MDQ6NTYtMDY6MDAiLz4KICAgIDwvcmRmOlNlcT4KICAg'
    b'PC94bXBNTTpIaXN0b3J5PgogICA8cGx1czpJbWFnZVN1cHBsaWVyPgogICAgPHJkZjpTZXEv'
    b'PgogICA8L3BsdXM6SW1hZ2VTdXBwbGllcj4KICAgPHBsdXM6SW1hZ2VDcmVhdG9yPgogICAg'
    b'PHJkZjpTZXEvPgogICA8L3BsdXM6SW1hZ2VDcmVhdG9yPgogICA8cGx1czpDb3B5cmlnaHRP'
    b'd25lcj4KICAgIDxyZGY6U2VxLz4KICAgPC9wbHVzOkNvcHlyaWdodE93bmVyPgogICA8cGx1'
    b'czpMaWNlbnNvcj4KICAgIDxyZGY6U2VxLz4KICAgPC9wbHVzOkxpY2Vuc29yPgogIDwvcmRm'
    b'OkRlc2NyaXB0aW9uPgogPC9yZGY6UkRGPgo8L3g6eG1wbWV0YT4KICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgIAogICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgCiAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAKICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgIAogICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgCiAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAKICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgIAogICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgCiAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAKICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgIAogICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgCiAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAKICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'IAogICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgCiAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAKICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgIAogICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgCiAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAKICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgIAogICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgCiAgICAgICAgICAgICAgICAgICAgICAgICAgIAo8P3hwYWNrZXQgZW5kPSJ3Ij8+'
    b'Lm355QAAAAZiS0dEAP8A/wD/oL2nkwAAAAlwSFlzAAALEwAACxMBAJqcGAAAAAd0SU1FB+UB'
    b'GAMEOGy4tZIAAABVSURBVFjD7ZMxCgAgCAAt+v+XbWiVKJPCuIMGhULtLGKjEk+xks1zaZNp'
    b'M1Ues1iA6jjeOP8E7qOBmzB9iy9oJzv8tYTXRE09AcABwAHAAcABCHGgA6xsIwH1g5pVAAAA'
    b'AElFTkSuQmCC')

