#----------------------------------------------------------------------
# This file was generated by /Users/humberto.a.sanchez.ii/PycharmProjects/PyUt/venv-pyenv-3.9.0/bin/img2py
#
from wx.lib.embeddedimage import PyEmbeddedImage

embeddedImage = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAADXnpUWHRSYXcgcHJvZmlsZSB0'
    b'eXBlIGV4aWYAAHjavZZreusoDIb/s4pZApIQiOVgLs9zdnCWPx++tUnTNmk9Y2qEZSwJvYLU'
    b'9b9/hvsHF/sQXdBkMcfocYUcMhcMzG9XWXvyYe33B38MbvTufMFQCaRsjxb3+Yee/I0lKhjp'
    b'O0NW9xfL7Yscdvt2Z4g3ITOiOW67obwbEt5e0G6gbMvyMVt6v4Slb7IdK7HtdrMLdhv2h+eE'
    b'7DWFH2HuQuLRs/AWgMybnBQMCD1J4jnyGIsE9CzHUpGQR3ny76Jy91TOEX2iv4MicdM7KG6T'
    b'GU/5UE96p98NujXF7zxLPT3f6JfldHGT5HmP0cyN0bfVlRCR0rgv6ljKOsLEBSmX9bOIlnAr'
    b'xmltGc0cqrcCefPVL2iVMjEyPihQo0KD+iorVYQYuDOQMHMFqKkzIMpcxTtwCrPR4CRZmhho'
    b'VeCd5PiMhVa/eXVXyeC4EWYywRjNUnCzu6J9amiMWfJE3s5cIS6eRYgwJrnZYxaA0DjqSNcE'
    b'H+3+mlwFBHVNs2GBxS+biUVpr61ZR7KCFkxUyG2vUWq7AaQIvhXBkICAjyRKkXxiTkTIo4FP'
    b'gSFjCbwAAalyQ5QcRCLgGE/f+CbROpeVNzXOLIBQiZKAJksBq4CDDfWTgqGGiooGVY2a1DRr'
    b'iRJD1BhjivPwK0lSSJpiSslSTsXEgqlFS2bOspXMWXA4ao45Zcs5lwKnBZYLvi6YUMrCiyxh'
    b'0SUuabElL6WifGqoWmNN1VzNtTRu0nBOtNhSs5Zb6dRRSj107bGnbj33MlBqQ0YYOuJIw0Ye'
    b'5aRGbsP6oT1PjQ5qvJKaE9NJDZ+mdJigeZzoZAZiHAjE0ySAgubJzBuFwG6im8x8ZuwKZUSp'
    b'E06jSQwEQyfWQSe7N3I33FwIv+LGBzk30V1Bzk10n5D7yO0BtTZ/baoXtxKa23Am1Qu2HyYV'
    b'NvzhN+lrKf1N5b6dO54z6773+8D/A/PuZ599lO6KaKZ0V0TzZI6eM+uuiOaJHD1v1l0Rzes5'
    b'+kK6n/l/Itk/zZb7XRz/NbVX5SvHiH/2mHFX5OfO0G/K8QX83xr6XRyX1dFbGO6K7fFyHT1O'
    b'w6b9/zbtczCku2uYXfsrck0luWs2yFmQr5mRgX9nMo6OfwEl19KFhbRE0QAAAYVpQ0NQSUND'
    b'IHByb2ZpbGUAAHicfZE9SMNQFIVPU6UiFRU7iDhEqU4WREUctQpFqBBqhVYdTF76B00akhQX'
    b'R8G14ODPYtXBxVlXB1dBEPwBcXNzUnSREu9LCi1ivfB4H+fdc3jvPkCoFplmtY0Dmm6biVhU'
    b'TKVXxcArfOhFD4YwLDPLmJOkOFrW1z11U91FeFbrvj+rS81YDPCJxLPMMG3iDeLpTdvgvE8c'
    b'YnlZJT4nHjPpgsSPXFc8fuOcc1ngmSEzmZgnDhGLuSZWmpjlTY14ijisajrlCymPVc5bnLVi'
    b'mdXvyV8YzOgry1ynNYgYFrEECSIUlFFAETYitOukWEjQebSFf8D1S+RSyFUAI8cCStAgu37w'
    b'P/g9Wys7OeElBaNA+4vjfIwAgV2gVnGc72PHqZ0A/mfgSm/4S1Vg5pP0SkMLHwHd28DFdUNT'
    b'9oDLHaD/yZBN2ZX8tIRsFng/o29KA323QOeaN7f6OU4fgCTNKn4DHBwCoznKXm/x7o7muf3b'
    b'U5/fD2jncqNSfiE1AAAPoGlUWHRYTUw6Y29tLmFkb2JlLnhtcAAAAAAAPD94cGFja2V0IGJl'
    b'Z2luPSLvu78iIGlkPSJXNU0wTXBDZWhpSHpyZVN6TlRjemtjOWQiPz4KPHg6eG1wbWV0YSB4'
    b'bWxuczp4PSJhZG9iZTpuczptZXRhLyIgeDp4bXB0az0iWE1QIENvcmUgNC40LjAtRXhpdjIi'
    b'PgogPHJkZjpSREYgeG1sbnM6cmRmPSJodHRwOi8vd3d3LnczLm9yZy8xOTk5LzAyLzIyLXJk'
    b'Zi1zeW50YXgtbnMjIj4KICA8cmRmOkRlc2NyaXB0aW9uIHJkZjphYm91dD0iIgogICAgeG1s'
    b'bnM6aXB0Y0V4dD0iaHR0cDovL2lwdGMub3JnL3N0ZC9JcHRjNHhtcEV4dC8yMDA4LTAyLTI5'
    b'LyIKICAgIHhtbG5zOnhtcE1NPSJodHRwOi8vbnMuYWRvYmUuY29tL3hhcC8xLjAvbW0vIgog'
    b'ICAgeG1sbnM6c3RFdnQ9Imh0dHA6Ly9ucy5hZG9iZS5jb20veGFwLzEuMC9zVHlwZS9SZXNv'
    b'dXJjZUV2ZW50IyIKICAgIHhtbG5zOnBsdXM9Imh0dHA6Ly9ucy51c2VwbHVzLm9yZy9sZGYv'
    b'eG1wLzEuMC8iCiAgICB4bWxuczpHSU1QPSJodHRwOi8vd3d3LmdpbXAub3JnL3htcC8iCiAg'
    b'ICB4bWxuczpkYz0iaHR0cDovL3B1cmwub3JnL2RjL2VsZW1lbnRzLzEuMS8iCiAgICB4bWxu'
    b'czp0aWZmPSJodHRwOi8vbnMuYWRvYmUuY29tL3RpZmYvMS4wLyIKICAgIHhtbG5zOnhtcD0i'
    b'aHR0cDovL25zLmFkb2JlLmNvbS94YXAvMS4wLyIKICAgeG1wTU06RG9jdW1lbnRJRD0iZ2lt'
    b'cDpkb2NpZDpnaW1wOmZlZDg0M2ZhLTcwNTQtNDk3Mi05NGU4LTJkOGE3M2M4ZTE5MCIKICAg'
    b'eG1wTU06SW5zdGFuY2VJRD0ieG1wLmlpZDpjYzIzYzkxMy1mZTE2LTQ0ZWMtOTFkMC0zNDA4'
    b'YzE2YjhmOTMiCiAgIHhtcE1NOk9yaWdpbmFsRG9jdW1lbnRJRD0ieG1wLmRpZDowNmRhNTUw'
    b'OC1lNzZlLTQ3N2UtYjA4ZS05N2M0NWE2NWJjYTMiCiAgIEdJTVA6QVBJPSIyLjAiCiAgIEdJ'
    b'TVA6UGxhdGZvcm09Ik1hYyBPUyIKICAgR0lNUDpUaW1lU3RhbXA9IjE2MTA5MDEyNjg2MzEz'
    b'ODAiCiAgIEdJTVA6VmVyc2lvbj0iMi4xMC4yMiIKICAgZGM6Rm9ybWF0PSJpbWFnZS9wbmci'
    b'CiAgIHRpZmY6T3JpZW50YXRpb249IjEiCiAgIHhtcDpDcmVhdG9yVG9vbD0iR0lNUCAyLjEw'
    b'Ij4KICAgPGlwdGNFeHQ6TG9jYXRpb25DcmVhdGVkPgogICAgPHJkZjpCYWcvPgogICA8L2lw'
    b'dGNFeHQ6TG9jYXRpb25DcmVhdGVkPgogICA8aXB0Y0V4dDpMb2NhdGlvblNob3duPgogICAg'
    b'PHJkZjpCYWcvPgogICA8L2lwdGNFeHQ6TG9jYXRpb25TaG93bj4KICAgPGlwdGNFeHQ6QXJ0'
    b'd29ya09yT2JqZWN0PgogICAgPHJkZjpCYWcvPgogICA8L2lwdGNFeHQ6QXJ0d29ya09yT2Jq'
    b'ZWN0PgogICA8aXB0Y0V4dDpSZWdpc3RyeUlkPgogICAgPHJkZjpCYWcvPgogICA8L2lwdGNF'
    b'eHQ6UmVnaXN0cnlJZD4KICAgPHhtcE1NOkhpc3Rvcnk+CiAgICA8cmRmOlNlcT4KICAgICA8'
    b'cmRmOmxpCiAgICAgIHN0RXZ0OmFjdGlvbj0ic2F2ZWQiCiAgICAgIHN0RXZ0OmNoYW5nZWQ9'
    b'Ii8iCiAgICAgIHN0RXZ0Omluc3RhbmNlSUQ9InhtcC5paWQ6ZjE0NTE1MmMtYWIxYy00MTlj'
    b'LWEyZjAtMTAxOGUwN2Y5ODQwIgogICAgICBzdEV2dDpzb2Z0d2FyZUFnZW50PSJHaW1wIDIu'
    b'MTAgKE1hYyBPUykiCiAgICAgIHN0RXZ0OndoZW49IjIwMjEtMDEtMTdUMTA6MzQ6MjgtMDY6'
    b'MDAiLz4KICAgIDwvcmRmOlNlcT4KICAgPC94bXBNTTpIaXN0b3J5PgogICA8cGx1czpJbWFn'
    b'ZVN1cHBsaWVyPgogICAgPHJkZjpTZXEvPgogICA8L3BsdXM6SW1hZ2VTdXBwbGllcj4KICAg'
    b'PHBsdXM6SW1hZ2VDcmVhdG9yPgogICAgPHJkZjpTZXEvPgogICA8L3BsdXM6SW1hZ2VDcmVh'
    b'dG9yPgogICA8cGx1czpDb3B5cmlnaHRPd25lcj4KICAgIDxyZGY6U2VxLz4KICAgPC9wbHVz'
    b'OkNvcHlyaWdodE93bmVyPgogICA8cGx1czpMaWNlbnNvcj4KICAgIDxyZGY6U2VxLz4KICAg'
    b'PC9wbHVzOkxpY2Vuc29yPgogIDwvcmRmOkRlc2NyaXB0aW9uPgogPC9yZGY6UkRGPgo8L3g6'
    b'eG1wbWV0YT4KICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'IAogICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgCiAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAKICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgIAogICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgCiAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAKICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgIAogICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgCiAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAK'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgIAogICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgCiAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAKICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgIAogICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgCiAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAKICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgIAogICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgCiAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAKICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgIAogICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgCiAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgIAo8P3hwYWNrZXQgZW5kPSJ3Ij8+4zi33wAAAAZiS0dEAP8A/wD/oL2nkwAAAAlwSFlz'
    b'AAALEwAACxMBAJqcGAAAAAd0SU1FB+UBERAiHPANgMQAAABASURBVDjLY2TADv5jEWNkIBL8'
    b'J0WciYFCMPAGMNIiEIkJUNp54T8F3h4gL1BsADHO/0+N6PtPjYD7T41Qx5AHAEKCDwSsMq1l'
    b'AAAAAElFTkSuQmCC')

