#----------------------------------------------------------------------
# This file was generated by /Users/humberto.a.sanchez.ii/PycharmProjects/PyUt/venv-pyenv-3.9.0/bin/img2py
#
from wx.lib.embeddedimage import PyEmbeddedImage

embeddedImage = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAAK3RFWHRDcmVhdGlvbiBUaW1l'
    b'AERpIDE2IEF1ZyAyMDA1IDEzOjU3OjUwICswMTAw0YaYRwAAAAd0SU1FB9MCDg4kJAUUyA8A'
    b'AAAJcEhZcwAACvAAAArwAUKsNJgAAAAEZ0FNQQAAsY8L/GEFAAAG+UlEQVR42sWWa2wU1xXH'
    b'z73z2Mfs2tj4gQHHWDbEtfOoQhqnQOOYAFZToIaIOumHSEWq4AuVQMhCVVoUKVFVtVWVNv1A'
    b'86FVkRrXjlpViVUaSrBkiLE3dox52IDfD+y1WXt37d2ZnbmPnlmbqEVtxQZQr3T2zuzMnfM7'
    b'/3vuuRfg/9zIf3tw+vRpTdf1fY5t72eO8zXTMvMdx+GOw2Ydxi6lUqlmn8/3t8bGRvHQAXp7'
    b'e785MT7+q5HhoVKTS9OXV5RQgzlcEkJYPEqT4YmAsxTzOBKuGYZx+MSJE5ceGkDf5cs/unKl'
    b'7+TIXCTxVF19OL+kxHKYBIcLYtmS2IwQi0sanxg2lnr+kRuZGlM9fuPIyZMn3/syAMo9kZ/o'
    b'+Sz0VjK4enbf915fWJe7Sg1Q4TGAe6hECMaArRjxZTmy7NlEQAUtMnTtlRe3vzTc3t7e96UB'
    b'erq7twxcv/6HuJE7t+eVvSZlQvEQqSlSKkCpBJAKBi4Zl5K5MA4ngjNw8srNPJ+qTfZ/vvf5'
    b'r29p6ezsnM8EgN69WFhY+PlgOGLV1O9ddGxOAwSMLEqDXoXoJheODeBoRFIGINC/TM8dXhBm'
    b'ksXSb0Q2Vj6t2Zb1k0wVSAO0trZW3+y/9vzG7d8KE5urHiCaCqAKEKBhjzKpqLrgQAQOoEJI'
    b'Il3/SMFREUNxqPbUjqimkG8fOnSoJGOAWDS6L2YxO/uxMgvjI1wIWHCEaXMpUhx4ghE7hY4s'
    b'xiQTGD6O4fgjcF2gCKArhIS1wmRpaSm1LHN3JgCq+2Oa5mYlpzBpYoqb+GlVUL52m17scHyG'
    b'mgccyFOwt9DcOfChGSv3t86MDwbVANGpAsb6jTbvu/JMxgBIvYauLmQsJUhUCkaBEtd5Ts0W'
    b'yGEOgG0vGyYd2Kkv7j+4OA8zEyP6qvIyiikjvdkFjNlOUcZTwN0PY5GxhSCmI+Tkkp1yIwfX'
    b'OU5+2nBa0vduv2Jul0wmKCYnLhYCVFHwv8wKY1oB23Zui0S82HEIiTm47hDLQl+3zobARiW4'
    b'WJbbXuldddyeL2ci8VFKFy3MjaU7GuP8dsYADuMhMj/9oslRBc6kTgn5uOX2zdnxYTVlJqm7'
    b'6tzAMA8JR+duIjIBJMUkKcoKaghGXKDE1JBGKO3KGEDTtL9YS9EfmuFRv7qq0HRwKYCqQ1ZR'
    b'CQeJi85VX6YdI8AyjInOcRUqlWv8ZDSuONX50v9RRwdDMVozzoHjx493E1Vvl1c+ybPAS1B+'
    b'ksLpEKofhBaQQg9IqRtAvdh7ApLjve4LkKfX5+oJ6RXhlCLh+t+zItH4X1taWqYyAfiiFO/c'
    b'uasvOjv1/Wwv1RZzSi3OGGFu5Fh/0YiD5d9my7Jn60Qvz/F446h9d5g7DQWRvN/87C09Oyd3'
    b'3datW6/V19c3PlddPXjxwoW5+wY4d+7c9M5ddfPxsf76AizAUX9JioCkqquSBKqpRAl6FG1d'
    b'QNENTVFGoo4YjhH+auFC3i/e+IHv5d17SVVVlTcYDL5WVPzYM9OTY+zTjktn7hvAbW1tbaFt'
    b'L9REZ29cfnmDGtNpVgGdEwEmMLMw42kyJclUgoiRJSGeyFU9VZELgV++/WNf7Y5d5ODBg6Cq'
    b'KlRWPUl6Otth9/l3njy1yu58Mwwj/wvgPx5Ijh07tjUei/46aPgeL99UYXvXVqS01YWWSlSh'
    b'mBEtNdnv+aStTQ/PRa4agWBObW1tZVlZGdTV1UFT0x/hK6OnoCgeh8DVCdM/HdlPPoMzGQHc'
    b'TdDDhw/vMJOJ/Yw5zzKHFQgs/ngwuY31P+TxeJqxXWhoaFiDzgcOHGjIHhgchAreDJvyKfjD'
    b'cYAx3Jm7By0YmfsO6YYPMwW4r3b06NFXKyor348nU/DcnQ9g8wtrwSjIxqKAJXsUc3DiDkIM'
    b'pWBo9rsI8ed7x6sPCoDr/vzAyHhzzcXf126o8uX7xj24U6H50DbkuyXeNdzhaZNUZl4nXdD0'
    b'UBW422QlVEXyjHOrt5UVQhnuR4+jGd7lmj62okTPCIPB6YMkBKfvjlMexOm/tjfnYO6nhU4r'
    b'RJb2gUcPusUUsnwAflQi6F2O1fBQsBJ7ap+o1gN1ByJdHZ+GH3gK/k3OLuiXX01sh65bZ/G4'
    b'VpzexSrWLYOkp4PBVf6S2pu7+43g8MBrOKScPrDXeyF64QYsJrdD6OYYDM0ADEzikSsJgEJE'
    b'12+G2S2NULY2T9q2/Tv3/YcOkIYIwSDMW6jE4CjcciEmYHaSQrT4CFRtKoHuUAhisdjFRwaw'
    b'osQwpKwa6LoxFBmIwtmlOlCJDc1/anJ3Xzf5jUcKkIbogHHct+veDeyRhqHDe789JTFymJmZ'
    b'aff7/R+n33mUAG57+513aXhs+Dye2ex4PH5EUZQA9p83NTXxR+37vto/Add4nsxxMlygAAAA'
    b'AElFTkSuQmCC')

