#----------------------------------------------------------------------
# This file was generated by /Users/humberto.a.sanchez.ii/PycharmProjects/PyUt/venv-pyenv-3.9.0/bin/img2py
#
from wx.lib.embeddedimage import PyEmbeddedImage

embeddedImage = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAK3RFWHRDcmVhdGlvbiBUaW1l'
    b'AERvIDE0IE5vdiAyMDAyIDIzOjMxOjQ0ICswMTAwhFAcSAAAAAd0SU1FB9MCGwAUCxzaSQIA'
    b'AAAJcEhZcwAACxIAAAsSAdLdfvwAAAAEZ0FNQQAAsY8L/GEFAAACUUlEQVR42sWTXUiTURjH'
    b'/+/XdO+as40c4ta3QWWQK7FPRGLdeFHQxeiqD4KEjaBoUUHihRdFSBhIVtRFEDS7MQcVZIVC'
    b'RTCzafMrar2u2nIuN7f57ut9384GDoyom6IHDpznnOf/e57znHOA/23Ub3etTysgBc9pK437'
    b'S1hWPxOM+Di1ujf7oOninwEHh7YtM4g9bUe2G7MMIMSAlyFgdCiMWY+3E31WRz6M+aX40GTN'
    b'apP0rMux1dA7CQxPA4E4kEgD9FINZFZVJxv3BuXxu4NsQXBirGUJX1KbCHy0Qcow2rJo97Xm'
    b'Op1rBGBpknXwXXpKmHlCyRRfbq5qMGxey8Q8A01EeaMA2L2SumDbtYp1dPqdUDjV1aNb1vf7'
    b'AV4F9Lo9gXiOscPV6FZIbMLWf5LT6trVphU7ReLTecC3REpYrgdqa8znN2wyndLxNHIk+rVv'
    b'Kjcnsc50l8W9cLqsq+FK9FPAw2k0+rxfqOBDOOWlZKw5UF/NU4qEYdIsRVLwZiJ0X7pe7/q5'
    b'RVIyNkqX6CxYqICSJG9wLgc1R+YUg6oy4LHnPSAmK5jmwR7Y/YcXAbJ4mwxPfy4COLZ09qEv'
    b'AhMRcnQ+O2C3rkPr8cY9bccs+zaaqFtwRsqKBJoWZSk1XgSI5u5OIU7FS8mlcmQkCGBeBnxC'
    b'FDfd4+JESLyDy4a5IoBhGFrFDRR7AOcl+WvH6RE9jx2B7yIejSXwSpj3J2eifWnaeAYdldFF'
    b'TaDLn2djU4FFL5FrFc5WazMtE1+iLxhKfS/TXnObLCv/5AP9VfsBefzjkDmDLj0AAAAASUVO'
    b'RK5CYII=')

