#----------------------------------------------------------------------
# This file was generated by /Users/humberto.a.sanchez.ii/PycharmProjects/PyUt/venv-pyenv-3.9.0/bin/img2py
#
from wx.lib.embeddedimage import PyEmbeddedImage

embeddedImage = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAAA8AAAAPCAYAAAA71pVKAAABhWlDQ1BJQ0MgcHJvZmlsZQAA'
    b'KJF9kT1Iw1AUhU/TSotUFCwi4pChOlkQFXHUKhShQqgVWnUweekfNGlIWlwcBdeCgz+LVQcX'
    b'Z10dXAVB8AfEzc1J0UVKvC8ptIjxwuN9nHfP4b37AKFRZpoVGAc0vWqmEnExk10Vg6/woQ8D'
    b'CCAkM8uYk6QkPOvrnrqp7mI8y7vvz+pRcxYDfCLxLDPMKvEG8fRm1eC8TxxhRVklPiceM+mC'
    b'xI9cV1x+41xwWOCZETOdmieOEIuFDlY6mBVNjXiKOKpqOuULGZdVzluctXKNte7JXxjO6SvL'
    b'XKc1jAQWsQQJIhTUUEIZVcRo10mxkKLzuId/yPFL5FLIVQIjxwIq0CA7fvA/+D1bKz854SaF'
    b'40DXi21/jADBXaBZt+3vY9tungD+Z+BKb/srDWDmk/R6W4seAb3bwMV1W1P2gMsdYPDJkE3Z'
    b'kfy0hHweeD+jb8oC/bdA95o7t9Y5Th+ANM0qeQMcHAKjBcpe93h3qHNu//a05vcD7EZyccBA'
    b'tS4AAAAGYktHRAD/AP8A/6C9p5MAAAAJcEhZcwAACxIAAAsSAdLdfvwAAAAHdElNRQflARAW'
    b'BQZrm9AMAAAAaElEQVQoz62S0Q3AIAgFH4Yl3MbRu03HwJ+aYC0Ibfkz8d4BCnwoup0lc3+B'
    b'j/OZb5UWpmTavILlFazsAgCctE4hHLDA2gNboAXoKlaLrdJkD8MjYISk4J3RnVkbvdk58jR/'
    b'/W2PzVUHml4lxjJDvWkAAAAASUVORK5CYII=')

