#----------------------------------------------------------------------
# This file was generated by /Users/humberto.a.sanchez.ii/PycharmProjects/PyUt/venv-pyenv-3.9.0/bin/img2py
#
from wx.lib.embeddedimage import PyEmbeddedImage

embeddedImage = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAADsnpUWHRSYXcgcHJvZmlsZSB0'
    b'eXBlIGV4aWYAAHja1VZbsuwmDPzXKrIEJPEQywEMVdlBlp/G9jjH87jX58xUKjHDwzI0olvA'
    b'UP/rz0F/4BGXPfmQLOYYHR6ffZaChrntKWvJzq/l/uJujZOdjg8Ck6LW7dXi3v9mZ3dC4oJW'
    b'+AJkbf9Qzx+y3/HtDki2SqdHs73sQHkHUtk+8A5QtmW5mC19XULtW73cVmJbpll4O7v98J7A'
    b'3hIwj4p0ZXUoRWVzQGdm0oIGo2RNMlt7G6Wo7WAg5BlP7otXdK/K0eIX9jtRNG52guFMZjzq'
    b'p3YOd/YdkFaKv8ys7Zj5ZO/1mOJE8sxjLEZj9G11xUdQGvdF3ZayttCxgnJdh0WkhBzQTmvK'
    b'SEaI3gbJF9dcRWqcWSDLYM8LFx7c17pxg4teukASEWkQatoMEmVp6ggK+Zl4SNKsixrUapBX'
    b'YZXDF17nzet0jQ0TL4yewgDjGQo0i0+kl0BjzJBndnZwBb9kBiHcmMrNEr0gCI9bHIWV4Fu6'
    b'f6auCgXDSrNhgcXVDaIG3mNrxpGuQis6BtTbXuO07ACgCHMHOIOo9+wia+DILokkZvBo0KcA'
    b'yES9VEjAIcgCL8WrRohjMufGmMRrXwmymXFmQYigERvJIFCBVvNgQ/wkb4ihEjT4EEIMKVjI'
    b'oUSNPoYYY4rz8CtJk08hxZSSpZyKqXkLFi2ZkWUrWbLicAw55pQt51wKJi1ALhhd0KGUKlWr'
    b'r6HGmqrVXEtD+DTfQostNaOWW1lk0QXnxBKXtNiSl9K5I5S676HHnrr13MtAqA0dfoQRRxo2'
    b'8iiHakybrA/pump8U01WpWbHdKiGoSndIHgeJ2FqBsXEMxRPUwEEtEzNnLH3QlO6qZnLgl0R'
    b'BF6GKc7CUzEo6DtLGHxo949yJ93I+7d0k5tyNKX7hHI0pXuh3KNuT1Rb5m3TnNKq0NyGk1Sn'
    b'2H7oVMTww510vabvDvhfAM2zwROya+t7mRf9j2v6yUCfcGd5uBCwI3bv6BP8/BJI+xgnEiYH'
    b'83Dem23UWlYHh3ktjb5LB4bFbXytmt0BRxve5WGj7zTtHLkbXQS+tPe+rqF2nnf8j1iiyQbz'
    b'jtNb97+Bfeg9xg50hcm34+gVs2f4tRddYvICkfTD+Hugik7zPGHyalDSRS5/W9MvuD3MV8ij'
    b'98Lw0qZ9HnivyKLvBt6HAvI1WfShPYv/2d8OveexRQdfbwYTXT8aHwn6egH8qxckX1k+vb3J'
    b'/uNAA3+YMk65vwGZnvBNCUlTKwAAAYVpQ0NQSUNDIHByb2ZpbGUAAHicfZE9SMNQFIVPU0WR'
    b'ioodRBwyVEGwICriqFUoQoVQK7TqYPLSP2jSkKS4OAquBQd/FqsOLs66OrgKguAPiJubk6KL'
    b'lHhfUmgR4w2PfJx3z+G9+wChVmKa1TYOaLptJuMxMZ1ZFTteEUAffb0YlZllzElSAr71dU/d'
    b'VHdRnuXf92d1q1mLAQGReJYZpk28QTy9aRuc94nDrCCrxOfEYyYdkPiR64rHb5zzLgs8M2ym'
    b'kvPEYWIx38JKC7OCqRFPEUdUTad8Ie2xynmLs1aqsMY5+Q1DWX1lmeu0hhDHIpYgQYSCCooo'
    b'wUaU/jopFpK0H/PxD7p+iVwKuYpg5FhAGRpk1w/+Br9na+UmJ7ykUAxof3Gcj2GgYxeoVx3n'
    b'+9hx6idA8Bm40pv+cg2Y+SS92tQiR0DPNnBx3dSUPeByBxh4MmRTdqUgLSGXA97P6JkyQP8t'
    b'0LXmza2xj9MHIEWzStwAB4fASJ6y133u3dk6t397GvP7AVJkcprCvuxqAAAPoGlUWHRYTUw6'
    b'Y29tLmFkb2JlLnhtcAAAAAAAPD94cGFja2V0IGJlZ2luPSLvu78iIGlkPSJXNU0wTXBDZWhp'
    b'SHpyZVN6TlRjemtjOWQiPz4KPHg6eG1wbWV0YSB4bWxuczp4PSJhZG9iZTpuczptZXRhLyIg'
    b'eDp4bXB0az0iWE1QIENvcmUgNC40LjAtRXhpdjIiPgogPHJkZjpSREYgeG1sbnM6cmRmPSJo'
    b'dHRwOi8vd3d3LnczLm9yZy8xOTk5LzAyLzIyLXJkZi1zeW50YXgtbnMjIj4KICA8cmRmOkRl'
    b'c2NyaXB0aW9uIHJkZjphYm91dD0iIgogICAgeG1sbnM6aXB0Y0V4dD0iaHR0cDovL2lwdGMu'
    b'b3JnL3N0ZC9JcHRjNHhtcEV4dC8yMDA4LTAyLTI5LyIKICAgIHhtbG5zOnhtcE1NPSJodHRw'
    b'Oi8vbnMuYWRvYmUuY29tL3hhcC8xLjAvbW0vIgogICAgeG1sbnM6c3RFdnQ9Imh0dHA6Ly9u'
    b'cy5hZG9iZS5jb20veGFwLzEuMC9zVHlwZS9SZXNvdXJjZUV2ZW50IyIKICAgIHhtbG5zOnBs'
    b'dXM9Imh0dHA6Ly9ucy51c2VwbHVzLm9yZy9sZGYveG1wLzEuMC8iCiAgICB4bWxuczpHSU1Q'
    b'PSJodHRwOi8vd3d3LmdpbXAub3JnL3htcC8iCiAgICB4bWxuczpkYz0iaHR0cDovL3B1cmwu'
    b'b3JnL2RjL2VsZW1lbnRzLzEuMS8iCiAgICB4bWxuczp0aWZmPSJodHRwOi8vbnMuYWRvYmUu'
    b'Y29tL3RpZmYvMS4wLyIKICAgIHhtbG5zOnhtcD0iaHR0cDovL25zLmFkb2JlLmNvbS94YXAv'
    b'MS4wLyIKICAgeG1wTU06RG9jdW1lbnRJRD0iZ2ltcDpkb2NpZDpnaW1wOjIyZmM0ZGJlLTIz'
    b'NjEtNDA5Ni1hZmQ5LTc0YWEyYjJiZjE3NyIKICAgeG1wTU06SW5zdGFuY2VJRD0ieG1wLmlp'
    b'ZDo4ZGNhYmFhYy05NDZjLTRiYjAtYjRhNS1mY2U3MWQwOTA0NzUiCiAgIHhtcE1NOk9yaWdp'
    b'bmFsRG9jdW1lbnRJRD0ieG1wLmRpZDowNzQ5YmNhNS01NDcwLTQ1ZWItOGU3Zi00NjkzY2Nj'
    b'YmZiYWIiCiAgIEdJTVA6QVBJPSIyLjAiCiAgIEdJTVA6UGxhdGZvcm09Ik1hYyBPUyIKICAg'
    b'R0lNUDpUaW1lU3RhbXA9IjE2MTA5MDM4NTA0ODI1ODUiCiAgIEdJTVA6VmVyc2lvbj0iMi4x'
    b'MC4yMiIKICAgZGM6Rm9ybWF0PSJpbWFnZS9wbmciCiAgIHRpZmY6T3JpZW50YXRpb249IjEi'
    b'CiAgIHhtcDpDcmVhdG9yVG9vbD0iR0lNUCAyLjEwIj4KICAgPGlwdGNFeHQ6TG9jYXRpb25D'
    b'cmVhdGVkPgogICAgPHJkZjpCYWcvPgogICA8L2lwdGNFeHQ6TG9jYXRpb25DcmVhdGVkPgog'
    b'ICA8aXB0Y0V4dDpMb2NhdGlvblNob3duPgogICAgPHJkZjpCYWcvPgogICA8L2lwdGNFeHQ6'
    b'TG9jYXRpb25TaG93bj4KICAgPGlwdGNFeHQ6QXJ0d29ya09yT2JqZWN0PgogICAgPHJkZjpC'
    b'YWcvPgogICA8L2lwdGNFeHQ6QXJ0d29ya09yT2JqZWN0PgogICA8aXB0Y0V4dDpSZWdpc3Ry'
    b'eUlkPgogICAgPHJkZjpCYWcvPgogICA8L2lwdGNFeHQ6UmVnaXN0cnlJZD4KICAgPHhtcE1N'
    b'Okhpc3Rvcnk+CiAgICA8cmRmOlNlcT4KICAgICA8cmRmOmxpCiAgICAgIHN0RXZ0OmFjdGlv'
    b'bj0ic2F2ZWQiCiAgICAgIHN0RXZ0OmNoYW5nZWQ9Ii8iCiAgICAgIHN0RXZ0Omluc3RhbmNl'
    b'SUQ9InhtcC5paWQ6M2JlNzgwOGYtZDI1Yi00Mzc1LWEwOGUtYTJiOTBiMTI2MmFkIgogICAg'
    b'ICBzdEV2dDpzb2Z0d2FyZUFnZW50PSJHaW1wIDIuMTAgKE1hYyBPUykiCiAgICAgIHN0RXZ0'
    b'OndoZW49IjIwMjEtMDEtMTdUMTE6MTc6MzAtMDY6MDAiLz4KICAgIDwvcmRmOlNlcT4KICAg'
    b'PC94bXBNTTpIaXN0b3J5PgogICA8cGx1czpJbWFnZVN1cHBsaWVyPgogICAgPHJkZjpTZXEv'
    b'PgogICA8L3BsdXM6SW1hZ2VTdXBwbGllcj4KICAgPHBsdXM6SW1hZ2VDcmVhdG9yPgogICAg'
    b'PHJkZjpTZXEvPgogICA8L3BsdXM6SW1hZ2VDcmVhdG9yPgogICA8cGx1czpDb3B5cmlnaHRP'
    b'd25lcj4KICAgIDxyZGY6U2VxLz4KICAgPC9wbHVzOkNvcHlyaWdodE93bmVyPgogICA8cGx1'
    b'czpMaWNlbnNvcj4KICAgIDxyZGY6U2VxLz4KICAgPC9wbHVzOkxpY2Vuc29yPgogIDwvcmRm'
    b'OkRlc2NyaXB0aW9uPgogPC9yZGY6UkRGPgo8L3g6eG1wbWV0YT4KICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgIAogICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgCiAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAKICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgIAogICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgCiAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAKICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgIAogICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgCiAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAKICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgIAogICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgCiAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAKICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'IAogICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgCiAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAKICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgIAogICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgCiAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAKICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgIAogICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgCiAgICAgICAgICAgICAgICAgICAgICAgICAgIAo8P3hwYWNrZXQgZW5kPSJ3Ij8+'
    b'44PVPQAAAAZiS0dEAP8A/wD/oL2nkwAAAAlwSFlzAAALEwAACxMBAJqcGAAAAAd0SU1FB+UB'
    b'ERERHuuq7u8AAABRSURBVDjLY2AY8oARSv8nVz8LjPXvTwVOVUwsHRjyTCwdEJoYa/79qYBr'
    b'wDCcWLfiMoSJFA9jM4SJ1FBDN4SJnKBHDlAmStMB04AnpKGflxgAtm0Wh1G4rz0AAAAASUVO'
    b'RK5CYII=')

