#----------------------------------------------------------------------
# This file was generated by /Users/humberto.a.sanchez.ii/PycharmProjects/PyUt/venv-pyenv-3.9.0/bin/img2py
#
from wx.lib.embeddedimage import PyEmbeddedImage

embeddedImage = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAABhWlDQ1BJQ0MgcHJvZmlsZQAA'
    b'KJF9kT1Iw1AUhU9TpSIVETuIOGSoThZERcRJq1CECqFWaNXB5KV/0KQhSXFxFFwLDv4sVh1c'
    b'nHV1cBUEwR8QNzcnRRcp8b6k0CLGC5f3cd47l/fOA4R6mWlWxxig6baZSsTFTHZVDL0igD5q'
    b'ETMys4w5SUrCt77u6STVXYzP8j/3Z/WoOYsBAZF4lhmmTbxBPLVpG5z3iSOsKKvE58SjJl2Q'
    b'+JHrisdvnAsuC3xmxEyn5okjxGKhjZU2ZkVTI54kjqqaTvOFjMcq5y3OWrnKmvfkLwzn9JVl'
    b'rlMPIYFFLEGijBRUUUIZNmK06qRYSNF+3Mc/6PolcinkKoGRYwEVaJBdP/gf/M7Wyk+Me5PC'
    b'caDzxXE+hoHQLtCoOc73seM0ToDgM3Clt/yVOjD9SXqtpUWPgN5t4OK6pSl7wOUOMPBkyKbs'
    b'SkFqIZ8H3s/om7JA/y3Qvebl1tzH6QOQpqySN8DBITBSoNnrPu/uas/t3zPN/H4AfJFyq461'
    b'vrwAAAAGYktHRAD/AP8A/6C9p5MAAAAJcEhZcwAADsQAAA7EAZUrDhsAAAAHdElNRQflAREB'
    b'ITdqeOMAAAAANklEQVQ4y2NgGAWkgP/YBBnJNICRLAP+/4eYwciI0M+IZDJBNswAhG5G6riA'
    b'ojCgOBZGARUAAHfCEwMt0PAfAAAAAElFTkSuQmCC')

