#----------------------------------------------------------------------
# This file was generated by /Users/humberto.a.sanchez.ii/PycharmProjects/PyUt/venv-pyenv-3.9.0/bin/img2py
#
from wx.lib.embeddedimage import PyEmbeddedImage

embeddedImage = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAAAXNSR0IArs4c6QAAAGxlWElm'
    b'TU0AKgAAAAgABAEaAAUAAAABAAAAPgEbAAUAAAABAAAARgEoAAMAAAABAAIAAIdpAAQAAAAB'
    b'AAAATgAAAAAAAABfAAAAAQAAAF8AAAABAAKgAgAEAAAAAQAAACCgAwAEAAAAAQAAACAAAAAA'
    b'NxUjagAAAAlwSFlzAAAOnAAADpwBB5RT3QAAAQFJREFUWAntll0KgzAQhNfS3scjeBSP4Huh'
    b'LIW+eySP4H0KtY5x7KKxFElsoVkIG1nZ+Zz8oEiK5MC/O5DRgLquu7Zt+Rg953kuVVVN+lKW'
    b'Zder7jZGPTnOP7UoCsHYGk3TCMZaH9bZ3wtwOSvrG7JOAP4+rs7GB05CZYiq6tDuelM5nOS1'
    b'zh6R4ADQ4JcDpB/YV6sRBQBqnzoRDYAQyO+ciAowimcAQGBP4BTYWJwCWwwxf9xxt+ggThDb'
    b'NzoAxdzGdA5YF6IvAQGQATG/5HYFsDCcJ4CvO7A4BW6HKpcoeLYnAM29APOXglOYhhMA/lD6'
    b'nwRTijuFXorkQHLgJxx4AsxecgDon9v0AAAAAElFTkSuQmCC')

