#----------------------------------------------------------------------
# This file was generated by /Users/humberto.a.sanchez.ii/PycharmProjects/PyUt/venv-pyenv-3.9.0/bin/img2py
#
from wx.lib.embeddedimage import PyEmbeddedImage

embeddedImage = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAABhGlDQ1BJQ0MgcHJvZmlsZQAA'
    b'KJF9kTtIw1AUhv+miiIVEStIcchQnSyIijhqFYpQIdQKrTqY3PQFTRqSFBdHwbXg4GOx6uDi'
    b'rKuDqyAIPkDc3JwUXaTEc5NCixgPHO7Hf89/OPdcQKiXmWZ1jAOabpupRFzMZFfFrlcE0E85'
    b'iIjMLGNOkpLwja97qqS4i/Fe/nV/Rq+asxgQEIlnmWHaxBvE05u2wXmfOMyKskp8Tjxm0oDE'
    b'j1xXPH7jXHBZ4D3DZjo1TxwmFgttrLQxK5oa8RRxVNV06i9kPFY5b3HWylXWnJO/MJTTV5a5'
    b'TjmMBBaxBAkiFFRRQhk2YnTqpFhI0X3cxx9x/RK5FHKVwMixgAo0yK4f/A9+79bKT054nUJx'
    b'oPPFcT5GgK5doFFznO9jx2mcAMFn4Epv+St1YOaT9FpLix4BfdvAxXVLU/aAyx1g6MmQTdmV'
    b'gpRCPg+8n9E3ZYGBW6Bnzdtb8x6nD0CadpW8AQ4OgdEC9V73eXd3+97+rWnu7wcRfHKAsQUM'
    b'igAAAAZiS0dEAP8A/wD/oL2nkwAAAAlwSFlzAAAOxAAADsQBlSsOGwAAAAd0SU1FB+UBEQEW'
    b'D9J9+6oAAAAtSURBVDjLY2AYBejgP6kaGHFoZiTVgP8EDMdrwH9K/EwVF1AUBhTHwiigAgAA'
    b'vGcHA5JjdeUAAAAASUVORK5CYII=')

