#----------------------------------------------------------------------
# This file was generated by /Users/humberto.a.sanchez.ii/PycharmProjects/PyUt/venv-pyenv-3.9.0/bin/img2py
#
from wx.lib.embeddedimage import PyEmbeddedImage

embeddedImage = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAAK3RFWHRDcmVhdGlvbiBUaW1l'
    b'AERvIDIxIE5vdiAyMDAyIDExOjQ1OjQ1ICswMTAwsqsFmAAAAAd0SU1FB9MIDQ0eFFwnL8wA'
    b'AAAJcEhZcwAACxIAAAsSAdLdfvwAAAAEZ0FNQQAAsY8L/GEFAAAE/klEQVR42uVWXWxURRQ+'
    b'c+/d7W53a39sMYFWfhYlxWgI+oBNMP48CKLRF/TBhAdfmvjEg4QHnhoTE01MfCPwqkZoiaKJ'
    b'0GqCISDGgFi0QNJWaNmtVLplW7e73fszM56ZO3c7e9vtFlufnPTr/Oydc75zzjd3LsD/vZG1'
    b'Npi9+fnItTOHt3qOB5RS4ByAUReww56CWNjS1d391CsfH1/zaDjnHcNn3+F/jX6NQ4ZwECWE'
    b'p8aMD1/8gF/6dP+vwR5jDZ0TjHjvzNgP0Lr5eVyZQeQRBUQOMSvR/uQ+mB4f7OR8uE7ss2oZ'
    b'vvfLkTN24V49YbzZcwsWprGBOQWLMjfOnHmLOqWI5xXNq8dTZqlUIBBrBMMQtu/r9FTvQvyh'
    b'zWAXMvhALIELdk0Co5c+3Nu+6zCKpQ5idUkwog1gRBqAWEmIRBM4T4KJ8yjaMyJx3CEwjfDA'
    b'lxgNWbSkLgD+hhVlgIMJHc+8r1LKFKjqPW2tpJBTEZMKKwvNUT+tlAALDEyFDAWNVTrC8DhD'
    b'1TMbVe+AWdcEhJjac1bFlpoEKDV81gjGHOBoVBgWPWfz/lw4pCXpFAfokKEOfPJWYiNEkx0q'
    b'I0xlQARSIGUCve9CEhKwwbBgPe7bQLA3DRwjPM+G+dlbYOfPATFMMCwDDBN7MTYJmBYB/MM5'
    b'k5ESTvzSIBHmeVAsjEE00YZOg5KYFcWRBHgSBhsfSaWSD3dAfWMbxBtbUa0tiCYY+uoIxBoa'
    b'cLxJ1Y5J48A91Qu4frjBmiIgSJmkCG7pLkTibWWXTJYgrxEA+H5r14FUatdbSlgi5bYEE4wN'
    b'R61z1a9HMroYqQ+xRhRB4oszWs/AdUwk0KyejULXgRPgvxcCDRD44s7g6e7UrjeI78Atg0un'
    b'84oQh4H0Othzdnct6dRo22D7jdkXcdAnCRi34McsGZwo3L/dnmhp07LgqGMsCIgj9ig6fwmO'
    b'Pb0695+NA1zINvaK0CWBN/uAnjzET2WG+g9ue24/6Flg8uRh9Eyo1y0b6R7I/nsGySS+CGNa'
    b'CUAe31Pp384dfHz3ayhYukBACgZfGryosuJHAK2tqywDVBK4mYCftqeHxwu58Y3JltZyFjgX'
    b'B3oOhwhjXj77yaZBMLYsGBEkdYhbNzwO969P7qgk0NMD7MQh6EtfO/9e5wv7/CMViJChYine'
    b'atyWz+7cuWNRJIFxATz+FX14LACT/r6K69gg0JcZ+hlvVoxUgBbxRCEBimfWRQK0tCZpr/Cp'
    b'T65/BFdymfFMMZtBynMSUoRuzs8A+48J9IhMcn564vfL6DQvCcgSUBShhyJkdlVD3L+HVkdA'
    b'NI/Bl+nrQ+UMUFECb8afVylBIDhBQH32VUW4LboNR6/ARZNMTNn5bFtdzFRvXyRA58oZEE6I'
    b'dqMEToM+IBOAaddveL4oAz3nwcNvx/67IyOyDEzscEQGFjSgqzk4VkLly2UiTKoqAcmSwrcT'
    b'I3d8DQgVejmfgFcqp1wnoDsPvwdqlWLJDxLiwHd/jmU95uYteQwcIUhaLoFwGBagHnkw1skE'
    b'82C8bAbePgq5UtG9OjM5hfXApwlGbxTBs55YsgR6GZZ6C+oEg9+WJaDSfGHi9jR+VHC4cTkP'
    b'3/TOweTsYyzIwFLQHYfLEqyvSAOqHf1jbJ0djTfPpSc7TxYjTc+2d75qVcuAngk9C9VQLjc8'
    b'aDvGX8b//Q+8b3HbA91kYA3srK79A38+eaaryzPWAAAAAElFTkSuQmCC')

