#----------------------------------------------------------------------
# This file was generated by /Users/humberto.a.sanchez.ii/PycharmProjects/PyUt/venv-pyenv-3.9.0/bin/img2py
#
from wx.lib.embeddedimage import PyEmbeddedImage

embeddedImage = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAADYXpUWHRSYXcgcHJvZmlsZSB0'
    b'eXBlIGV4aWYAAHja7VdZju0oDP1nFb2E2GYwy2GU3g56+X0ckvTNHaT3VPXT6goKEGOOh2O4'
    b'VW78/Wu6v/DwFtX5kDTmGDc8PvvMBRPd1lP2nja/9/vDxxK+b3J3LTBEglHWp8ZD/5TTBbCG'
    b'gll4ANJ2LNT7QvYHvj4BHZbFPLJ5P4DyASS8FugAKCusLWZNjyHUscZ+RqLrddZ5vbv98p2Q'
    b'vR5gR5iHkGzoWXg5IPaSk4IJoWcRXmKTRPRezlCRkHd52h68cs+sXDP6IH8iReKSOwjuyYzX'
    b'+FZO4Ul+ALo9xQ+WpV2Wb/JOl4lbku2ds6ubc6zoio9IaTyCOkPZZ1CsSLns2yJawhswT3vL'
    b'aOpQvQ2U961tFa1RJgYtkzx1KjRp7GOjBhc9D04YmRuIMplK4sxNNgfGvDWanCRLFwVzDfQK'
    b'pHz5QrvdvJtrpDDcCZpMACMrBWfdd7SPQHNayRNteuUKfrEVIdww5qyHFgihedZR2BN8tufH'
    b'eBUwGPY0KwIsW10QNdBRW1ZHshMtUAwY11mj1A8ApAi2A5whAQNbJAkUaUvMiQh5VPBTAKQs'
    b'nisooBC4w0v2IhHkKJtt7Em063LgJcadZccHxyiBmiwFXHlcbKif5BU1VIIEH0KIIQUNOZQo'
    b'0ccQY0zRLr+SJPkUUkwpacqpqKjXoFGTqtOsJXMWXI4hx5yy5pxLgdEC5ILdBQqlVK5SfQ01'
    b'1lS15loayqf5FlpsqalruZXOXTruiR576tpzL4MGSmn4EUYcaejIo0yU2pTpZ5hxpqkzz3Kx'
    b'Rm7R+tJ+nzU6WeOdKVNMF2vYmtIJQXadBOMMjLEnMJ6MARQ0G2ebkvfsjDrjbMu42SQwvAxG'
    b'Dk47GAODfhCHSRd3/zJ34815/yXe+GTOGXXfwZwz6j4w98rbG9a6/dq0TdzOkB1DS+omOH5Q'
    b'GFpYi/2o/fbo/nTDD9AP0P8aqI6J01amrilENtUyq52/8+sdmNtmZVwSU3t8XL5L7asOCZe5'
    b'Vm5r0HRfBTj3u9dgnn1/F5x92d+3S80w3Vo02HP3MnVKL6cW8u7U49qp6b4KcEbkPodk2Hsc'
    b'lo8jks9F4L6jiswT95Lo04s/hHPfUdU/QD9A/yGgib99Mv7H+AcyreZ3cOZYtwAAAYRpQ0NQ'
    b'SUNDIHByb2ZpbGUAAHicfZE9SMNQFIVPU7UiFQc7FHHIUJ0siIo4ahWKUCHUCq06mLz0D5o0'
    b'JCkujoJrwcGfxaqDi7OuDq6CIPgD4ubmpOgiJd6XFFrEeOHxPs675/DefYDQqDDN6hoHNN02'
    b'08mEmM2tiqFXBBCFgB6EZGYZc5KUgm993VM31V2cZ/n3/Vn9at5iQEAknmWGaRNvEE9v2gbn'
    b'feIIK8kq8TnxmEkXJH7kuuLxG+eiywLPjJiZ9DxxhFgsdrDSwaxkasRTxDFV0ylfyHqsct7i'
    b'rFVqrHVP/sJwXl9Z5jqtYSSxiCVIEKGghjIqsBGnXSfFQprOEz7+IdcvkUshVxmMHAuoQoPs'
    b'+sH/4PdsrcLkhJcUTgDdL47zMQKEdoFm3XG+jx2neQIEn4Erve2vNoCZT9LrbS12BAxsAxfX'
    b'bU3ZAy53gOiTIZuyKwVpCYUC8H5G35QDBm+BvjVvbq1znD4AGZpV6gY4OARGi5S97vPu3s65'
    b'/dvTmt8P0MtyZm2C+RoAAA+gaVRYdFhNTDpjb20uYWRvYmUueG1wAAAAAAA8P3hwYWNrZXQg'
    b'YmVnaW49Iu+7vyIgaWQ9Ilc1TTBNcENlaGlIenJlU3pOVGN6a2M5ZCI/Pgo8eDp4bXBtZXRh'
    b'IHhtbG5zOng9ImFkb2JlOm5zOm1ldGEvIiB4OnhtcHRrPSJYTVAgQ29yZSA0LjQuMC1FeGl2'
    b'MiI+CiA8cmRmOlJERiB4bWxuczpyZGY9Imh0dHA6Ly93d3cudzMub3JnLzE5OTkvMDIvMjIt'
    b'cmRmLXN5bnRheC1ucyMiPgogIDxyZGY6RGVzY3JpcHRpb24gcmRmOmFib3V0PSIiCiAgICB4'
    b'bWxuczppcHRjRXh0PSJodHRwOi8vaXB0Yy5vcmcvc3RkL0lwdGM0eG1wRXh0LzIwMDgtMDIt'
    b'MjkvIgogICAgeG1sbnM6eG1wTU09Imh0dHA6Ly9ucy5hZG9iZS5jb20veGFwLzEuMC9tbS8i'
    b'CiAgICB4bWxuczpzdEV2dD0iaHR0cDovL25zLmFkb2JlLmNvbS94YXAvMS4wL3NUeXBlL1Jl'
    b'c291cmNlRXZlbnQjIgogICAgeG1sbnM6cGx1cz0iaHR0cDovL25zLnVzZXBsdXMub3JnL2xk'
    b'Zi94bXAvMS4wLyIKICAgIHhtbG5zOkdJTVA9Imh0dHA6Ly93d3cuZ2ltcC5vcmcveG1wLyIK'
    b'ICAgIHhtbG5zOmRjPSJodHRwOi8vcHVybC5vcmcvZGMvZWxlbWVudHMvMS4xLyIKICAgIHht'
    b'bG5zOnRpZmY9Imh0dHA6Ly9ucy5hZG9iZS5jb20vdGlmZi8xLjAvIgogICAgeG1sbnM6eG1w'
    b'PSJodHRwOi8vbnMuYWRvYmUuY29tL3hhcC8xLjAvIgogICB4bXBNTTpEb2N1bWVudElEPSJn'
    b'aW1wOmRvY2lkOmdpbXA6MGM3NGZmZDQtMTNiMS00NjZiLThhNGYtOTE4ZjVlMjlhMWY5Igog'
    b'ICB4bXBNTTpJbnN0YW5jZUlEPSJ4bXAuaWlkOjA5YzI3ZDI3LWVkNzgtNGQwMC05NzYwLWNk'
    b'NWYwZjMwNDI1YSIKICAgeG1wTU06T3JpZ2luYWxEb2N1bWVudElEPSJ4bXAuZGlkOmUyZjM1'
    b'NWMxLTc3OTQtNDk5MC05NTBiLTNkM2U0MGQyNmQ1ZCIKICAgR0lNUDpBUEk9IjIuMCIKICAg'
    b'R0lNUDpQbGF0Zm9ybT0iTWFjIE9TIgogICBHSU1QOlRpbWVTdGFtcD0iMTYxMTQ1NDAwNzg4'
    b'ODE4MSIKICAgR0lNUDpWZXJzaW9uPSIyLjEwLjIyIgogICBkYzpGb3JtYXQ9ImltYWdlL3Bu'
    b'ZyIKICAgdGlmZjpPcmllbnRhdGlvbj0iMSIKICAgeG1wOkNyZWF0b3JUb29sPSJHSU1QIDIu'
    b'MTAiPgogICA8aXB0Y0V4dDpMb2NhdGlvbkNyZWF0ZWQ+CiAgICA8cmRmOkJhZy8+CiAgIDwv'
    b'aXB0Y0V4dDpMb2NhdGlvbkNyZWF0ZWQ+CiAgIDxpcHRjRXh0OkxvY2F0aW9uU2hvd24+CiAg'
    b'ICA8cmRmOkJhZy8+CiAgIDwvaXB0Y0V4dDpMb2NhdGlvblNob3duPgogICA8aXB0Y0V4dDpB'
    b'cnR3b3JrT3JPYmplY3Q+CiAgICA8cmRmOkJhZy8+CiAgIDwvaXB0Y0V4dDpBcnR3b3JrT3JP'
    b'YmplY3Q+CiAgIDxpcHRjRXh0OlJlZ2lzdHJ5SWQ+CiAgICA8cmRmOkJhZy8+CiAgIDwvaXB0'
    b'Y0V4dDpSZWdpc3RyeUlkPgogICA8eG1wTU06SGlzdG9yeT4KICAgIDxyZGY6U2VxPgogICAg'
    b'IDxyZGY6bGkKICAgICAgc3RFdnQ6YWN0aW9uPSJzYXZlZCIKICAgICAgc3RFdnQ6Y2hhbmdl'
    b'ZD0iLyIKICAgICAgc3RFdnQ6aW5zdGFuY2VJRD0ieG1wLmlpZDoyNjUwN2FkNS03MGI4LTQ1'
    b'YzItYWYzYy04NWYyZmNmODhhODEiCiAgICAgIHN0RXZ0OnNvZnR3YXJlQWdlbnQ9IkdpbXAg'
    b'Mi4xMCAoTWFjIE9TKSIKICAgICAgc3RFdnQ6d2hlbj0iMjAyMS0wMS0yM1QyMDowNjo0Ny0w'
    b'NjowMCIvPgogICAgPC9yZGY6U2VxPgogICA8L3htcE1NOkhpc3Rvcnk+CiAgIDxwbHVzOklt'
    b'YWdlU3VwcGxpZXI+CiAgICA8cmRmOlNlcS8+CiAgIDwvcGx1czpJbWFnZVN1cHBsaWVyPgog'
    b'ICA8cGx1czpJbWFnZUNyZWF0b3I+CiAgICA8cmRmOlNlcS8+CiAgIDwvcGx1czpJbWFnZUNy'
    b'ZWF0b3I+CiAgIDxwbHVzOkNvcHlyaWdodE93bmVyPgogICAgPHJkZjpTZXEvPgogICA8L3Bs'
    b'dXM6Q29weXJpZ2h0T3duZXI+CiAgIDxwbHVzOkxpY2Vuc29yPgogICAgPHJkZjpTZXEvPgog'
    b'ICA8L3BsdXM6TGljZW5zb3I+CiAgPC9yZGY6RGVzY3JpcHRpb24+CiA8L3JkZjpSREY+Cjwv'
    b'eDp4bXBtZXRhPgogICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgCiAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAKICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgIAogICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgCiAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAKICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgIAogICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgCiAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAKICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'IAogICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgCiAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAKICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgIAogICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgCiAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAKICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgIAogICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgCiAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAK'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgIAogICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgCiAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAKICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgCjw/eHBhY2tldCBlbmQ9InciPz68Mg6lAAAABmJLR0QA/wD/AP+gvaeTAAAACXBI'
    b'WXMAAAsTAAALEwEAmpwYAAAAB3RJTUUH5QEYAgYv3J844AAAAHFJREFUWMPtlEsKACEMQxPx'
    b'TN5/3UvVldCBcRDxM4u8XYNgSD+AEEKIffjIIx4y0P0nbU6BwYzfboG/GaGZOQCUUggArV6g'
    b'9aJ/tIZB4EfvZrSRGfN0e1WymcXI0OpV2ux2HBvCfHgb+LtDdP0UCyGEqMGXOgXDiP2LAAAA'
    b'AElFTkSuQmCC')

