#----------------------------------------------------------------------
# This file was generated by /Users/humberto.a.sanchez.ii/PycharmProjects/PyUt/venv-pyenv-3.9.0/bin/img2py
#
from wx.lib.embeddedimage import PyEmbeddedImage

embeddedImage = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAADKXpUWHRSYXcgcHJvZmlsZSB0'
    b'eXBlIGV4aWYAAHja7ZZbktwgDEX/WUWWYEkIxHJ4VmUHWX4u+JF2T0/VJJPPNmXAAkmgI2O7'
    b'/uvncD9w8Sab8xotpBA2XD75xBkd2/Yrr5o2v+p18TGE55vcXQMMkaCV/dHCMf+U02VgbzJ6'
    b'+mDI6jFQ7gPJH/btydDhWeaKZr8dhtJhSHgfoMNA3re1hWTxcQul7207d2L77Wbl7b7sD88R'
    b'0WsKP8LchWRDzcL7AmTe5CSjQ6hZhHdxFnRRk4TDGALyKk7bw6rcM5WrR5/In6DA2ZI7CO7B'
    b'DFf7Uk76JD8MuhXiB89SL883ea6Xi1uQ5z1GMzdG33eXfUBIw7Gpcyurh4kFIZelFlAibkU/'
    b'rpJQzCF7K5C3rW4FpVIiBpZBnhplGtRXW6liiZ47R7TMFaCmzCRy4opXBGz8LDQ4SpImBmIV'
    b'eAVSvtZCy29a7ioZHDfCTCYYo5kKblb/o3xqaIyZ8kSbXbHCungmIZYxyc0aswCExplHugJ8'
    b'ludrchUQ1BVmwwbzVnYTRenIrZlHskALJira/V2j2A4DCBF8KxZDAgJbIFEKtEXmSIQ4Gvhk'
    b'GDIWzwUISJUbVsleJACO8fQNnUhrLivvYpxZAKESJAJNkgxWHgcb8id6Qw5lFfWqGjSqadIc'
    b'JPigIYQY5uGXo0QfNYYYo8UUs4l5UwsWzZwly4mT4HDUFFJMllLKGU4zLGdoZ0zIuXCR4ouW'
    b'UGKxkkquSJ/qq9ZQYzVXU82NmzScEy202Kylljt1pFL3XXvosVtPPQ+k2pDhh44w4rCRRr6o'
    b'kduxfihfp0YnNV6k5sR4UYNqjKcJmseJTmYgxp5APE4CSGiezDYj79lNdJPZlnCyiTJWqRNO'
    b'o0kMBH0n1kEXuz/kbtyc99/ixic5N9H9D3JuovuE3EduL6i1+bWpm7hFaL6GM6ib4PXDhG6Z'
    b'Lc+P2pdb97cKb0NvQ29Df9WOMt9MfCCH3YZLHwPdXTonzX/G16p3TffvqndN91p1tbv+Pu9h'
    b'dOpj/ik/DOD/6N+VH3Xdd5QfW/d98G9Db0NvQ98wNPDDktxvZnzLvr7XBjQAAAGEaUNDUElD'
    b'QyBwcm9maWxlAAB4nH2RPUjDUBSFT1NFkYqgHYoIZqhOFkRFHLUKRagQaoVWHUxe+gdNGpIU'
    b'F0fBteDgz2LVwcVZVwdXQRD8AXFzc1J0kRLvSwotYrzweB/n3XN47z5AqJeZZnWMA5pum6lE'
    b'XMxkV8WuVwQQgYBh9MvMMuYkKQnf+rqnbqq7GM/y7/uzetWcxYCASDzLDNMm3iCe3rQNzvvE'
    b'YVaUVeJz4jGTLkj8yHXF4zfOBZcFnhk206l54jCxWGhjpY1Z0dSIp4ijqqZTvpDxWOW8xVkr'
    b'V1nznvyFoZy+ssx1WkNIYBFLkCBCQRUllGEjRrtOioUUncd9/IOuXyKXQq4SGDkWUIEG2fWD'
    b'/8Hv2Vr5yQkvKRQHOl8c52ME6NoFGjXH+T52nMYJEHwGrvSWv1IHZj5Jr7W06BHQtw1cXLc0'
    b'ZQ+43AEiT4Zsyq4UpCXk88D7GX1TFhi4BXrWvLk1z3H6AKRpVskb4OAQGC1Q9rrPu7vb5/Zv'
    b'T3N+PyqgcooyZuksAAAPoGlUWHRYTUw6Y29tLmFkb2JlLnhtcAAAAAAAPD94cGFja2V0IGJl'
    b'Z2luPSLvu78iIGlkPSJXNU0wTXBDZWhpSHpyZVN6TlRjemtjOWQiPz4KPHg6eG1wbWV0YSB4'
    b'bWxuczp4PSJhZG9iZTpuczptZXRhLyIgeDp4bXB0az0iWE1QIENvcmUgNC40LjAtRXhpdjIi'
    b'PgogPHJkZjpSREYgeG1sbnM6cmRmPSJodHRwOi8vd3d3LnczLm9yZy8xOTk5LzAyLzIyLXJk'
    b'Zi1zeW50YXgtbnMjIj4KICA8cmRmOkRlc2NyaXB0aW9uIHJkZjphYm91dD0iIgogICAgeG1s'
    b'bnM6aXB0Y0V4dD0iaHR0cDovL2lwdGMub3JnL3N0ZC9JcHRjNHhtcEV4dC8yMDA4LTAyLTI5'
    b'LyIKICAgIHhtbG5zOnhtcE1NPSJodHRwOi8vbnMuYWRvYmUuY29tL3hhcC8xLjAvbW0vIgog'
    b'ICAgeG1sbnM6c3RFdnQ9Imh0dHA6Ly9ucy5hZG9iZS5jb20veGFwLzEuMC9zVHlwZS9SZXNv'
    b'dXJjZUV2ZW50IyIKICAgIHhtbG5zOnBsdXM9Imh0dHA6Ly9ucy51c2VwbHVzLm9yZy9sZGYv'
    b'eG1wLzEuMC8iCiAgICB4bWxuczpHSU1QPSJodHRwOi8vd3d3LmdpbXAub3JnL3htcC8iCiAg'
    b'ICB4bWxuczpkYz0iaHR0cDovL3B1cmwub3JnL2RjL2VsZW1lbnRzLzEuMS8iCiAgICB4bWxu'
    b'czp0aWZmPSJodHRwOi8vbnMuYWRvYmUuY29tL3RpZmYvMS4wLyIKICAgIHhtbG5zOnhtcD0i'
    b'aHR0cDovL25zLmFkb2JlLmNvbS94YXAvMS4wLyIKICAgeG1wTU06RG9jdW1lbnRJRD0iZ2lt'
    b'cDpkb2NpZDpnaW1wOjA1OWU2NTBjLTYxNzctNDc4NC1iODIzLWEzZTM2NmM0YjFhNyIKICAg'
    b'eG1wTU06SW5zdGFuY2VJRD0ieG1wLmlpZDo5MTU3YTY0NS05Mjc4LTQxMTUtYmE2Yy0zZDFi'
    b'YWQ5MmIxMzMiCiAgIHhtcE1NOk9yaWdpbmFsRG9jdW1lbnRJRD0ieG1wLmRpZDozNGJkMzFl'
    b'NC00NGY4LTQxY2MtODAyZS04MDA4ZjY2NjVjMjEiCiAgIEdJTVA6QVBJPSIyLjAiCiAgIEdJ'
    b'TVA6UGxhdGZvcm09Ik1hYyBPUyIKICAgR0lNUDpUaW1lU3RhbXA9IjE2MTE0NTU1NDIyNjIw'
    b'MzciCiAgIEdJTVA6VmVyc2lvbj0iMi4xMC4yMiIKICAgZGM6Rm9ybWF0PSJpbWFnZS9wbmci'
    b'CiAgIHRpZmY6T3JpZW50YXRpb249IjEiCiAgIHhtcDpDcmVhdG9yVG9vbD0iR0lNUCAyLjEw'
    b'Ij4KICAgPGlwdGNFeHQ6TG9jYXRpb25DcmVhdGVkPgogICAgPHJkZjpCYWcvPgogICA8L2lw'
    b'dGNFeHQ6TG9jYXRpb25DcmVhdGVkPgogICA8aXB0Y0V4dDpMb2NhdGlvblNob3duPgogICAg'
    b'PHJkZjpCYWcvPgogICA8L2lwdGNFeHQ6TG9jYXRpb25TaG93bj4KICAgPGlwdGNFeHQ6QXJ0'
    b'd29ya09yT2JqZWN0PgogICAgPHJkZjpCYWcvPgogICA8L2lwdGNFeHQ6QXJ0d29ya09yT2Jq'
    b'ZWN0PgogICA8aXB0Y0V4dDpSZWdpc3RyeUlkPgogICAgPHJkZjpCYWcvPgogICA8L2lwdGNF'
    b'eHQ6UmVnaXN0cnlJZD4KICAgPHhtcE1NOkhpc3Rvcnk+CiAgICA8cmRmOlNlcT4KICAgICA8'
    b'cmRmOmxpCiAgICAgIHN0RXZ0OmFjdGlvbj0ic2F2ZWQiCiAgICAgIHN0RXZ0OmNoYW5nZWQ9'
    b'Ii8iCiAgICAgIHN0RXZ0Omluc3RhbmNlSUQ9InhtcC5paWQ6MGYxMGNmZGYtOGZhYi00YWZl'
    b'LWFkYTEtZmZiNGEyYTNkMTI3IgogICAgICBzdEV2dDpzb2Z0d2FyZUFnZW50PSJHaW1wIDIu'
    b'MTAgKE1hYyBPUykiCiAgICAgIHN0RXZ0OndoZW49IjIwMjEtMDEtMjNUMjA6MzI6MjItMDY6'
    b'MDAiLz4KICAgIDwvcmRmOlNlcT4KICAgPC94bXBNTTpIaXN0b3J5PgogICA8cGx1czpJbWFn'
    b'ZVN1cHBsaWVyPgogICAgPHJkZjpTZXEvPgogICA8L3BsdXM6SW1hZ2VTdXBwbGllcj4KICAg'
    b'PHBsdXM6SW1hZ2VDcmVhdG9yPgogICAgPHJkZjpTZXEvPgogICA8L3BsdXM6SW1hZ2VDcmVh'
    b'dG9yPgogICA8cGx1czpDb3B5cmlnaHRPd25lcj4KICAgIDxyZGY6U2VxLz4KICAgPC9wbHVz'
    b'OkNvcHlyaWdodE93bmVyPgogICA8cGx1czpMaWNlbnNvcj4KICAgIDxyZGY6U2VxLz4KICAg'
    b'PC9wbHVzOkxpY2Vuc29yPgogIDwvcmRmOkRlc2NyaXB0aW9uPgogPC9yZGY6UkRGPgo8L3g6'
    b'eG1wbWV0YT4KICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'IAogICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgCiAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAKICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgIAogICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgCiAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAKICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgIAogICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgCiAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAK'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgIAogICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgCiAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAKICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgIAogICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgCiAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAKICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgIAogICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgCiAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAKICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgIAogICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgCiAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgIAo8P3hwYWNrZXQgZW5kPSJ3Ij8+Nl3WgwAAAAZiS0dEAP8A/wD/oL2nkwAAAAlwSFlz'
    b'AAALEwAACxMBAJqcGAAAAAd0SU1FB+UBGAIgFkBEM8wAAAAqSURBVFjD7dGhAQAgAALB1/13'
    b'1uoEGrxLQKUAgMdGtY7c0a9s0wcA8L0NctoHAyid3RAAAAAASUVORK5CYII=')

