#----------------------------------------------------------------------
# This file was generated by /Users/humberto.a.sanchez.ii/PycharmProjects/PyUt/venv-pyenv-3.9.0/bin/img2py
#
from wx.lib.embeddedimage import PyEmbeddedImage

embeddedImage = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAAK3RFWHRDcmVhdGlvbiBUaW1l'
    b'AERpIDE2IEF1ZyAyMDA1IDEzOjU3OjUwICswMTAw0YaYRwAAAAd0SU1FB9MCDg4hMoy3iRsA'
    b'AAAJcEhZcwAACvAAAArwAUKsNJgAAAAEZ0FNQQAAsY8L/GEFAAAHEUlEQVR42sWXe2xT1xnA'
    b'v3Puw49rx5A4cQKhwXKANBntBGx0jJWGUryWxwgdC2VapbF1oElUAiGWP1ijSmuhXbutD22C'
    b'atq0SFuWtJuqKlo3lhIppSFxE0ICSaBJnBckTnBim9j3de49O9eQiFaahmnQPvvzvbqv73e+'
    b'5zXA/1nQfztRU1MjiKJYoWvabqLrX5MVOVfXdUPXyaROyHlVVescDsc/jh07Zi44QGdn55Oj'
    b'IyNvhgcH/LJBZYe3IMm7FxsUIUQSMZyKjLr02bhNp3BZkqSDVVVV5xcMoOvixZ93d3dVh6ei'
    b'yYeCuyK5RUWKTijohokUjSKNIKQYFCdGB6XZjn9nR68N8zandKi6uvqdewHgvrDyqo5PQ79I'
    b'uXMmK3747MzS7EW8C5s2CQwbpgyCECC3FTmydBpYl3TxIEQHLj/92ObHB5ubm7vuGaCjvX1D'
    b'X0/PnxJS9tSOp3fKmJicDVGBo5QDjCkA5djCKTEoJRaMbiDTIKB7i2WvgxfGei/sfOQbG+pb'
    b'W1unMwHg53ZmZmZe649ElYrnv39T1wxxMYecDoxFBZla/pvcUmAIYDBlKVezLdJHkQjWMURk'
    b'dNP/reiK0nBhT9eFE+yK72YCgK2fhoaG9Vd7Lz+yYvO2CNIM3gZIYGS8yawJFiQz+vpz++DV'
    b'5yrTEOPhAVFTZExZBhnMIxKnY+GhLTGBQ985cOBAUcYA8VisIq4QzfNAQAGTIsM0YUY3Zc2g'
    b'pmqA9WGGjHTsgX3lVBKxpAST1QWLBogcQhHBl/L7/VhR5O0Zh0CW5bXcYl9KZikug0F5Exur'
    b'fi8um3O5pZZxC8Lar778hB+6b4Xk5W+P9Lt5FxIxB1LhCs3o6l6TMQCjzsc5PkJUE8WoSTBg'
    b'ZD38lz/ZmzZqMo9YW0tf+PG2+Up49XQjTIyGxUXFAXaDRO2ePEI0vSBjAINlM7Amo5kmknWT'
    b'jumaaq10zuicUuZvckcpWuFIpZJYQJSjJiKY49KwGQNomn7dTCaW6TpCcZ3VnZUZ7OFVv62f'
    b'z/zjP3oybfTk6TO3js0pa4+sWvBNhQKdvSEQw7ieMYBOjBCaHn9MNpgXDEJFjNDvgtevTo4M'
    b'8qqcwi/3bl0+v2od4ID/vTEQ7FQ3EfJluQXNBKSwU8lrAwLCuC0TgHQVCILwd5KMCXJkyKkQ'
    b'hJPsiQYvQlZBkZHrX0Wslc4DsH3E26nkKzJ8/hKz9MFiNK6K+vpc6jzX0kKYMxoyBjh69Gg7'
    b'4sVm2v2RVwE7UnRAKguHyTvBFFzUCsdrp87Cb043pwE0tnLB5sQPF2aLSWo3IypHoeefWdFY'
    b'4v36+vprmQDMD6MTJ06sScxEW3zrtqTi/o1RjijWYRZYNoBY3d8YGxKUVAoR5m6vR+IeLlmJ'
    b'Vc5mtkdMfV/+tPfkz35q92R74x6P5weFhYW7ZpPJX71y8mTP/wKYnwWNjY3jT2wNTieGe3fl'
    b'ue1czFmkIqCYJQnzKockdxbKy8vFxYX5nDfHi67JnBFOYGOvb8b7+vHnHU9t34nKysrsbrf7'
    b'mYJlD6wZHxsmn7Sc//CuASxpamoKbXx0U2zyysWnlvNxEWfl4SnTRUzM6oITkEYFiGg2Y1Th'
    b'jNU5gq0s+rHr1y+94CjfshXt378feJ6H0rLVqKO1GbaffWP1qUVa64sRCN9VCO6UI0eOfDMR'
    b'j73llhyrileWaPYlJaqQ41N4xJucHBXUsV7bR01NYmQqeklyuReXl5eXBgIBCAaDUFv7Z3hw'
    b'6BQUJBLgujQqO8eju9Gn8GFGAHMJevDgwS2s7+8mRF9HdJJnsubPZsB11o9CNputjsnHlZWV'
    b'+cx43549lZ6+/n4oMepgZS4GZyQBMMwmc3u/AuGp76F2+CBTgLuSw4cP7y0pLf1LIqXC12+8'
    b'C2sfXQJSnoc1BRVgaApg9AaDGFBhYHIfg/jbF+/n78Xo59yE8dm+8EjdpnN/LF9e5sh1jNgA'
    b'JKYOpstzrRZvKZvwuJZyE8+iNqhdUA/MCS2FsqhXaszZGPBBgM2jVUwlO5t0rHUO3/ZER5hA'
    b'//h+FIKaufu4L2P0TnlxCqZe8ekNEJ2tAJvoZu8VAFkOACfzhNt+a62SDYOS3FH+lfWiK7gn'
    b'2tbySeRLh+Bz7myDXvrV5GZo++wMa2DsfYJNsZKlt0DS4SBwyXic78zeftw92PcMu6UYLyRA'
    b'GqITrsDN1GYIXR2GgQmAvjH2ypUCYI6IFa6FyQ3HILDESzVN+4N1/YIDpCFC0A/TCvNE/xB8'
    b'ZkGMwuQYhtiyQ1C2sgjaQyGIx+Pn7hvAbU8MgqpsgrYrA9G+GJyZDQKPNKj7a601fa3kl+4r'
    b'QBqiBUZAJsG3XTuoJInwzulTlK0cJiYmmp1O57/S19xPAEteeuNtHBkePMv+4GiJROIQx3Eu'
    b'tr1QW1tr3G/bdyX/AXbykwAPX4syAAAAAElFTkSuQmCC')

