#----------------------------------------------------------------------
# This file was generated by /Users/humberto.a.sanchez.ii/PycharmProjects/PyUt/venv-pyenv-3.9.0/bin/img2py
#
from wx.lib.embeddedimage import PyEmbeddedImage

embeddedImage = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAABhGlDQ1BJQ0MgcHJvZmlsZQAA'
    b'KJF9kT1Iw1AUhU9TRZGKiB1EHDJUJwtFRTpqFYpQIdQKrTqYvPQPmjQkKS6OgmvBwZ/FqoOL'
    b's64OroIg+APi5uak6CIl3pcUWsR44fE+zrvn8N59gNCoMM3qigGabpvpZELM5lbFnlcEMAgg'
    b'hrjMLGNOklLwra976qa6i/Is/74/q1/NWwwIiMSzzDBt4g3imU3b4LxPHGYlWSU+J54w6YLE'
    b'j1xXPH7jXHRZ4JlhM5OeJw4Ti8UOVjqYlUyNeJo4omo65QtZj1XOW5y1So217slfGMrrK8tc'
    b'pzWKJBaxBAkiFNRQRgU2orTrpFhI03nCxz/i+iVyKeQqg5FjAVVokF0/+B/8nq1VmJr0kkIJ'
    b'oPvFcT7GgJ5doFl3nO9jx2meAMFn4Epv+6sNIP5Jer2tRY6AgW3g4rqtKXvA5Q4w/GTIpuxK'
    b'QVpCoQC8n9E35YChW6BvzZtb6xynD0CGZpW6AQ4OgfEiZa/7vLu3c27/9rTm9wOdBnK4rX9f'
    b'CAAAAAZiS0dEAP8A/wD/oL2nkwAAAAlwSFlzAAAOTQAADk0BRtVoCQAAAAd0SU1FB+UBEQAy'
    b'Fd81iUEAAAGnSURBVFjD7ZZPiqtAGMRLfdpgSK/9s4+4y0Wy8gLZJJCAEvAiIYsEcofcJZCF'
    b'5BoJCbTSqbeYGRcTZBxGZubx/IGr/iirS60W6Onp+d8x2g5ut1sWRQGSAICqqlBVVb1u2zZs'
    b'234RNQzEcYzlcvmh/p+2BoqiwOFwAEmQxP1+x+12q9cHgwFc14VhGDAMA0mSfC2BzWbD0+kE'
    b'rTUejwccx4EQonUCSimUZQkhBIQQiOMYi8WideKYzWZ0XZe2bRMAp9MpP/NsX+cppWQYhsyy'
    b'jK0S2O/3PJ/PUEpBKVUnMB6PsVqtWu9gvV7zeDzWCZimCcuyEEUR5vN5s06e5xyNRszznF2+'
    b'7U265vtBpRQulwuUUp1+bk26TwbKssT1ekVZlp0aaNI1f7qIfp8Bx3EwHA7hOE6nN2rSfTIg'
    b'hICUEkKITg006T5VcRRFAACtNbIs41sffLUHtNaYTCa1/odkWcYwDCml/N4mfGO327EoiroR'
    b'v/0seE+apgyCgL7v0/M8SilpWVZ9SSnpeR5932cQBEzTtFVirY/jOI6RJMmn/gd6enr+Cf4C'
    b'yeL2pJ1F1M4AAAAASUVORK5CYII=')

