#----------------------------------------------------------------------
# This file was generated by /Users/humberto.a.sanchez.ii/PycharmProjects/PyUt/venv-pyenv-3.9.0/bin/img2py
#
from wx.lib.embeddedimage import PyEmbeddedImage

embeddedImage = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAADnnpUWHRSYXcgcHJvZmlsZSB0'
    b'eXBlIGV4aWYAAHja7VdbkhsrDP1nFVkCkniI5dA8qrKDu/x7oOkeu+M4M85MVT4G3CCEWhI6'
    b'ErZN++9nNz/QmIIzzkcNKQSL5pJLnEGo3ds2R7JujrPx2sL6jm/ODQZLMMu+TMdGAx80lcVf'
    b'RuiQPxQdBGVQ/m1jc4u/XfhLIetV0bIstFu2dV+XpUh4ebTWdcmHpPHuaC3cWLArPuvxHHwM'
    b'eDhK8FydDy1ERLQFP7gYHdvAEXEwQQNBLIWEYOsZyNl+WUfAUT0cFOYmJBYjy/TRgAAbzIx5'
    b'jCywMoRAe1GMaDtcgJdtBLkAwdHoCLC5Ddg5/6Y9O6q5nvX2qCuf7vLlpK55dJKXPNK2+HIP'
    b'sw3nfIF/bZC/vCCnfb61nNxp+I5vajpt2Cv8vVftve2nyy4As7AOdRxxUpDbcDQn87WAHvF4'
    b'0HH2hK4224JkrLag8jbQiRiQdnJUKVOnNudiqMBHx40jZuaCTCjgqUROXGZKuNGpA6okFQnB'
    b'UpA/Ai4PX6YrZKbdNO0VUliuBFEmKKORbO/t5iPCt733Ub1Edi8tMjvAPNIcbgzkxggxIEJ9'
    b'BdXPAB/92gauYgChn2FWHDDbbVexeXrLLZlAC+Q85v0WoFh3BaNQYNobOEMCCGwg8RTIRuZI'
    b'hEAqAMpwfRTfBgTIoyrgJDsRVAErD9N4JRJEDWVGCU0+rlkg4SVIBDZJMsByziN/olPkUPbi'
    b'nffjBvHqk89BgkN5BdSbGlRVjhJdRDnGGDWmmFXUqdegUVWT5sRJcJ17FGBMmlLKGTYzNGe8'
    b'nCGQs9l4k81tfgtb3HRLWy5In+KKL6HEoiWVXLlKxUVUQ41Va6q5UUMqNdd8Cy02bcm03JFr'
    b'Xbrrvoceu/bU84karbK99g+gRgs1nkgJnniiBm6Mhwoa14k3AzMgxo6AeBwQIKF5YGaVnOOB'
    b'3MAM30+oCs9w0g9sKg3EgKBrxL6T2cEDdm/IvYTbuPwf4cYfRc4M6F5E7g430xJwe4BaHb8B'
    b'ykRsr8IRVCuoPshkVnysvZnNlfHq/K3o7xVtba6stN6fqjOf489FUVd740rvhzNja+vtqXfm'
    b'M7y5U3TjzbB+ERu7z300PX+OT+ZhhB74xH/w0TwM5Asr8+qLdys74H9Xur3N0h5vmb+I7zR/'
    b'xMp8JOmewWLs18D/3sL41aevKVr+c2H8NmW/Ikbfir4V/QOKpOO3EP6/mv8Bv9YOtm6LFuUA'
    b'AAGFaUNDUElDQyBwcm9maWxlAAB4nH2RPUjDUBSFT1ulIhUFOxRxyFBdtCAq0lGrUIQKoVZo'
    b'1cHkpX/QpCFJcXEUXAsO/ixWHVycdXVwFQTBHxA3NydFFynxvqTQIsYLj/dx3j2H9+4D/I0K'
    b'U82uCUDVLCOdTAjZ3KoQfIUPEQwgjjGJmfqcKKbgWV/31E11F+NZ3n1/Vp+SNxngE4hnmW5Y'
    b'xBvEM5uWznmfOMxKkkJ8Tjxu0AWJH7kuu/zGueiwn2eGjUx6njhMLBQ7WO5gVjJU4mniqKJq'
    b'lO/Puqxw3uKsVmqsdU/+wlBeW1nmOq1hJLGIJYgQIKOGMiqwEKNdI8VEms4THv4hxy+SSyZX'
    b'GYwcC6hCheT4wf/g92zNwtSkmxRKAN0vtv0xAgR3gWbdtr+Pbbt5AgSegSut7a82gPgn6fW2'
    b'Fj0C+reBi+u2Ju8BlztA5EmXDMmRArT8hQLwfkbflAMGb4HeNXdurXOcPgAZmlXqBjg4BEaL'
    b'lL3u8e6ezrn929Oa3w/KSnLKc4m6gwAAD6BpVFh0WE1MOmNvbS5hZG9iZS54bXAAAAAAADw/'
    b'eHBhY2tldCBiZWdpbj0i77u/IiBpZD0iVzVNME1wQ2VoaUh6cmVTek5UY3prYzlkIj8+Cjx4'
    b'OnhtcG1ldGEgeG1sbnM6eD0iYWRvYmU6bnM6bWV0YS8iIHg6eG1wdGs9IlhNUCBDb3JlIDQu'
    b'NC4wLUV4aXYyIj4KIDxyZGY6UkRGIHhtbG5zOnJkZj0iaHR0cDovL3d3dy53My5vcmcvMTk5'
    b'OS8wMi8yMi1yZGYtc3ludGF4LW5zIyI+CiAgPHJkZjpEZXNjcmlwdGlvbiByZGY6YWJvdXQ9'
    b'IiIKICAgIHhtbG5zOmlwdGNFeHQ9Imh0dHA6Ly9pcHRjLm9yZy9zdGQvSXB0YzR4bXBFeHQv'
    b'MjAwOC0wMi0yOS8iCiAgICB4bWxuczp4bXBNTT0iaHR0cDovL25zLmFkb2JlLmNvbS94YXAv'
    b'MS4wL21tLyIKICAgIHhtbG5zOnN0RXZ0PSJodHRwOi8vbnMuYWRvYmUuY29tL3hhcC8xLjAv'
    b'c1R5cGUvUmVzb3VyY2VFdmVudCMiCiAgICB4bWxuczpwbHVzPSJodHRwOi8vbnMudXNlcGx1'
    b'cy5vcmcvbGRmL3htcC8xLjAvIgogICAgeG1sbnM6R0lNUD0iaHR0cDovL3d3dy5naW1wLm9y'
    b'Zy94bXAvIgogICAgeG1sbnM6ZGM9Imh0dHA6Ly9wdXJsLm9yZy9kYy9lbGVtZW50cy8xLjEv'
    b'IgogICAgeG1sbnM6dGlmZj0iaHR0cDovL25zLmFkb2JlLmNvbS90aWZmLzEuMC8iCiAgICB4'
    b'bWxuczp4bXA9Imh0dHA6Ly9ucy5hZG9iZS5jb20veGFwLzEuMC8iCiAgIHhtcE1NOkRvY3Vt'
    b'ZW50SUQ9ImdpbXA6ZG9jaWQ6Z2ltcDozZWVmZTk5Yy1hZWIyLTRkZTktOTYzOS1iZDY3Zjlm'
    b'ZTYxZjgiCiAgIHhtcE1NOkluc3RhbmNlSUQ9InhtcC5paWQ6OTgzOGI4YTQtMjU4ZC00MTJm'
    b'LTgwYjItNTZhZGMxYTM2MThiIgogICB4bXBNTTpPcmlnaW5hbERvY3VtZW50SUQ9InhtcC5k'
    b'aWQ6NmRlMzQzOTAtNjNiNi00OTQ0LWI3MDUtNmQyYjVmM2NlYTE5IgogICBHSU1QOkFQST0i'
    b'Mi4wIgogICBHSU1QOlBsYXRmb3JtPSJNYWMgT1MiCiAgIEdJTVA6VGltZVN0YW1wPSIxNjEx'
    b'NTA3NTE1ODI3NDU3IgogICBHSU1QOlZlcnNpb249IjIuMTAuMjIiCiAgIGRjOkZvcm1hdD0i'
    b'aW1hZ2UvcG5nIgogICB0aWZmOk9yaWVudGF0aW9uPSIxIgogICB4bXA6Q3JlYXRvclRvb2w9'
    b'IkdJTVAgMi4xMCI+CiAgIDxpcHRjRXh0OkxvY2F0aW9uQ3JlYXRlZD4KICAgIDxyZGY6QmFn'
    b'Lz4KICAgPC9pcHRjRXh0OkxvY2F0aW9uQ3JlYXRlZD4KICAgPGlwdGNFeHQ6TG9jYXRpb25T'
    b'aG93bj4KICAgIDxyZGY6QmFnLz4KICAgPC9pcHRjRXh0OkxvY2F0aW9uU2hvd24+CiAgIDxp'
    b'cHRjRXh0OkFydHdvcmtPck9iamVjdD4KICAgIDxyZGY6QmFnLz4KICAgPC9pcHRjRXh0OkFy'
    b'dHdvcmtPck9iamVjdD4KICAgPGlwdGNFeHQ6UmVnaXN0cnlJZD4KICAgIDxyZGY6QmFnLz4K'
    b'ICAgPC9pcHRjRXh0OlJlZ2lzdHJ5SWQ+CiAgIDx4bXBNTTpIaXN0b3J5PgogICAgPHJkZjpT'
    b'ZXE+CiAgICAgPHJkZjpsaQogICAgICBzdEV2dDphY3Rpb249InNhdmVkIgogICAgICBzdEV2'
    b'dDpjaGFuZ2VkPSIvIgogICAgICBzdEV2dDppbnN0YW5jZUlEPSJ4bXAuaWlkOmQ5ZGQ5MjMw'
    b'LWQwNTctNDEzNi1iMjRmLTU2OGJiMjZmZTc3OSIKICAgICAgc3RFdnQ6c29mdHdhcmVBZ2Vu'
    b'dD0iR2ltcCAyLjEwIChNYWMgT1MpIgogICAgICBzdEV2dDp3aGVuPSIyMDIxLTAxLTI0VDEw'
    b'OjU4OjM1LTA2OjAwIi8+CiAgICA8L3JkZjpTZXE+CiAgIDwveG1wTU06SGlzdG9yeT4KICAg'
    b'PHBsdXM6SW1hZ2VTdXBwbGllcj4KICAgIDxyZGY6U2VxLz4KICAgPC9wbHVzOkltYWdlU3Vw'
    b'cGxpZXI+CiAgIDxwbHVzOkltYWdlQ3JlYXRvcj4KICAgIDxyZGY6U2VxLz4KICAgPC9wbHVz'
    b'OkltYWdlQ3JlYXRvcj4KICAgPHBsdXM6Q29weXJpZ2h0T3duZXI+CiAgICA8cmRmOlNlcS8+'
    b'CiAgIDwvcGx1czpDb3B5cmlnaHRPd25lcj4KICAgPHBsdXM6TGljZW5zb3I+CiAgICA8cmRm'
    b'OlNlcS8+CiAgIDwvcGx1czpMaWNlbnNvcj4KICA8L3JkZjpEZXNjcmlwdGlvbj4KIDwvcmRm'
    b'OlJERj4KPC94OnhtcG1ldGE+CiAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAKICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgIAogICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgCiAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAKICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgIAogICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgCiAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAKICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgIAogICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgCiAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAKICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgIAogICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgCiAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAKICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgIAogICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgCiAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAKICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgIAogICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'CiAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAKICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgICAgIAogICAgICAgICAgICAg'
    b'ICAgICAgICAgICAgICAKPD94cGFja2V0IGVuZD0idyI/PgdeROIAAAAGYktHRAD/AP8A/6C9'
    b'p5MAAAAJcEhZcwAACxMAAAsTAQCanBgAAAAHdElNRQflARgQOiO5eHoqAAAAI3RFWHRDb21t'
    b'ZW50AFJldmVyc2UtRW5naW5lZXJlZCBieSBoYXNpadNjEEMAAABbSURBVFjD7ZU7DgAgCEPB'
    b'+99ZFwcnwQQoiX0Jm6GV8BEhhDRm7khFL+KedyU/L6mEJVZiwhJJNeFNHm5Cj4T6YDaMgZ51'
    b'uAF4D7SZghZ7ALIJW94CSNkJIeRfFkpAJ+PtcHXSAAAAAElFTkSuQmCC')

